package com.jiankangyouyi.cloud.basedata.enums;

import com.jiankangyouyi.cloud.data.center.api.enums.ActivityLevelEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 活动强度Enum
 * <p>
 * 活动强度 0 未知 1 极轻 2 轻度 3 中度 4 重度
 *
 * @author yangsongbo
 */
@AllArgsConstructor
@Getter
public class ActivityLevelPalUtil {

    private final static int AGE7 = 7;
    private final static int AGE18 = 18;

    /**
     * 根据活动等级与年龄获取枚举
     *
     * @param activityLevel 活动等级
     * @param age           年龄
     * @return 活动等级枚举
     */
    public static double getEnumPal(String activityLevel, int age) {
        ActivityLevelEnum activityLevelEnum = ActivityLevelEnum.getEnum(activityLevel);
        double pal = activityLevelEnum.getRate();

        if (age < AGE7) {
            return 1;
        } else if (age < AGE18) {
            if (activityLevelEnum == ActivityLevelEnum.ACTIVITY_LEVEL_LIGHT) {
                return 1.375;
            }
        }
        return pal;
    }
}
