package com.jiankangyouyi.cloud.basedata.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NonNull;

import java.math.BigDecimal;

import static com.jiankangyouyi.cloud.basedata.constant.Constants.BMI_LESS_THAN_64_ADVICE;
import static com.jiankangyouyi.cloud.basedata.constant.Constants.BMI_MORE_THAN_64_ADVICE;

/**
 * bmi 状态
 *
 * @author : lvhaoran
 * @date Date : 2022年01月18日
 */
@AllArgsConstructor
@Getter
public enum BMIStatusEnum {
    /**
     * 消瘦
     */
    THIN("1", "消瘦"),

    /**
     * 正常
     */
    NORMAL("2", "正常"),

    /**
     * 超重
     */
    OVERWEIGHT("3", "超重"),
    /**
     * 肥胖
     */
    OBESITY("4", "肥胖"),
    ;

    private String status;

    /**
     * 描述
     */
    private String description;


    public static BMIStatusEnum getEnum(String status) {
        BMIStatusEnum[] values = values();
        if (status == null) {
            return null;
        }
        for (BMIStatusEnum value : values) {
            if (status.equals(value.status)) {
                return value;
            }
        }
        return null;
    }


    /**
     * 获取小于64 bmi 状态
     *
     * @param bmi bmi
     * @return BMIStatusEnum
     */
    public static BMIStatusEnum getLessThan64BmiStatus(@NonNull BigDecimal bmi) {
        BigDecimal bmiUpperLimit = new BigDecimal("18.5");
        BigDecimal bmiLowerLimit = new BigDecimal("23.9");
        BigDecimal bmiUpperLimit1 = new BigDecimal("24");
        BigDecimal bmiLowerLimit1 = new BigDecimal("27.9");
        if (bmi.compareTo(bmiUpperLimit) < 0) {
            return BMIStatusEnum.THIN;
        } else if (bmi.compareTo(bmiUpperLimit) >= 0 && bmi.compareTo(bmiLowerLimit) <= 0) {
            return BMIStatusEnum.NORMAL;
        } else if (bmi.compareTo(bmiUpperLimit1) >= 0 && bmi.compareTo(bmiLowerLimit1) <= 0) {
            return BMIStatusEnum.OVERWEIGHT;
        }
        return BMIStatusEnum.OBESITY;
    }

    /**
     * 获取大于64 bmi 状态
     *
     * @param bmi bmi
     * @return BMIStatusEnum
     */
    public static BMIStatusEnum getMoreThan64BmiStatus(@NonNull BigDecimal bmi) {
        BigDecimal bmiUpperLimit = new BigDecimal("20");
        BigDecimal bmiLowerLimit = new BigDecimal("26.9");
        BigDecimal bmiUpperLimit1 = new BigDecimal("27");
        BigDecimal bmiLowerLimit1 = new BigDecimal("27.9");
        if (bmi.compareTo(bmiUpperLimit) < 0) {
            return BMIStatusEnum.THIN;
        } else if (bmi.compareTo(bmiUpperLimit) >= 0 && bmi.compareTo(bmiLowerLimit) <= 0) {
            return BMIStatusEnum.NORMAL;
        } else if (bmi.compareTo(bmiUpperLimit1) >= 0 && bmi.compareTo(bmiLowerLimit1) <= 0) {
            return BMIStatusEnum.OVERWEIGHT;
        }
        return BMIStatusEnum.OBESITY;
    }


    /**
     * 获取bmi 建议话术
     */
    public static BMIStatusEnum getBmiStatus(@NonNull BigDecimal age, @NonNull BigDecimal bmi) {
        BigDecimal ageLimit = new BigDecimal("64");
        if (age.compareTo(ageLimit) <= 0) {
            return getLessThan64BmiStatus(bmi);
        } else {
            return getMoreThan64BmiStatus(bmi);
        }
    }

    /**
     * 获取bmi 建议话术
     */
    public static String getBmiAdvice(@NonNull BigDecimal age) {
        BigDecimal ageLimit = new BigDecimal("64");
        if (age.compareTo(ageLimit) <= 0) {
            return BMI_LESS_THAN_64_ADVICE;
        } else {
            return BMI_MORE_THAN_64_ADVICE;
        }
    }
}
