package com.jiankangyouyi.cloud.basedata.enums;

import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;


/**
 * Redis Key Enum
 *
 * @author yangsongbo
 */
@AllArgsConstructor
public enum RedisKeyEnum {


    /**
     * <p>公共参数缓存，后缀为paramGroup、paramKey</p>
     */
    STRING_PARAM_VALUE("string_param_value", "公共参数缓存，后缀为paramGroup、paramKey"),

    /**
     * <p>公共参数缓存，后缀为paramGroup</p>
     */
    LIST_PARAM_VALUE("list_param_value", "公共参数缓存，后缀为paramGroup"),
    /**
     * 问卷缓存，存储为序列化对象，后缀为bizType
     */
    STRING_QUESTIONNAIRE("string_base_data_questionnaire", "问卷缓存，存储为序列化对象，后缀为bizType"),

    /**
     * 身体指标缓存，存储为序列化对象，后缀为indicator
     */
    STRING_BODY_INDICATOR("string_base_data_body_indicator", "身体指标缓存，存储为序列化对象，后缀为indicator"),
    /**
     * 字典缓存 后缀为dictType,dictSubType
     */
    LIST_BASE_DICT("list_base_dict", "字典数据缓存，后缀为dictType,dictSubType"),
    /**
     * 字典分类缓存 后缀为dictType
     */
    LIST_BASE_DICT_TYPE("list_base_dict_type", "字典分类数据缓存，后缀为dictType"),
    /**
     * 指标写锁缓存，存储为指定信息，后缀为classify1
     */
    STRING_INDICATOR_LOCK("string_base_data_indicator_lock", "指标写锁缓存，存储为指定信息，后缀为classify1"),

    /**
     * 身体指标缓存，存储为序列化对象，后缀为indicatorId
     */
    STRING_INDICATOR_CACHE("string_base_data_indicator_cache", "指标缓存，存储为序列化对象，后缀为indicatorId"),

    /**
     * 运动库锁，后缀为exerciseId
     */
    STRING_EXERCISE_LOCK("string_base_data_exercise_lock", "运动库锁，后缀为exerciseId"),

    /**
     * 运动库缓存，存储为序列化对象，后缀为后缀为exerciseId"
     */
    STRING_EXERCISE_CACHE("string_base_data_exercise_cache", "运动库缓存，存储为序列化对象，后缀为后缀为exerciseId"),


    /**
     * 导出数据间隔时间，后缀为account，exportType
     */
    STRING_EXPORT_DATA_INTERVAL("string_base_data_export_data_interval", "导出数据间隔时间，后缀为account，exportType"),

    /**
     * 分类数据列表缓存，后缀为bizProperty
     */
    LIST_BASE_CLASSIFY("list_base_data_classify", "分类数据列表缓存，后缀为bizProperty"),
    /**
     * 问卷缓存，存储为序列化对象，后缀为bizType+版本号
     */
    STRING_QUESTIONNAIRE_VERSION("string_base_data_questionnaire_version", "问卷缓存，存储为序列化对象，后缀为bizType+版本号"),

    /**
     * 运动梅脱值列表缓存，后缀为bizProperty
     */
    LIST_SPORT_METRE("list_sport_metre", "运动梅脱值列表缓存，后缀为bizProperty"),


    /**
     * 食物排行榜-碳水化合物， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_CARBOHYDRATE("list_food_rank_list_carbohydrate", "食物排行榜-碳水化合物， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-蛋白质， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_PROTEIN("list_food_rank_list_protein", "食物排行榜-蛋白质， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-脂肪， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_FAT("list_food_rank_list_fat", "食物排行榜-脂肪， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-膳食纤维， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_DIETARY_FIBER("list_food_rank_list_dietary_fiber", "食物排行榜-膳食纤维， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-胆固醇， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_CHOLESTEROL("list_food_rank_list_cholesterol", "食物排行榜-胆固醇， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-钙， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_CALCIUM("list_food_rank_list_calcium", "食物排行榜-钙， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-铁， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_IRON("list_food_rank_list_iron", "食物排行榜-铁， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-锌， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_ZINC("list_food_rank_list_zinc", "食物排行榜-锌， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-锰， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_MANGANESE("list_food_rank_list_manganese", "食物排行榜-锰， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-镁， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_MAGNESIUM("list_food_rank_list_magnesium", "食物排行榜-镁， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-铬， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_CHROMIUM("list_food_rank_list_chromium", "食物排行榜-铬， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-钾， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_POTASSIUM("list_food_rank_list_potassium", "食物排行榜-钾， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-硒， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_SELENIUM("list_food_rank_list_selenium", "食物排行榜-硒， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-钠， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_SODIUM("list_food_rank_list_sodium", "食物排行榜-钠， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-碘， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_IODINE("list_food_rank_list_iodine", "食物排行榜-碘， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素C， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_C("list_food_rank_list_vitamin_c", "食物排行榜-维生素C， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素A， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_A("list_food_rank_list_vitamin_a", "食物排行榜-维生素A， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B1(硫胺素)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B1("list_food_rank_list_vitamin_b1", "食物排行榜-维生素B1(硫胺素)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素D， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_D("list_food_rank_list_vitamin_d", "食物排行榜-维生素D， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素E， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_E("list_food_rank_list_vitamin_e", "食物排行榜-维生素E， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B2(核黄素)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B2("list_food_rank_list_vitamin_b2", "食物排行榜-维生素B2(核黄素)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B3(烟酸)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B3("list_food_rank_list_vitamin_b3", "食物排行榜-维生素B3(烟酸)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B9(叶酸)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B9("list_food_rank_list_vitamin_b9", "食物排行榜-维生素B9(叶酸)， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B6， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B6("list_food_rank_list_vitamin_b6", "食物排行榜-维生素B6， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),

    /**
     * 食物排行榜-维生素B12， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_VITAMIN_B12("list_food_rank_list_vitamin_b12", "食物排行榜-维生素B12， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),
    
    /**
     * 食物排行榜-嘌呤， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量
     */
    LIST_FOOD_RANK_LIST_PURINE("list_food_rank_list_purine", "食物排行榜-嘌呤， 后缀为 LOW (低含量) 或 HIGH (高含量)，推荐数量"),


    /**
     * 标签库锁
     */
    LOCK_TAG("string_base_data_tag_lock", "标签库锁"),

    /**
     * 食物库同步ES锁
     */
    LOCK_FOOD_TO_ES("lock_food_to_es", "食物库同步ES锁"),


    /**
     * 刷新加工食品库锁
     */
    LOCK_FOOD_PROCESS_REFRESH("lock_food_process_refresh", "刷新加工食品库锁"),


    /**
     * 刷新食材库锁
     */
    LOCK_FOOD_MATERIAL_REFRESH("lock_food_material_refresh", "刷新食材库锁"),
    ;

    /**
     * redis key
     */
    private String key;

    /**
     * 描述
     */
    private String describe;


    public String getDescribe() {
        return this.describe;
    }

    public String getKey() {
        return this.key;
    }

    /**
     * 获取key
     *
     * @param keySuffixes key后缀
     * @return redis key
     */
    public String getKey(String... keySuffixes) {
        StringBuilder builder = new StringBuilder(this.key);

        if (ArrayUtils.isNotEmpty(keySuffixes)) {
            for (String keySuffix : keySuffixes) {
                if (StringUtils.isNotBlank(keySuffix)) {
                    builder.append("_").append(keySuffix);
                }
            }
        }
        return builder.toString();
    }


}



