package com.jiankangyouyi.cloud.basedata.enums;

import com.jiankangyouyi.cloud.basedata.api.model.entity.questionnaire.SingleChoiceMainOption;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * 地区枚举
 *
 * @author jingpeng
 */
@Getter
@AllArgsConstructor
public enum RegionEnum {


    /**
     * 北京市
     */
    BJ("110000","北京市"),

    /**
     * 天津市
     */
    TJ("120000","天津市"),

    /**
     * 河北省
     */
    HE("130000","河北省"),

    /**
     * 山西省
     */
    SX("140000","山西省"),

    /**
     * 内蒙古自治区
     */
    NM("150000","内蒙古自治区"),

    /**
     * 辽宁省
     */
    LN("210000","辽宁省"),

    /**
     * 吉林省
     */
    JL("220000","吉林省"),

    /**
     * 黑龙江省
     */
    HL("230000","黑龙江省"),

    /**
     * 上海市
     */
    SH("310000","上海市"),

    /**
     * 江苏省
     */
    JS("320000","江苏省"),

    /**
     * 浙江省
     */
    ZJ("330000","浙江省"),

    /**
     * 安徽省
     */
    AH("340000","安徽省"),

    /**
     * 福建省
     */
    FJ("350000","福建省"),

    /**
     * 江西省
     */
    JX("360000","江西省"),

    /**
     * 山东省
     */
    SD("370000","山东省"),

    /**
     * 河南省
     */
    HA("410000","河南省"),

    /**
     * 湖北省
     */
    HB("420000","湖北省"),

    /**
     * 湖南省
     */
    HM("430000","湖南省"),

    /**
     * 广东省
     */
    GD("440000","广东省"),

    /**
     * 广西壮族自治区
     */
    GX("450000","广西壮族自治区"),

    /**
     * 海南省
     */
    HI("460000","海南省"),

    /**
     * 重庆市
     */
    CQ("500000","重庆市"),

    /**
     * 四川省
     */
    SC("510000","四川省"),

    /**
     * 贵州省
     */
    GZ("520000","贵州省"),

    /**
     * 云南省
     */
    YN("530000","云南省"),

    /**
     * 西藏自治区
     */
    XZ("540000","西藏自治区"),

    /**
     * 陕西省
     */
    SN("610000","陕西省"),

    /**
     * 甘肃省
     */
    GS("620000","甘肃省"),

    /**
     * 青海省
     */
    QH("630000","青海省"),

    /**
     * 宁夏回族自治区
     */
    NX("640000","宁夏回族自治区"),

    /**
     * 新疆维吾尔自治区
     */
    XJ("650000","新疆维吾尔自治区"),

    /**
     * 台湾省
     */
    TW("710000","台湾省"),

    /**
     * 香港特别行政区
     */
    HK("810000","香港特别行政区"),

    /**
     * 澳门特别行政
     */
    MO("820000","澳门特别行政"),
    ;

    private String code;
    private String comment;


    public String code() {
        return code;
    }

    public String comment() {
        return comment;
    }

    public static RegionEnum parseCode(String code) {
        for (RegionEnum enumItem : RegionEnum.values()) {
            if (enumItem.getCode().equals(code)) {
                return enumItem;
            }
        }
        return null;
    }
    public static RegionEnum parseComment(String comment) {
        for (RegionEnum enumItem : RegionEnum.values()) {
            if (enumItem.getComment().equals(comment)) {
                return enumItem;
            }
        }
        return null;
    }

    public static Boolean contains(String code) {
        return parseCode(code) !=null || parseComment(code)!=null;
    }


    /**
     * 返回地区枚举的选择器选项
     * @return
     */
    public static List<SingleChoiceMainOption> getChoiceOptions(){
        List<SingleChoiceMainOption> list = new ArrayList<>();
        int i =0;
        for (RegionEnum type : RegionEnum.values()){
            i++;
            list.add(SingleChoiceMainOption.builder()
                    .optionCode(String.valueOf(i))
                    .optionValue(String.valueOf(i))
                    .optionContents(Collections.singletonList(type.getComment()))
                    .imageUrls(null)
                    .supplementContents(null)
                    .build());
        }
        return list;
    }
}
