package com.jiankangyouyi.cloud.basedata.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 处理码定义
 *
 * @author yangsongbo
 */
@Getter
@AllArgsConstructor
public enum ResultCodeEnum implements BaseEnum {

    /**
     * 成功
     */
    SUCCESS("0", "成功"),

    /**
     * 登出
     */
    LOGOUT("LOGOUT", "登出"),

    /**
     * 处理失败
     */
    ERROR("ERROR", "处理失败"),

    /**
     * 获取问卷失败
     */
    HBD0001("HBD0001", "获取问卷失败"),

    /**
     * 上传文件失败
     */
    HBD0002("HBD0002", "上传文件失败"),
    /**
     * 保存失败
     */
    HBD0003("HBD0003", "保存失败，请重新尝试"),

    /**
     * 更新失败
     */
    HBD0004("HBD0004", "更新失败，请重新尝试"),

    /**
     * 删除失败
     */
    HBD0005("HBD0005", "删除失败，请重新尝试"),

    /**
     * 参数不合法
     */
    HBD0006("HBD0006", "参数不合法"),

    /**
     * 问题分类不存在
     */
    HBD0007("HBD0007", "分类不存在"),
    /**
     * 上传文件失败/七牛云返回 qiniuKey 为 NULL
     */
    HBD0008("HBD0008", "上传文件失败"),
    /**
     * 问题详情解析失败
     */
    HBD0009("HBD0009", "问题详情解析失败"),
    /**
     * 食物批量启用停用操作存在失败条数
     */
    HBD0010("HBD0010", "食物批量启用停用操作存在失败条数"),
    /**
     * 列表数据为空，无法导出
     */
    HBD0011("HBD0011", "列表数据为空，无法导出"),
    /**
     * 导出数据失败
     */
    HBD0012("HBD0012", "导出数据失败"),
    /**
     * 当前数据已存在，保存失败
     */
    HBD0013("HBD0013", "当前数据已存在，保存失败"),
    /**
     * 待操作的数据不存在，操作失败
     */
    HBD0014("HBD0014", "待操作的数据不存在，操作失败"),
    /**
     * 食物识别横向扩充兜底方案接口操作失败
     */
    HBD0015("HBD0015", "食物识别横向扩充兜底方案接口操作失败"),

    /**
     * 操作过于频繁，请稍后再试
     */
    HBD0016("HBD0016", "操作过于频繁，请稍后再试"),

    /**
     * 食材数据不存在
     */
    HBD0100("HBD0100", "食材数据不存在"),

    /**
     * 加工食品数据不存在
     */
    HBD0101("HBD0101", "加工食品数据不存在"),

    /**
     * 预包装食品数据不存在
     */
    HBD0102("HBD0102", "预包装食品数据不存在"),

    /**
     * 数据已被删除
     */
    HBD0103("HBD0103", "数据已被删除"),

    /**
     * 图片读取失败
     */
    IMG0001("IMG0001", "图片读取失败"),

    /**
     * 图片大小错误
     */
    IMG0002("IMG0002", "图片大小错误"),

    /**
     * 图片尺寸错误
     */
    IMG0003("IMG0003", "图片尺寸错误"),

    /**
     * 图片格式读取失败
     */
    IMG0004("IMG0004", "图片格式读取失败"),

    /**
     * 图片格式错误
     */
    IMG0005("IMG0005", "图片格式错误"),

    /**
     * 食物识别失败
     */
    IMG0006("IMG0006", "食物识别失败"),

    /**
     * HTTP BODY参数错误
     */
    SSP0002("SSP0002", "HTTP BODY参数错误"),

    /**
     * 尚未匹配可用的封面信息
     */
    HBD0104("HBD0104", "尚未匹配可用的封面信息"),
    /**
     * 尚未配置权限
     */
    HBD0105("HBD0105", "尚未配置权限"),

    /**
     * 非法操作
     */
    HBD0106("HBD0106", "非法操作"),
    /**
     * 处理失败
     */
    DATA0035("DATA0035", "食物识别失败"),

    /**
     * 翻译失败
     */
    TRANSLATE0001("TRANSLATE0001", "翻译失败"),

    /**
     * 文本纠错失败
     */
    DATA0036("DATA0036", "文本纠错失败"),

    /**
     * 图像超分辨率识别失败
     */
    DATA0037("DATA0037", "图像超分辨率识别失败"),

    /**
     * 语句重复度计算失败
     */
    DATA0038("DATA0038", "语句重复度计算失败"),
    ;

    private final String code;
    private final String message;


    @Override
    public String code() {
        return code;
    }

    @Override
    public String message() {
        return message;
    }

    public static ResultCodeEnum getEnum(String code) {
        ResultCodeEnum[] values = values();
        if (code == null) {
            return null;
        }
        for (ResultCodeEnum value : values) {
            if (code.equals(value.code)) {
                return value;
            }
        }
        return null;
    }
}
