package com.jiankangyouyi.cloud.basedata.enums;

import com.jiankangyouyi.cloud.basedata.api.enums.GenderEnum;
import com.jiankangyouyi.cloud.basedata.constant.Constants;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NonNull;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;

/**
 * 腰臀比 状态
 *
 * @author : lvhaoran
 * @date Date : 2022年01月19日
 */
@AllArgsConstructor
@Getter
public enum WaistHipRatioEnum {

    /**
     * 腹型肥胖
     */
    ABDOMINAL_OBESITY("1", "腹型肥胖"),

    /**
     * 正常
     */
    NORMAL("2", "正常"),

    ;

    private String status;

    /**
     * 描述
     */
    private String description;


    public static WaistHipRatioEnum getEnum(String status) {
        WaistHipRatioEnum[] values = values();
        if (status == null) {
            return null;
        }
        for (WaistHipRatioEnum value : values) {
            if (status.equals(value.status)) {
                return value;
            }
        }
        return null;
    }


    /**
     * 获取腰臀比 状态
     *
     * @param gender        性别
     * @param waistHipRatio 腰臀比
     * @return WaistHipRatioEnum
     */
    public static WaistHipRatioEnum getWaistHipRatioStatus(@NotBlank String gender, @NonNull BigDecimal waistHipRatio) {
        BigDecimal waistHipRatioMaleLimit = new BigDecimal("0.9");
        BigDecimal waistHipRatioFemaleLimit = new BigDecimal("0.85");
        if (StringUtils.equals(gender, GenderEnum.MALE.getGender())) {
            if (waistHipRatio.compareTo(waistHipRatioMaleLimit) > 0) {
                return WaistHipRatioEnum.ABDOMINAL_OBESITY;
            } else {
                return WaistHipRatioEnum.NORMAL;
            }
        } else {
            if (waistHipRatio.compareTo(waistHipRatioFemaleLimit) > 0) {
                return WaistHipRatioEnum.ABDOMINAL_OBESITY;
            } else {
                return WaistHipRatioEnum.NORMAL;
            }
        }
    }

    /**
     * 获取腰臀比话术
     *
     * @param gender            性别
     * @param waistHipRatioEnum 腰臀比状态
     * @return String
     */
    public static String getWaistHipRatioAdvice(@NotBlank String gender, @NonNull WaistHipRatioEnum waistHipRatioEnum) {
        String advice = "";
        switch (waistHipRatioEnum) {
            case ABDOMINAL_OBESITY:
                if (StringUtils.equals(gender, GenderEnum.MALE.getGender())) {
                    advice = Constants.MALE_ABDOMINAL_OBESITY_ADVICE;
                } else {
                    advice = Constants.FEMALE_ABDOMINAL_OBESITY_ADVICE;
                }
                break;
            case NORMAL:
                if (StringUtils.equals(gender, GenderEnum.MALE.getGender())) {
                    advice = Constants.MALE_NORMAL_ADVICE;
                } else {
                    advice = Constants.FEMALE_NORMAL_ADVICE;
                }
                break;
            default:
                break;
        }
        return advice;
    }
}
