package com.jiankangyouyi.cloud.basedata.model.dto.api;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Range;

import javax.validation.constraints.Digits;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;

/**
 * 计算体重指数BMI
 *
 * @author : lvhaoran
 * @date Date : 2022年01月18日
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class CalculationBmiAdviceDTO extends AbstractHttpApiRequestDTO {

    private static final long serialVersionUID = 1L;

    @NotBlank(message = "年龄不能为空")
    @Pattern(regexp = "^\\+?[1-9][0-9]*$", message = "年龄格式不合法")
    @Range(min = 18, max = 80, message = "年龄输入范围18岁-80岁")
    private String age;

    /**
     * 身高 CM 限制范围 100-230
     */
    @NotBlank(message = "身高不能为空")
    @Pattern(regexp = "^\\+?[1-9][0-9]*$", message = "身高必须为整数")
    @Range(min = 100, max = 230, message = "身高输入范围100cm-230cm")
    private String height;

    /**
     * 体重 KG 限制范围 25-200
     */
    @NotBlank(message = "体重不能为空")
    @Digits(integer = 3, fraction = 1, message = "体重支持1位小数")
    @Range(min = 25, max = 200, message = "体重输入范围25kg-200kg")
    private String weight;
}
