package com.jiankangyouyi.cloud.basedata.model.dto.api;

import lombok.*;
import org.hibernate.validator.constraints.Range;

import javax.validation.constraints.Digits;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;

/**
 * 计算体重指数BMI
 *
 * @author : lvhaoran
 * @date Date : 2022年01月18日
 */
@EqualsAndHashCode(callSuper = true)
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class CalculationBmrAdviceRequestDTO extends AbstractHttpApiRequestDTO {

    private static final long serialVersionUID = 1L;

    /**
     * 身高 CM 限制范围 50-230
     */
    @NotBlank(message = "请求参数height不能为空")
    @Range(min = 50, max = 230, message = "身高输入范围50cm-230cm")
    private String height;

    /**
     * 体重 KG 限制范围 10-200
     */
    @NotBlank(message = "请求参数weight不能为空")
    @Digits(integer = 3, fraction = 1, message = "体重支持1位小数")
    @Range(min = 10, max = 200, message = "体重输入范围10kg-200kg")
    private String weight;

    /**
     * 年龄  限制范围 1-100
     */
    @NotBlank(message = "请求参数age不能为空")
    @Range(min = 1, max = 100, message = "年龄输入范围1-100")
    private String age;

    /**
     * 性别 限制范围 1男 2女
     * {@link GenderEnum}
     */
    @NotBlank(message = "请求参数gender不能为空")
    @Pattern(regexp = "(1|2)", message = "性别格式不合法")
    private String gender;

    /**
     * 体力活动等级 限制范围 1，2，3
     */
    @NotBlank(message = "请求参数activityLevel不能为空")
    @Range(min = 1,max = 4, message = "体力活动等级不合法")
    private String activityLevel;
}
