package com.jiankangyouyi.cloud.basedata.model.dto.api;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Range;

import javax.validation.constraints.Digits;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;

/**
 * 腰臀比计算
 *
 * @author : lvhaoran
 * @date Date : 2022年01月19日
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class CalculationWaistHipRatioAdviceDTO extends AbstractHttpApiRequestDTO {

    private static final long serialVersionUID = 1L;

    /**
     * 性别
     */
    @NotBlank(message = "性别不能为空")
    @Pattern(regexp = "(1|2)", message = "性别格式不合法")
    private String gender;

    /**
     * 腰围
     */
    @NotBlank(message = "腰围不能为空")
    @Digits(integer = 3, fraction = 1, message = "腰围支持1位小数")
    @Range(min = 50, max = 200, message = "腰围输入范围50cm-200cm")
    private String waistline;

    /**
     * 臀围
     */
    @NotBlank(message = "臀围不能为空")
    @Digits(integer = 3, fraction = 1, message = "臀围支持1位小数")
    @Range(min = 50, max = 200, message = "臀围输入范围50cm-200cm")
    private String hipCircumference;
}
