package com.jiankangyouyi.cloud.basedata.model.dto.api;

import com.jiankangyouyi.cloud.basedata.model.dto.api.component.FoodRankListQuery;
import com.jiankangyouyi.cloud.core.validator.annotation.IntValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MaxHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MinHC;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 食物排行榜DTO
 *
 * @author yangsongbo
 **/
@Data
@EqualsAndHashCode(callSuper = false)
@AllArgsConstructor
@NoArgsConstructor
public class FoodRankListDTO extends AbstractHttpApiRequestDTO {


    /**
     * 返回条数，默认为20，范围[1,20]
     */
    @MaxHC(value = 20, message = "请求参数top合理范围为[1,20]")
    @MinHC(value = 1, message = "请求参数top合理范围为[1,20]")
    @IntValHC(message = "请求参数top必须为整数")
    private String top;


    /**
     * 查询列表
     */
    @Valid
    @NotEmpty(message = "请求参数queryList不能为空")
    private List<FoodRankListQuery> queryList;

}
