package com.jiankangyouyi.cloud.basedata.model.dto.api;

import com.jiankangyouyi.cloud.core.validator.annotation.IntValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MaxHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MinHC;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;

/**
 * 细粒度食物识别
 *
 * @author lvqidong
 * @date 2022/02/28 13:08
 **/
@Data
@EqualsAndHashCode(callSuper = true)
public class RecognitionFoodDTO extends AbstractHttpApiRequestDTO implements Serializable {


    /**
     * 食物图片Base64
     */
    private String image;

    /**
     * 食物图片URL
     */
    private String imageUrl;

    /**
     * top 返回数量
     */
    @IntValHC(message = "请求参数top不合法")
    @MaxHC(value = 5, message = "请求参数top范围为[1,5]")
    @MinHC(value = 1, message = "请求参数top范围为[1,5]")
    private String top;

    /**
     * 返回食物图像宽度
     */
    @IntValHC(message = "请求参数imageWidth不合法")
    @MaxHC(value = 9999, message = "请求参数imageWidth范围为[0,9999]")
    @MinHC(value = 0, message = "请求参数imageWidth范围为[0,9999]")
    private String imageWidth;

}
