package com.jiankangyouyi.cloud.basedata.model.dto.manager;

import com.jiankangyouyi.cloud.basedata.api.enums.OpenStatusEnum;
import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：2022/8/4 5:41 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
public class HealthTipListPageDTO extends AbstractManagerRequestDTO implements ValidDTO {

    /**
     * 小贴士ID (知识ID)
     */
    @Size(max = 32,message = "请求参数 tipId 超过有效长度 32")
    private String tipId;
    /**
     * 小贴士标题
     */
    @Size(max = 50,message = "请求参数 tipTitle 超过有效长度 50")
    private String tipTitle;
    /**
     * 小贴士内容
     */
    @Size(max = 200,message = "请求参数 content 超过有效长度 200")
    private String content;

    /**
     * 自定义标签
     */
    private List<String> customTags;

    /**
     * 启用状态 1、启用 2、禁用
     */
    @EnumHC(enumTypes = OpenStatusEnum.class)
    private String openStatus;

    /**
     * 更新开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateTimeStart不合法")
    private String updateTimeStart;
    /**
     * 更新结束始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateTimeEnd不合法")
    private String updateTimeEnd;

    /**
     * 分页信息
     */
    @NotNull(message = "请求参数 page 不能为空")
    private Page page;

}
