package com.jiankangyouyi.cloud.basedata.model.dto.manager;

import com.jiankangyouyi.cloud.basedata.api.enums.LifeStyleSchemeTypeEnum;
import com.jiankangyouyi.cloud.basedata.api.enums.OpenStatusEnum;
import com.jiankangyouyi.cloud.basedata.api.model.component.CrowdType;
import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.BigDecimalValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：2022/8/5 9:11 上午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
public class LifeStyleSchemeListPageDTO extends AbstractManagerRequestDTO implements ValidDTO {
    /**
     * 方案ID
     */
    @Size(max = 32,message = "请求参数 schemeId 超过有效长度 32")
    private String schemeId;
    /**
     * 小贴士标题
     */
    @Size(max = 20,message = "请求参数 schemeName 超过有效长度 20")
    private String schemeName;
    /**
     * 方案类型
     */
    @Size(max = 32,message = "请求参数 schemeType 超过有效长度 32")
    @EnumHC(enumTypes = LifeStyleSchemeTypeEnum.class,message = "请求参数 schemeType 不合法")
    private String schemeType;

    /**
     * 方案标题
     */
    @Size(max = 50,message = "请求参数 schemeTitle 超过有效长度 50")
    private String schemeTitle;
    /**
     * 不良标签
     */
    @Size(max = 32,message = "请求参数 unhealthyLabel 超过有效长度 32")
    private String unhealthyLabel;
    /**
     * 人群类型
     */
    private List<CrowdType> crowdTypes;
    /**
     * 小贴士ID(知识ID)
     */
    @Size(max = 32,message = "请求参数 tipId 超过有效长度 32")
    private String tipId;

    /**
     * 启用状态 1、启用 2、禁用
     */
    @EnumHC(enumTypes = OpenStatusEnum.class)
    private String openStatus;

    /**
     * 更新开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateTimeStart不合法")
    private String updateTimeStart;
    /**
     * 更新结束始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateTimeEnd不合法")
    private String updateTimeEnd;

    /**
     * 哺乳状态 1：哺乳期 2：非哺乳期
     */
    private String lactationStatus;

    /**
     * 产后阶段天数 起
     */
    @BigDecimalValHC()
    private Integer postpartumStartDays;

    /**
     * 产后阶段天数 止
     */
    @BigDecimalValHC()
    private Integer postpartumEndDays;


    /**
     * 分页信息
     */
    @NotNull(message = "请求参数 page 不能为空")
    private Page page;
}
