package com.jiankangyouyi.cloud.basedata.model.dto.manager;

import com.jiankangyouyi.cloud.basedata.api.enums.LifeStyleSchemeTypeEnum;
import com.jiankangyouyi.cloud.basedata.api.model.component.CrowdType;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.PunchCardContent;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.RuleLimit;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.BigDecimalValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import com.jiankangyouyi.cloud.data.center.api.enums.LactationStatusEnum;
import lombok.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：2022/8/5 9:11 上午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class LifeStyleSchemeSaveDTO extends AbstractManagerRequestDTO implements ValidDTO {
    /**
     * 方案ID
     */
    @Size(max = 32,message = "请求参数 schemeId 超过有效长度 32")
    private String schemeId;
    /**
     * 小贴士标题
     */
    @NotBlank(message = "请求参数 schemeName 不能为空")
    @Size(max = 20,message = "请求参数 schemeName 超过有效长度 20")
    private String schemeName;
    /**
     * 方案类型
     */
    @NotBlank(message = "请求参数 schemeType 不能为空")
    @Size(max = 32,message = "请求参数 schemeType 超过有效长度 32")
    @EnumHC(enumTypes = LifeStyleSchemeTypeEnum.class,message = "请求参数 schemeType 不合法")
    private String schemeType;

    /**
     * 方案标题
     */
    @NotBlank(message = "请求参数 schemeTitle 不能为空")
    @Size(max = 50,message = "请求参数 schemeTitle 超过有效长度 50")
    private String schemeTitle;
    /**
     * 人群类型
     */
    @NotEmpty(message = "请求参数 crowdTypes 不能为空")
    @Valid
    private List<CrowdType> crowdTypes;

    /**
     * 哺乳状态 1：哺乳期，2：非哺乳期
     */
    @EnumHC(enumTypes = LactationStatusEnum.class,message = "请求参数 lactationStatus 不合法")
    private String lactationStatus;

    /**
     * 产后阶段天数 起
     */
    @BigDecimalValHC()
    private Integer postpartumStartDays;

    /**
     * 产后阶段天数 止
     */
    @BigDecimalValHC()
    private Integer postpartumEndDays;

    /**
     * 规则组合
     */
    @Valid
    private List<RuleLimit> ruleLimits;

    /**
     * 打卡内容
     */
    @NotNull(message = "请求参数 punchCardContent 不能为空")
    @Valid
    private PunchCardContent punchCardContent;
}
