package com.jiankangyouyi.cloud.basedata.model.dto.manager.action;

import com.jiankangyouyi.cloud.basedata.api.enums.action.RelationActionOrderTypeEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.*;

import javax.validation.constraints.*;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/6/4 10:42 上午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ExerciseModern2UpdateDTO extends AbstractManagerRequestDTO implements ValidDTO {
    /**
     * 动作编号
     */
    @NotBlank(message = "请求参数actionId不能为空")
    @Size(max = 20,message = "请求参数actionId有效长度为20")
    private String actionId;
    /**
     * 动作名称
     */
    @NotBlank(message = "请求参数actionName不能为空")
    @Size(max = 20,message = "请求参数actionName有效长度为20")
    private String actionName;
    /**
     * 是否为被关联动作
     */
    @EnumHC(enumTypes = RelationActionOrderTypeEnum.class)
    private String relationActionOrder;
    /**
     * 是否为被关联动作
     */
    private Boolean relation;
    /**
     * 关联动作编号
     */
    private String relationId;
    /**
     * 动作特点
     */
    private List<String> actionFeatures;
    /**
     * 动作分类
     */
    @NotBlank(message = "请求参数actionClassification不能为空")
    @Size(max = 16,message = "请求参数actionClassification最大有效长度为16")
    private String actionClassification;
    /**
     * 动作难度
     */
    @NotBlank(message = "请求参数actionDifficulty不能为空")
    @Size(max = 16,message = "请求参数actionDifficulty最大有效长度为16")
    private String actionDifficulty;
    /**
     * 梅脱值
     */
    @NotNull(message = "请求参数met不能为空")
    private Double met;
    /**
     * 动作强度
     */
    @NotBlank(message = "请求参数actionIntensity不能为空")
    @Size(max = 16,message = "请求参数actionIntensity最大有效长度为16")
    private String actionIntensity;

    /**
     * 动作体位
     */
    @NotBlank(message = "请求参数actionPosition不能为空")
    @Size(max = 16,message = "请求参数actionPosition最大有效长度为16")
    private String actionPosition;
    /**
     * 训练肌群/锻炼部位
     */
    @NotEmpty(message = "请求参数trainPositions不能为空")
    private List<String> trainPositions;
    /**
     * 器械名称
     */
    @NotEmpty(message = "请求参数equipments不能为空")
    private List<String> equipments;
    /**
     * 动作讲解
     */
    @NotEmpty(message = "请求参数actionExplains不能为空")
    private List<String> actionExplains;
    /**
     * 注意事项
     */
    @NotEmpty(message = "请求参数attentions不能为空")
    private List<String> attentions;
}
