package com.jiankangyouyi.cloud.basedata.model.dto.manager.article;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.enums.food.AuditStatusEnum;
import com.jiankangyouyi.cloud.basedata.api.enums.food.AuditStatusValidEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * @description: 分页查询文章库请求dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/10/25 3:34 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class FindArticleRequestDTO extends AbstractManagerRequestDTO {
    /**
     * 分页条件
     */
    @NotNull(message = "page not null")
    @Valid
    private Page page;
    /**
     * 文章id
     */
    private String articleId;

    /**
     * 1级分类codes
     */
    private Set<String> cls1Codes;
    /**
     * 2级分类codes
     */
    private Set<String> cls2Codes;

    /**
     * 标签
     */
    private Set<String> tags;
    /**
     * 标签 是否选择空选项 默认false
     */
    private Boolean tagsSelectNull = false;

    /**
     * 状态 [1:启用][3:停用]
     */
    private Set<Integer> status;
    /**
     * 审核状态
     * {@link AuditStatusEnum}
     */
    private List<String> auditStatus;
    /**
     * 关键字
     */
    private String keyword;

    /**
     * 创建时间起 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTimeStart;
    /**
     * 创建时间止 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTimeEnd;

    /**
     * 修改时间起 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTimeStart;
    /**
     * 修改时间止 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTimeEnd;

    /**
     * 采纳时间起 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date adoptTimeStart;

    /**
     * 采纳时间止 yyyy-MM-dd HH:mm:ss
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date adoptTimeEnd;

    /**
     * 排序字段 默认为updateTime
     */
    private String orderColumn;

    /**
     * 是否升序 默认false
     */
    private boolean asc;
    /**
     * 创建人
     */
    private String createAccount;
    /**
     * 采纳人
     */
    private String adoptAccount;
}
