package com.jiankangyouyi.cloud.basedata.model.dto.manager.common;

import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.constraints.Max;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * 分类保存参数
 *
 * @author fengxuanjun
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class BaseDataClassifySaveDTO extends AbstractManagerRequestDTO implements ValidDTO {

    private static final long serialVersionUID = 1L;

    /**
     * 分类ID，新增是null，修改时必传）
     */
    @Size(max = 32, message = "请求参数classifyId长度不合法")
    private String classifyId;

    /**
     * 业务属性
     * 1 食材库
     * 2 加工食品库
     * 3 包装食品库
     * 4 中医药材库
     * 5 问题库
     * 6 指标库
     */
    @NotBlank(message = "请求参数bizProperty不能为空")
    @Size(max = 3, message = "请求参数bizProperty长度不合法")
    private String bizProperty;

    /**
     * 分类编码，修改时必传
     */
    @Size(max = 4, message = "请求参数classifyCode长度不合法")
    private String classifyCode;

    /**
     * 上级分类ID
     */
    @NotBlank(message = "请求参数parentId不能为空")
    @Size(max = 32, message = "请求参数parentId长度不合法")
    private String parentId;

    /**
     * 分类名称
     */
    @NotBlank(message = "请求参数classifyName不能为空")
    @Size(max = 20, message = "请求参数classifyName长度不合法")
    private String classifyName;

    /**
     * 等级
     */
    @NotNull(message = "请求参数level不能为空")
    @Max(value = 10, message = "请求参数classifyLevel长度不合法")
    private Integer classifyLevel;

    /**
     * 排序,默认 9999
     */
    @NotNull(message = "请求参数rowOrder不能为空")
    @Max(value = 9999, message = "请求参数rowOrder长度不合法")
    private Integer rowOrder;

    /**
     * 是否有效 1：有效，2：无效
     */
    @NotBlank(message = "请求参数validStatus不能为空")
    @Size(max = 1, message = "请求参数validStatus长度不合法")
    private String validStatus;

    /**
     * NULL 分类图片
     */
    @Size(max = 255, message = "请求参数imageUrl长度不合法")
    private String imageUrl;

    /**
     * 分类简介
     */
    @Size(max = 500, message = "请求参数description长度不合法")
    private String description;

    /**
     * 临床意义
     */
    @Size(max = 500, message = "请求参数meaning长度不合法")
    private String meaning;

}
