package com.jiankangyouyi.cloud.basedata.model.dto.manager.common;

import com.jiankangyouyi.cloud.basedata.enums.export.ExportLocationEnum;
import com.jiankangyouyi.cloud.basedata.enums.export.ExportStatusEnum;
import com.jiankangyouyi.cloud.basedata.enums.export.ExportTypeEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * 数据导出结果列表
 *
 * @author yangsongbo
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class ManagerDataExportResultDTO extends AbstractManagerRequestDTO {

    private static final long serialVersionUID = 1L;


    /**
     * 分页参数
     */
    @NotNull(message = "分页参数page不能为空")
    @Valid
    private Page page;

    /**
     * 导出数据ID
     */
    @Size(max = 32, message = "请求参数exportId长度不合法")
    private String exportId;

    /**
     * 导出类型
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.enums.export.ExportTypeEnum}
     */
    @EnumHC(enumTypes = ExportTypeEnum.class, message = "请求参数exportType不合法")
    private String exportType;

    /**
     * 导出位置
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.enums.export.ExportLocationEnum}
     */
    @EnumHC(enumTypes = ExportLocationEnum.class, message = "请求参数exportLocation不合法")
    private String exportLocation;


    /**
     * 导出状态
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.enums.export.ExportStatusEnum}
     */
    @EnumHC(enumTypes = ExportStatusEnum.class, message = "请求参数exportStatus不合法")
    private String exportStatus;

    /**
     * 开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(pattern = "yyyy-MM-dd HH:mm:ss", message = "请求参数beginTime不合法")
    private String beginCreateTime;

    /**
     * 结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(pattern = "yyyy-MM-dd HH:mm:ss", message = "请求参数endTime不合法")
    private String endCreateTime;

}
