package com.jiankangyouyi.cloud.basedata.model.dto.manager.food;

import com.jiankangyouyi.cloud.basedata.api.enums.food.FoodStatusValidEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.food.component.ClassifyQuery;
import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import java.util.List;

/**
 * 底层库管理-查询预包装食品列表
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class ManagerFoodPackageListDTO extends AbstractManagerRequestDTO {

    /**
     * 食物ID
     */
    @Length(max = 32, message = "请求参数foodId长度不合法")
    private String foodId;

    /**
     * 食物名称
     */
    @Length(max = 50, message = "请求参数foodName长度不合法")
    private String foodName;

    /**
     * 食物状态
     */
    @EnumHC(enumTypes = FoodStatusValidEnum.class, message = "请求参数foodStatus不合法")
    private List<String> foodStatus;
    /**
     * 审核状态 0、草稿 1、待审核 2、已审核 3、已驳回
     */
    private List<String> auditStatus;

    /**
     * 分类查询
     */
    private List<ClassifyQuery> classifyQueryList;

    /**
     * 开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateBeginTime不合法")
    private String updateBeginTime;

    /**
     * 结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC( message = "请求参数updateEndTime不合法")
    private String updateEndTime;

    /**
     * 排序方式，DESC 降序 、ASC 生序 默认为 DESC
     */
    private String sort;
    /**
     * 排序字段 默认为 updateTime 更新时间排序
     */
    private String sortField;
    /**
     * 条形码
     */
    private String barCode;

    /**
     * 创建人
     */
    private String createAccount;
    /**
     * 采纳人
     */
    private String adoptAccount;
    /**
     * 修改人
     */
    private String updateAccount;

    /**
     * 创建开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数createBeginTime不合法")
    private String createBeginTime;

    /**
     * 创建结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数createEndTime不合法")
    private String createEndTime;
    /**
     * 采纳开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数adoptBeginTime不合法")
    private String adoptBeginTime;

    /**
     * 采纳结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数adoptEndTime不合法")
    private String adoptEndTime;

}
