package com.jiankangyouyi.cloud.basedata.model.dto.manager.food;

import com.jiankangyouyi.cloud.basedata.api.enums.food.*;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.food.component.ClassifyQuery;
import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import java.util.List;

/**
 * 底层库管理-查询加工食品列表
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class ManagerFoodProcessListDTO extends AbstractManagerRequestDTO {

    /**
     * 食物ID
     */
    @Length(max = 32, message = "请求参数foodId长度不合法")
    private String foodId;

    /**
     * 食物名称，模糊匹配,非必输
     */
    @Length(max = 50, message = "请求参数foodName长度不合法")
    private String foodName;

    /**
     * 食物状态： 0 启用 1 禁用
     */
    @EnumHC(enumTypes = FoodStatusValidEnum.class, message = "请求参数foodStatus不合法")
    private List<String> foodStatus;
    /**
     * 审核状态 0、草稿 1、待审核 2、已审核 3、已驳回
     */
    private List<String> auditStatus;

    /**
     * 分类查询
     */
    private List<ClassifyQuery> classifyQueryList;

    /**
     * 是否参与配餐： true/false,非必输
     */
    private Boolean catering;

    /**
     * 配餐版本号：字典大类02，字典子类0229
     */
    private List<String> versions;

    /**
     * 推荐人群：字典大类02，字典子类0205,非必输
     */
    private List<String> recommendCrowds;

    /**
     * 禁忌人群：字典大类02，字典子类0205,非必输
     */
    private List<String> tabooCrowds;

    /**
     * 适合餐别 字典大类 02 字典子类 0226
     */
    private List<String> suitableForMeals;

    /**
     * 推荐人群 是否选择空选项
     */
    private Boolean recommendCrowdsSelectNull = false;

    /**
     * 禁忌人群 是否选择空选项
     */
    private Boolean tabooCrowdsSelectNull = false;

    /**
     * 富含营养素：字典大类02，字典子类0206,非必输
     */
    private List<String> highContentNutrients;

    /**
     * 低量营养素：字典大类02，字典子类0218,非必输
     */
    private List<String> lowContentNutrients;

    /**
     * 致敏原： 字典大类02，字典子类 0234
     */
    private List<String> allergen;
    /**
     * 升糖指数等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    @EnumHC(enumTypes = GiLevelEnum.class, message = "请求参数giLevel不合法")
    private List<String> giLevel;

    /**
     * 血糖负荷等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    @EnumHC(enumTypes = GlLevelEnum.class, message = "请求参数glLevel不合法")
    private List<String> glLevel;

    /**
     * 嘌呤等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    @EnumHC(enumTypes = PurineLevelEnum.class, message = "请求参数purineLevel不合法")
    private List<String> purineLevel;

    /**
     * 果糖含量等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    @EnumHC(enumTypes = FructoseLevelEnum.class, message = "请求参数fructoseLevel不合法")
    private List<String> fructoseLevel;

    /**
     * 性质：字典大类02，字典子类0215,非必输
     */
    private List<String> natures;

    /**
     * 膳食特点：字典大类02，字典子类0214,非必输
     */
    private List<String> foodSpecialties;

    /**
     * 烹饪特点：字典大类02，字典子类0214,非必输
     */
    private List<String> cookingSpecialties;
    /**
     * 口味 字典大类 02 字典子类 0201 , 非必输
     */
    private List<String> tastes;

    /**
     * 主料食物ID
     */
    private String majorFoodId;

    /**
     * 辅料食物ID
     */
    private String minorFoodId;

    /**
     * 修改开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateBeginTime不合法")
    private String updateBeginTime;

    /**
     * 修改结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数updateEndTime不合法")
    private String updateEndTime;

    /**
     * 排序方式，DESC 降序 、ASC 生序 默认为 DESC
     */
    private String sort;
    /**
     * 排序字段 默认为 updateTime 更新时间排序
     */
    private String sortField;

    /**
     * 创建人
     */
    private String createAccount;
    /**
     * 采纳人
     */
    private String adoptAccount;
    /**
     * 修改人
     */
    private String updateAccount;

    /**
     * 创建开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数createBeginTime不合法")
    private String createBeginTime;

    /**
     * 创建结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数createEndTime不合法")
    private String createEndTime;
    /**
     * 采纳开始时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数adoptBeginTime不合法")
    private String adoptBeginTime;

    /**
     * 采纳结束时间,yyyy-MM-dd HH:mm:ss
     */
    @DateValHC(message = "请求参数adoptEndTime不合法")
    private String adoptEndTime;


}
