package com.jiankangyouyi.cloud.basedata.model.dto.manager.food;

import com.jiankangyouyi.cloud.basedata.api.enums.food.FoodStatusValidEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.Max;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 底层库管理-食物快速查询
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class ManagerFoodQuickQueryDTO extends AbstractManagerRequestDTO {

    /**
     * 食物ID
     */
    @Length(max = 32, message = "请求参数foodId长度不合法")
    private String foodId;

    /**
     * 食物名称
     */
    @Length(max = 50, message = "请求参数foodName长度不合法")
    private String foodName;

    /**
     * 食物状态
     */
    @EnumHC(enumTypes = FoodStatusValidEnum.class, message = "请求参数foodStatus不合法")
    private List<String> foodStatus;
    /**
     * 审核状态 0、草稿 1、待审核 2、已审核 3、已驳回
     */
    private List<String> auditStatus;

    /**
     * 是否参与配餐： true/false
     */
    private Boolean catering;

    /**
     * 每页条数
     */
    @NotNull(message = "请求参数pageSize不能为空")
    @Max(value = 99, message = "请求参数pageSize不合法")
    private Integer pageSize;

}
