package com.jiankangyouyi.cloud.basedata.model.dto.manager.food;

import com.jiankangyouyi.cloud.basedata.api.enums.food.FoodPropertyEnum;
import com.jiankangyouyi.cloud.basedata.api.enums.food.FoodStatusValidEnum;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.food.component.ClassifyQuery;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.Max;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 底层库管理-食物名称模糊查询
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class ManagerQueryFuzzyByFoodNameDTO extends AbstractManagerRequestDTO {


    /**
     * 食物名称
     */
    @NotBlank(message = "请求参数foodName不能为空")
    @Length(max = 50, message = "请求参数foodName长度不合法")
    private String foodName;

    /**
     * 查询条数
     */
    @NotNull(message = "请求参数pageSize不能为空")
    @Max(value = 99, message = "请求参数pageSize不合法")
    private Integer pageSize;

    /**
     * 食物属性 ： 1 食材 2 加工食品 3 包装食品
     */
    @NotBlank(message = "请求参数foodProperty不能为空")
    @EnumHC(enumTypes = FoodPropertyEnum.class, message = "请求参数foodProperty不合法")
    private String foodProperty;

    /**
     * 食物状态： 1 启用 2 停用 3 草稿
     */
    @EnumHC(enumTypes = FoodStatusValidEnum.class, message = "请求参数foodStatus不合法")
    private List<String> foodStatus;

    /**
     * 分类查询
     */
    private List<ClassifyQuery> classifyQueryList;

}
