package com.jiankangyouyi.cloud.basedata.model.dto.manager.question;

import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * 问题列表查询条件请求数据
 *
 * @author fengxuanjun
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class QuestionListQueryDTO implements ValidDTO {

    private static final long serialVersionUID = 1L;

    /**
     * 分页请求信息
     */
    @Valid
    @NotNull(message ="请求参数page不能为空")
    private Page page;

    /**
     * 一级分类ID
     */
    @Size(max = 32, message = "请求参数classify1长度不合法")
    private String classify1;

    /**
     * 二级分裂ID
     */
    @Size(max = 32, message = "请求参数classify2长度不合法")
    private String classify2;

    /**
     * 题型
     * 1：单选题
     * 2：多选题
     * 3：性别题
     * 4：出生日期题
     * 5：单项数字题
     * 6：多项数字题
     * 7：BMI题
     */
    @Size(max = 2, message = "请求参数questionType长度不合法")
    private String questionType;

    /**
     * 相关疾病
     */
    private List<String> relatedDiseases;

    @Size(max = 50, message = "请求参数questionContent长度不合法")
    private String questionContent;

    /**
     * 开始时间-问题时间 yyyy-MM-dd HH:mm:ss
     */
    @Size(max = 19, message = "请求参数beginTime长度不合法")
    private String beginTime;

    /**
     * 开始时间-问题时间 yyyy-MM-dd HH:mm:ss
     */
    @Size(max = 19, message = "请求参数endTime长度不合法")
    private String endTime;



}
