package com.jiankangyouyi.cloud.basedata.model.dto.manager.question;

import com.jiankangyouyi.cloud.basedata.model.dto.manager.AbstractManagerRequestDTO;
import com.jiankangyouyi.cloud.basedata.model.dto.manager.question.component.MainQuestionParam;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * 问题保存请求数据
 *
 * @author fengxuanjun
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class QuestionSaveDTO extends AbstractManagerRequestDTO implements ValidDTO {

    private static final long serialVersionUID = 1L;

    /**
     * 问题ID，新增是为null,修改时必传
     */
    @Size(max = 32, message = "请求参数questionId长度不合法")
    private String questionId;

    /**
     * 一级分类Code
     */
    @Size(max = 32, message = "请求参数classify1长度不合法")
    @NotBlank(message = "请求参数classify1不能为空")
    private String classify1;

    /**
     * 二级分裂Code
     */
    @Size(max = 32, message = "请求参数classify2长度不合法")
    private String classify2;

    /**
     * 题型
     * 1：单选题
     * 2：多选题
     * 3：性别题
     * 4：出生日期题
     * 5：单项数字题
     * 6：多项数字题
     * 7：BMI题
     */
    @NotBlank(message = "请求参数questionType不能为空")
    @Size(max = 2, message = "请求参数questionType长度不合法")
    private String questionType;

    /**
     * 相关疾病
     */
    private List<String> relatedDiseases;


    /**
     * 问题对象
     */
    @Valid
    @NotNull(message ="请求参数mainQuestion不能为空")
    private MainQuestionParam mainQuestion;
}
