package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;


/**
 * 分类表
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "classifyId_-1",
                        def = "{'classifyId' : -1}"
                )
        }
)
@Document(collection = "v3.base.data.classify")
public class BaseDataClassifyDO extends BaseMongoEntity {

    private static final long serialVersionUID = 1L;

    /**
     * NOT NULL 分类业务ID
     */
    @Indexed(unique = true)
    private String classifyId;

    /**
     * NOT NULL
     * 业务属性
     * 1 食材库
     * 2 加工食品库
     * 3 包装食品库
     * 4 中医药材库
     * 5 问题库
     * 6 指标库
     */
    private String bizProperty;

    /**
     * NOT NULL 上级业务ID 一级默认为”0“
     */
    private String parentId;

    /**
     * NOT NULL 分类等级（例：一级：1，二级：2）
     */
    private Integer classifyLevel;

    /**
     * NOT NULL 分类名称
     */
    private String classifyName;

    /**
     * NOT NULL 分类编码（例：一级01，二级0101）
     */
    private String classifyCode;

    /**
     * NOT NULL 排序（默认9999）
     */
    private Integer rowOrder;

    /**
     * NULL 分类图片
     */
    private String imageUrl;

    /**
     * 分类简介
     */
    private String description;

    /**
     * 临床意义
     */
    private String meaning;

    public static final String FIELD_CLASSIFYID = "classifyId";
    public static final String FIELD_BIZPROOERTY = "bizProperty";
    public static final String FIELD_PARENTID = "parentId";
    public static final String FIELD_CLASSIFYLEVEL = "classifyLevel";
    public static final String FIELD_CLASSIFYNAME = "classifyName";
    public static final String FIELD_CLASSIFYCODE = "classifyCode";
    public static final String FIELD_ROWORDER = "rowOrder";
    public static final String FIELD_IMAGEURL = "imageUrl";
    public static final String FIELD_DESCRIPTION = "description";
    public static final String FIELD_MEANING = "meaning";

}
