package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.enums.export.ExportStatusEnum;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import com.jiankangyouyi.cloud.core.util.time.TimeUtils;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;


/**
 * 数据导出表
 *
 * @author yangsongbo
 */
@Data
@Builder
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "account_-1_createTime_-1_exportStatus_1",
                        def = "{ 'account': -1,'createTime': -1,'exportStatus': 1}"
                )
        }
)
@Document(collection = "v3.base.data.export")
public class BaseDataExportDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId _id;

    /**
     * 有效标识符
     */
    private String validStatus;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;


    /**
     * 导出ID，主键
     */
    @Indexed(unique = true)
    private String exportId;

    /**
     * 登录帐号
     */
    private String account;

    /**
     * 导出类型
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.enums.export.ExportTypeEnum}
     */
    private String exportType;

    /**
     * 导出位置
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.enums.export.ExportTypeEnum}
     */
    private String exportLocation;

    /**
     * 请求数据
     */
    private String requestJson;

    /**
     * 已处理数据量
     */
    private Integer processCount;

    /**
     * 总数据量
     */
    private Integer totalCount;

    /**
     * 下载链接
     */
    private String downloadUrl;

    /**
     * 耗时，毫秒
     */
    private Long costTime;

    /**
     * 导出状态
     * <p>
     * {@link ExportStatusEnum}
     */
    private String exportStatus;

    /**
     * 处理信息
     */
    private String message;


    public BaseDataExportDO() {
        Date curDate = TimeUtils.getCurrentDate();
        this.updateTime = curDate;
        this.createTime = curDate;
        this.createDate = TimeUtils.getStringOfCurrentDate(TimeUtils.FORMAT_STANDARD_DATE);
        this.validStatus = ValidStatusEnum.VALID.getCode();
    }

    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_EXPORTID = "exportId";
    public static final String FIELD_ACCOUNT = "account";
    public static final String FIELD_EXPORTTYPE = "exportType";
    public static final String FIELD_EXPORTLOCATION = "exportLocation";
    public static final String FIELD_REQUESTJSON = "requestJson";
    public static final String FIELD_PROCESSCOUNT = "processCount";
    public static final String FIELD_TOTALCOUNT = "totalCount";
    public static final String FIELD_DOWNLOADURL = "downloadUrl";
    public static final String FIELD_COSTTIME = "costTime";
    public static final String FIELD_EXPORTSTATUS = "exportStatus";
    public static final String FIELD_MESSAGE = "message";
}
