package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.model.entity.indicator.BodyIndicator;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;

/**
 * 身体指标库
 *
 * @author yangsongbo
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "indicator_-1_validStatus_1",
                        def = "{'indicator' : -1, 'validStatus' : 1}"
                )
        }
)
@Document(collection = "v3.body.indicator")
public class BodyIndicatorDO extends BodyIndicator {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;
    /**
     * 有效标识符,无效时使用UUID
     */
    private String validStatus;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NULL 备注
     */
    private String remark;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALID_STATUS = "validStatus";
    public static final String FIELD_UPDATE_TIME = "updateTime";
    public static final String FIELD_CREATE_TIME = "createTime";
    public static final String FIELD_REMARK = "remark";
    public static final String FIELD_INDICATOR = "indicator";
    public static final String FIELD_INDICATOR_NAME = "indicatorName";
    public static final String FIELD_UNIT = "unit";
    public static final String FIELD_RANGE_TYPE = "rangeType";
    public static final String FIELD_RANGE = "range";


}
