package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.basedata.api.model.vo.food.RecognitionFoodVO;
import com.jiankangyouyi.cloud.basedata.model.vo.external.AiFoodRecognitionResVO;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;
import java.util.List;

/**
 * 食物识别调用记录
 *
 * @author lvqidong
 * @date 2022/03/02 11:16
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_createDate_-1_createTime_-1_success_1",
                        def = "{'appId' : -1, 'createDate' : -1 , 'createTime' : -1,'success' : 1}"
                ),
                @CompoundIndex(
                        name = "aiRecognitionRes.sn_-1",
                        def = "{'aiRecognitionRes.sn' : -1}"
                ),
                @CompoundIndex(
                        name = "recognition_food_id_index",
                        def = "{'recognitionFoodList.foodId' : -1, 'recognitionFoodList.confidence' : -1 , 'appId' : -1, 'createDate' : -1 , 'createTime' : -1}"
                )
        }
)
@Document(collection = "v3.food.recognition.record")
public class FoodRecognitionRecordDO implements Serializable {

    /**
     * 主键
     */
    @Id
    private ObjectId _id;


    /**
     * 请求ID
     */
    @Indexed(unique = true)
    private String requestId;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 创建时间 yyyy-MM-dd HH:mm:ss
     */
    private String createTime;

    /**
     * 食物识别图片URL
     */
    private String imageUrl;

    /**
     * 返回结果数，取值范围[1,5],为空默认为1,结果按照置信度倒序排列
     */
    private Integer top;

    /**
     * 图片宽度
     */
    private Integer imageWidth;

    /**
     * 是否识别成功 recognitionFoodList不为空视为成功
     */
    private Boolean success;

    /**
     * AI算法返回结果
     */
    private AiFoodRecognitionResVO aiRecognitionRes;

    /**
     * 食物识别返回信息
     */
    private List<RecognitionFoodVO> recognitionFoodList;


}
