package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;


/**
 * 硬件表
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "hardwareId_-1_bizType_1_classify1-1_classify2-1",
                        def = "{'hardwareId_' : -1,'bizType':1,'classify1':1,'classify2':1}"
                )
        }
)
@Document(collection = "v3.base.data.hardware")
public class HardwareDO extends BaseMongoEntity {

    private static final long serialVersionUID = 1L;

    /**
     * NOT NULL 硬件业务ID
     */
    @Indexed(unique = true)
    private String hardwareId;

    /**
     * 一级分类
     */
    private String classify1;

    /**
     * 二级分类
     */
    private String classify2;

    /**
     * 品牌 对应字典code
     */
    private String brand;

    /**
     * 型号 对应字典code
     */
    private String model;

    /**
     * 通讯方式 对应字典code
     */
    private String communication;

    /**
     * 数据项 例：蓝牙、Wi-Fi...
     */
    private List<String> dataItems;

    /**
     * 业务类型 对应字典code
     */
    private String bizType;

    /**
     * 产品图片 七牛文件Key
     */
    private List<String> images;

    /**
     * 产品文档 七牛文件Key
     */
    private String documentKey;

    /**
     * 技术文档 接口文档链接地址
     */
    private String apiUrl;

    /**
     * 功能简述 文本，不超过500字
     */
    private String description;

    public static final String FIELD_HARDWAREID = "hardwareId";
    public static final String FIELD_CLASSIFY1 = "classify1";
    public static final String FIELD_CLASSIFY2 = "classify2";
    public static final String FIELD_BRAND = "brand";
    public static final String FIELD_MODEL = "model";
    public static final String FIELD_COMMUNICATION = "communication";
    public static final String FIELD_DATAITEMS = "dataItems";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_IMAGES = "images";
    public static final String FIELD_DOCUMENTKEY = "documentKey";
    public static final String FIELD_APIURL = "apiUrl";
    public static final String FIELD_DESCRIPTION = "description";

}
