package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.basedata.api.model.entity.indicator.IndicatorConstraint;
import com.jiankangyouyi.cloud.basedata.api.model.entity.indicator.IndicatorInfo;
import lombok.Builder;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import javax.validation.constraints.*;
import java.util.Date;
import java.util.List;

/**
 * 指标模型
 * 中文名+indicatorName
 */
@Data
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "indicatorName_-1_detectionMethod_1_validStatus_1",
                        def = "{'indicatorName' : -1, 'detectionMethod' : 1,'validStatus':1}"
                ),
                @CompoundIndex(
                        name = "indicatorId_1_detectionMethod_1",
                        def = "{'indicatorId' : 1, 'validStatus':1}"
                )
        }
)
@Document(collection = "v3.indicator")
public class IndicatorDO extends IndicatorInfo {
    private static final long serialVersionUID = 1L;
    @Id
    private ObjectId id;


    @Version
    private Long version;
    /**
     * 预留备注字段
     */
    private String remark;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_VERSION = "version";
    public static final String FIELD_REMARK = "remark";
    public static final String FIELD_INDICATORID = "indicatorId";
    public static final String FIELD_INDICATOR = "indicator";
    public static final String FIELD_INDICATORNAME = "indicatorName";
    public static final String FIELD_DETECTIONMETHOD = "detectionMethod";
    public static final String FIELD_UNIT = "unit";
    public static final String FIELD_CLASSIFY1 = "classify1";
    public static final String FIELD_CLASSIFY2 = "classify2";
    public static final String FIELD_CLASSIFY3 = "classify3";
    public static final String FIELD_DESCRIPTION = "description";
    public static final String FIELD_BEFOREATTENTIONS = "beforeAttentions";
    public static final String FIELD_ATTENTIONSING = "attentionsIng";
    public static final String FIELD_AFTERATTENTIONS = "afterAttentions";
    public static final String FIELD_RECOMMENDCHECKS = "recommendChecks";
    public static final String FIELD_UNRECOMMENDCHECKS = "unRecommendChecks";
    public static final String FIELD_INDICATORTYPE = "indicatorType";
    public static final String FIELD_INDICATORCONSTRAINTS = "indicatorConstraints";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";

//    @Builder(builderMethodName = "indicatorDOBuilder")
//    public IndicatorDO(String indicatorId, @NotEmpty(message = "indicator不可为空") @Size(max = 25, message = "indicator最大长度为25") String indicator, @NotEmpty(message = "indicatorName不可为空") @Size(max = 25, message = "indicatorName最大长度为25") String indicatorName, @NotEmpty(message = "detectionMethod不可为空") String detectionMethod, @NotEmpty(message = "unit不可为空") String unit, @NotEmpty(message = "classify1不可为空") String classify1, String classify2, String classify3, List<String> description, String judgingCriteria, List<String> beforeAttentions, List<String> attentionsIng, List<String> afterAttentions, List<String> recommendChecks, List<String> unRecommendChecks, @NotNull(message = "indicatorType不可为空") @Min(value = 1, message = "indicatorType最小为1") @Max(value = 3, message = "indicatorType最大为3") Integer indicatorType, List<IndicatorConstraint> indicatorConstraints, @NotEmpty(message = "validStatus不可为空") String validStatus, Date updateTime, Date createTime, ObjectId id, Long version, String remark) {
//        super(indicatorId, indicator, indicatorName, detectionMethod, unit, classify1, classify2, classify3, description, judgingCriteria, beforeAttentions, attentionsIng, afterAttentions, recommendChecks, unRecommendChecks, indicatorType, indicatorConstraints, validStatus, updateTime, createTime);
//        this.id = id;
//        this.version = version;
//        this.remark = remark;
//    }


}
