package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.basedata.api.model.entity.knowledge.KnowledgeQuestion;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;

/**
 * 知识竞赛问题表
 *
 * @author jingpeng
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "questionCategory_1",
                        def = "{'questionCategory' : 1, 'validStatus':1}"
                ),
                @CompoundIndex(
                        name = "questionId_-1",
                        def = "{'questionId' : -1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.knowledge.question")
public class KnowledgeQuestionDO extends BaseMongoEntity {

    /**
     * 问题id
     */
    private String questionId;

    /**
     * 问题分类
     */
    private String questionCategory;

    /**
     * 标签
     *
     */
    private List<String> tags;

    /**
     * 问题对象
     */
    private KnowledgeQuestion question;

    /**
     * 备注信息
     */
    private String remark;

    /**
     * 最后修改人
     */
    private String updateName;

    /**
     * 启用/禁用 1启用 2 禁用
     */
    private String useFlag;

    /**
     *选择提类型 1 单选 2 多选
     */
    private String optionFlag;

    public static final String FIELD_TAGS = "tags";
    public static final String FIELD_QUESTIONID = "questionId";
    public static final String FIELD_QUESTIONCATEGORY = "questionCategory";
    public static final String FIELD_QUESTION = "question";
    public static final String FIELD_REMARK = "remark";
    public static final String FIELD_QUESTIONCONTENTS = "question.questionContents";
    public static final String FIELD_SUPPLEMENTCONTENTS = "supplementContents";
    public static final String FIELD_IMAGEURLS = "imageUrls";
    public static final String FIELD_OPTIONS = "options";
    public static final String FIELD_OPTIONS_OPTIONCODE = "options.optionCode";
    public static final String FIELD_OPTIONS_OPTIONCONTENTS = "options.optionContents";
    public static final String FIELD_OPTIONS_SUPPLEMENTCONTENTS = "options.supplementContents";
    public static final String FIELD_OPTIONS_IMAGEURLS = "options.imageUrls";
    public static final String FIELD_OPTIONS_RIGHT = "options.right";
    public static final String FIELD_ANSWERINTERPRETS = "answerInterprets";

    public static final String FIELD_UPDATENAME = "updateName";
    public static final String FIELD_USER_FLAG = "useFlag";
    public static final String FIELD_OPTION_FLAG = "optionFlag";
}
