package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.model.component.CrowdType;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.PunchCardContent;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.RuleLimit;
import com.jiankangyouyi.cloud.core.validator.annotation.BigDecimalValHC;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 生活方式方案组合配置
 * @author ：wangyalei
 * @date ：2022/8/1 2:27 下午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Document(collection = "v3.ls.scheme.group.config")
public class LifeStyleSchemeGroupConfigDO {
    @Id
    private ObjectId id;
    /**
     * 有效状态 1、有效 2、无效
     */
    private String validStatus;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    /**
     * 操作人账号
     */
    private String optionAccount;
    /**
     * 方案ID
     */
    @Indexed(unique = true)
    private String schemeId;
    /**
     * 方案名称
     */
    private String schemeName;
    /**
     * 方案类别
     */
    private String schemeType;
    /**
     * 方案标题
     */
    private String schemeTitle;
    /**
     * 人群类型
     */
    private List<CrowdType> crowdTypes;
    /**
     * 哺乳状态
     *  1：哺乳期
     *  2：非哺乳期
     */
    private String lactationStatus;

    /**
     * 产后阶段天数 起
     */
    private Integer postpartumStartDays;

    /**
     * 产后阶段天数 止
     */
    private Integer postpartumEndDays;

    /**
     * 不良标签
     */
    private String unhealthyTag;
    /**
     * 规则限制 (规则组合)
     */
    private List<RuleLimit> ruleLimits;
    /**
     * 打卡内容
     */
    private PunchCardContent punchCardContent;
    /**
     * 启用状态 1、启用 2、禁用
     */
    private String openStatus;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_OPTIONACCOUNT = "optionAccount";
    public static final String FIELD_SCHEMEID = "schemeId";
    public static final String FIELD_SCHEMENAME = "schemeName";
    public static final String FIELD_SCHEMETYPE = "schemeType";
    public static final String FIELD_SCHEMETITLE = "schemeTitle";
    public static final String FIELD_CROWDTYPES = "crowdTypes";
    public static final String FIELD_CROWDTYPES_CROWD = "crowdTypes.crowd";
    public static final String FIELD_CROWDTYPES_RISKLEVELS = "crowdTypes.riskLevels";
    public static final String FIELD_UNHEALTHYTAG = "unhealthyTag";
    public static final String FIELD_RULELIMITS = "ruleLimits";
    public static final String FIELD_RULELIMITS_AGETYPERULECONDITION = "ruleLimits.ageTypeRuleCondition";
    public static final String FIELD_RULELIMITS_AGETYPERULECONDITION_STARTVALUE = "ruleLimits.ageTypeRuleCondition.startValue";
    public static final String FIELD_RULELIMITS_AGETYPERULECONDITION_INCLUDESTART = "ruleLimits.ageTypeRuleCondition.includeStart";
    public static final String FIELD_RULELIMITS_AGETYPERULECONDITION_ENDVALUE = "ruleLimits.ageTypeRuleCondition.endValue";
    public static final String FIELD_RULELIMITS_AGETYPERULECONDITION_INCLUDEEND = "ruleLimits.ageTypeRuleCondition.includeEnd";
    public static final String FIELD_RULELIMITS_GENDERTYPERULECONDITION = "ruleLimits.genderTypeRuleCondition";
    public static final String FIELD_RULELIMITS_GENDERTYPERULECONDITION_GENDER = "ruleLimits.genderTypeRuleCondition.gender";
    public static final String FIELD_RULELIMITS_WAISTTYPERULECONDITION = "ruleLimits.waistTypeRuleCondition";
    public static final String FIELD_RULELIMITS_WAISTTYPERULECONDITION_STARTVALUE = "ruleLimits.waistTypeRuleCondition.startValue";
    public static final String FIELD_RULELIMITS_WAISTTYPERULECONDITION_INCLUDESTART = "ruleLimits.waistTypeRuleCondition.includeStart";
    public static final String FIELD_RULELIMITS_WAISTTYPERULECONDITION_ENDVALUE = "ruleLimits.waistTypeRuleCondition.endValue";
    public static final String FIELD_RULELIMITS_WAISTTYPERULECONDITION_INCLUDEEND = "ruleLimits.waistTypeRuleCondition.includeEnd";
    public static final String FIELD_RULELIMITS_BMITYPERULECONDITION = "ruleLimits.bmiTypeRuleCondition";
    public static final String FIELD_RULELIMITS_BMITYPERULECONDITION_STARTVALUE = "ruleLimits.bmiTypeRuleCondition.startValue";
    public static final String FIELD_RULELIMITS_BMITYPERULECONDITION_INCLUDESTART = "ruleLimits.bmiTypeRuleCondition.includeStart";
    public static final String FIELD_RULELIMITS_BMITYPERULECONDITION_ENDVALUE = "ruleLimits.bmiTypeRuleCondition.endValue";
    public static final String FIELD_RULELIMITS_BMITYPERULECONDITION_INCLUDEEND = "ruleLimits.bmiTypeRuleCondition.includeEnd";
    public static final String FIELD_PUNCHCARDCONTENT = "punchCardContent";
    public static final String FIELD_PUNCHCARDCONTENT_FIRSTPHASECONTENTS = "punchCardContent.firstPhaseContents";
    public static final String FIELD_PUNCHCARDCONTENT_FIRSTPHASECONTENTS_TIPID = "punchCardContent.firstPhaseContents.tipId";
    public static final String FIELD_PUNCHCARDCONTENT_FIRSTPHASECONTENTS_TIPCONTENT = "punchCardContent.firstPhaseContents.tipContent";
    public static final String FIELD_PUNCHCARDCONTENT_SECONDPHASECONTENTS = "punchCardContent.secondPhaseContents";
    public static final String FIELD_PUNCHCARDCONTENT_SECONDPHASECONTENTS_TIPID = "punchCardContent.secondPhaseContents.tipId";
    public static final String FIELD_PUNCHCARDCONTENT_SECONDPHASECONTENTS_TIPCONTENT = "punchCardContent.secondPhaseContents.tipContent";
    public static final String FIELD_PUNCHCARDCONTENT_THIRDPHASECONTENTS = "punchCardContent.thirdPhaseContents";
    public static final String FIELD_PUNCHCARDCONTENT_THIRDPHASECONTENTS_TIPID = "punchCardContent.thirdPhaseContents.tipId";
    public static final String FIELD_PUNCHCARDCONTENT_THIRDPHASECONTENTS_TIPCONTENT = "punchCardContent.thirdPhaseContents.tipContent";
    public static final String FIELD_PUNCHCARDCONTENT_FOURTHPHASECONTENTS = "punchCardContent.fourthPhaseContents";
    public static final String FIELD_PUNCHCARDCONTENT_FOURTHPHASECONTENTS_TIPID = "punchCardContent.fourthPhaseContents.tipId";
    public static final String FIELD_PUNCHCARDCONTENT_FOURTHPHASECONTENTS_TIPCONTENT = "punchCardContent.fourthPhaseContents.tipContent";
    public static final String FIELD_OPENSTATUS = "openStatus";
    public static final String FIELD_LACTATIONSTATUS = "lactationStatus";
    public static final String FIELD_POSTPARTUMSTARTDAYS = "postpartumStartDays";
    public static final String FIELD_POSTPARTUMENDDAYS = "postpartumEndDays";
}
