package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.jiankangyouyi.cloud.basedata.model.vo.manager.literature.ServiceNodesVO;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;

/**
 * 参考文献
 *
 * @author lvqidong
 * @date 2022/02/09 10:34
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "literatureId_-1",
                        def = "{'literatureId' : -1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.literature")
@FieldNameConstants
public class LiteratureDO extends BaseMongoEntity {

    /**
     * 文献id
     */
    private String literatureId;

    /**
     * 文献标题内容
     */
    private String literatureContext;

    /**
     * 启用/禁用 1启用 2 禁用
     */
    private String useFlag;

    /**
     * 排序值
     */
    private Integer literatureSort;

    /**
     * 附件名称
     */
    private String attachmentName;

    /**
     * 附件地址
     */
    private String attachmentUrl;


    /**
     * 关联服务
     */
    private List<ServiceNodesVO> serviceNodes;

    public static final String FIELD_LITERATUREID = "literatureId";
    public static final String FIELD_LITERATURECONTEXT = "literatureContext";
    public static final String FIELD_USEFLAG = "useFlag";
    public static final String FIELD_LITERATURESORT = "literatureSort";
    public static final String FIELD_ATTACHMENTNAME = "attachmentName";
    public static final String FIELD_ATTACHMENTURL = "attachmentUrl";
    public static final String FIELD_SERVICENODES = "serviceNodes";
    public static final String FIELD_SERVICENODES_SERVICECODE = "serviceNodes.serviceCode";
    public static final String FIELD_SERVICENODES_SERVICENAME = "serviceNodes.serviceName";
    public static final String FIELD_SERVICENODES_CLASSIFYCODE = "serviceNodes.classifyCode";
    public static final String FIELD_SERVICENODES_CLASSIFYNAME = "serviceNodes.classifyName";



}
