package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.model.entity.questionnaire.QuestionnaireConfig;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.*;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Transient;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 问卷表
 *
 * @author yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "questionnaires_questionId_-1_validStatus_1",
                        def = "{'questionnaires.questionId' : -1, 'validStatus' : -1}"
                ),
                @CompoundIndex(
                        name = "questionnaire_bizType_-1_validStatus_1",
                        def = "{'bizType' : -1, 'validStatus' : -1}"
                ),
                @CompoundIndex(
                        name = "questionnaire_bizType_-1_version_-1",
                        def = "{'bizType' : -1,'version':-1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.questionnaire")
public class QuestionnaireDO implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 有效标识：{@link ValidStatusEnum}
     */
    @Builder.Default
    private String validStatus=ValidStatusEnum.VALID.getCode();

    /**
     * 问卷版本号
     */
    private String version;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @Builder.Default
    private Date updateTime=new Date();

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @Builder.Default
    private Date createTime=new Date();

    /**
     * NOT NULL 业务类型 见《开放平台业务类型设计.xlsx》）
     */
//    @Indexed(unique = true)
    private String bizType;

    /**
     * 问卷名称
     */
    private String questionnaireName;

    /**
     * NOT NULL 问卷配置
     */
    private List<QuestionnaireConfig> questionnaireConfigs;

    /**
     * NOT NULL 测评题数
     */
    private Integer questionCount;

    /**
     * NULL 备注
     */
    private String remark;

    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_QUESTIONNAIRENAME = "questionnaireName";
    public static final String FIELD_QUESTIONNAIRECONFIGS = "questionnaires";
    public static final String FIELD_QUESTIONNAIRECONFIGS_QUESTIONID = "questionnaireConfigs.questionId";
    public static final String FIELD_QUESTIONNAIRECONFIGS_QUESTIONCODE = "questionnaireConfigs.questionCode";
    public static final String FIELD_QUESTIONNAIRECONFIGS_QUESTIONTYPE = "questionnaireConfigs.questionType";
    public static final String FIELD_QUESTIONNAIRECONFIGS_QUESTIONCONFIG = "questionnaireConfigs.questionConfig";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS = "questionnaireConfigs.nextSelectors";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS_CONDITIONS = "questionnaireConfigs.nextSelectors.conditions";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS_CONDITIONS_QUESTIONCODE = "questionnaireConfigs.nextSelectors.conditions.questionCode";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS_CONDITIONS_CONDITIONVALUE = "questionnaireConfigs.nextSelectors.conditions.conditionValue";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS_NEXTQUESTIONCODE = "questionnaireConfigs.nextSelectors.nextQuestionCode";
    public static final String FIELD_QUESTIONNAIRECONFIGS_NEXTSELECTORS_SKIPQUESTIONCOUNT = "questionnaireConfigs.nextSelectors.skipQuestionCount";
    public static final String FIELD_QUESTIONCOUNT = "questionCount";
    public static final String FIELD_REMARK = "remark";
    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_VERSION = "version";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";

}
