package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.bol.secure.Encrypted;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 描述
 *
 * @author qxy
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "v3.question.answers")
public class QuestionsAndAnswersDO extends BaseMongoEntity {


    /**
     * 一级分类
     */
    private String classify1;
    /**
     * 二级分类
     */
    private String classify2;
    /**
     * 三级分类
     */
    private String classify3;
    /**
     * 问题
     */
    @Encrypted
    private String question;
    /**
     * 答案
     */
    @Encrypted
    private String answer;
    /**
     * 人群
     */
    private List<String> crowd;
    /**
     * 标签
     */
    private List<String> tags;
    /**
     * 食材   必填项，可添加多个标签，标签个数最多不能超过10个，每个标签限制1-10个字，不能含有空格、标点符号、特殊符号
     */
    private List<String> foodMaterial;
    /**
     * 参考文献
     */
    @Encrypted
    private List<String> reference;
    /**
     * 疾病
     */
    private List<String> disease;

    /**
     * 状态 1）草稿：所以角色均可删除
     *
     * （2）待审核：所有角色均可删除
     *
     * （3）已采纳：录入人员不可删除，审核人员可删除
     *
     * （4）已驳回：所有角色均可删除
     *
     *  （5） 已删除
     */
    private String status;
    /**
     * 用户id
     */
    private String accountId;
    /**
     * 操作这一刻的用户名称
     */
    private String accountName;

    /**
     * 驳回理由
     */
    private List<String> reasonsForRejection;

    /**
     * 采纳时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date adoptTime;
    /**
     * 采纳人
     */
    private String adoptAccountId;
    /**
     * 采纳人
     */
    private String adoptAccountName;

    public static final String FIELD_CLASSIFY1 = "classify1";
    public static final String FIELD_CLASSIFY2 = "classify2";
    public static final String FIELD_CLASSIFY3 = "classify3";
    public static final String FIELD_QUESTION = "question";
    public static final String FIELD_ANSWER = "answer";
    public static final String FIELD_CROWD = "crowd";
    public static final String FIELD_TAGS = "tags";
    public static final String FIELD_FOODMATERIAL= "foodMaterial";
    public static final String FIELD_REFERENCE = "reference";
    public static final String FIELD_DISEASE = "disease";
    public static final String FIELD_STATUS = "status";
    public static final String FIELD_ACCOUNTID = "accountId";
    public static final String FIELD_ACCOUNTNAME = "accountName";
    public static final String FIELD_REASONSFORREJECTION = "reasonsForRejection";
    public static final String FIELD_ADOPTTIME = "adoptTime";
    public static final String FIELD_ADOPTACCOUNTID = "adoptAccountId";
    public static final String FIELD_ADOPTACCOUNTNAME = "adoptAccountName";


}
