package com.jiankangyouyi.cloud.basedata.model.entity.mongo.disease;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.model.entity.disease.DiseaseInfo;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 疾病库-基础数据
 * @author ：fengxuanjun
 * @date 2021年12月15日
 *
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "diseaseId_-1_diseaseStatus_1",
                        def = "{'diseaseId' : -1, 'diseaseStatus' : -1}"
                ),
        }
)
@Document(collection = "v3.disease")
public class DiseaseDO extends DiseaseInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 疾病ID
     */
    @Indexed(unique = true)
    private String diseaseId;

    /**
     * 疾病状态
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.disease.DiseaseStatusEnum}
     */
    private String diseaseStatus;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 疾病名称
     */
    private String diseaseName;

    /**
     * 疾病别名
     */
    private List<String> diseaseAlias;

    /**
     * 疾病分类1
     */
    private String classify1;

    /**
     * 疾病分类2
     */
    private String classify2;

    /**
     * 疾病分类3
     */
    private String classify3;

    /**
     * 疾病分型
     */
    private List<String> partings;

    /**
     * 高发人群
     */
    private List<String> highRiskGroups;

    /**
     * 预后
     */
    private List<String> prognosis;

    /**
     * 疾病简介
     */
    private String about;

    /**
     * 并发症
     */
    private String complication;

    /**
     * 日常预防
     */
    private String prevention;

//    /**
//     * 病因症状
//     */
//    private DiseaseCause diseaseCause;
//
//    /**
//     * 疾病医学
//     */
//    private DiseaseMedical diseaseMedical;
//
//    /**
//     * 疾病饮食
//     */
//    private DiseaseDiet diseaseDiet;
//
//    /**
//     * 疾病运动
//     */
//    private DiseaseExercise diseaseExercise;
//
//    /**
//     * 疾病生活方式
//     */
//    private List<DiseaseLife> diseaseLife;
//
//    /**
//     * 疾病心理调节
//     */
//    private List<DiseaseMental> diseaseMental;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_DISEASE_ID = "diseaseId";
    public static final String FIELD_DISEASE_NAME = "diseaseName";
    public static final String FIELD_DISEASE_ALIAS = "diseaseAlias";
    public static final String FIELD_DISEASE_STATUS = "diseaseStatus";
    public static final String FIELD_CLASSIFY1 = "classify1";
    public static final String FIELD_CLASSIFY2 = "classify2";
    public static final String FIELD_CLASSIFY3 = "classify3";
    public static final String FIELD_PARTINGS = "partings";
    public static final String FIELD_HIGHRISKGROUPS = "highRiskGroups";
    public static final String FIELD_PROGNOSIS = "prognosis";
    public static final String FIELD_ABOUT = "about";
    public static final String FIELD_COMPLICATION = "complication";
    public static final String FIELD_PREVENTION = "prevention";

    public static final String FIELD_DISEASECAUSE = "diseaseCause";
    public static final String FIELD_DISEASEMEDICAL = "diseaseMedical";
    public static final String FIELD_DISEASEDIET = "diseaseDiet";
    public static final String FIELD_DISEASEEXERCISE = "diseaseExercise";
    public static final String FIELD_DISEASELIFE = "diseaseLife";
    public static final String FIELD_DISEASEMENTAL = "diseaseMental";

}
