package com.jiankangyouyi.cloud.basedata.model.entity.mongo.food;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;

/**
 * 食物基础表
 *
 * @author ：yangsongbo
 */
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "foodId_-1",
                        def = "{'foodId' : -1}",
                        unique = true
                )
        }
)
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "v4.food.basic")
public class FoodBasicDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId _id;

    /**
     * 食物ID，业务主键
     */
    private String foodId;

    /**
     * 食物属性（1、食材 2、加工食品 3、预包装食品 4、药材）
     */
    private String foodProperty;

    /**
     * 食物状态
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.food.FoodStatusEnum}
     */
    private String foodStatus;

    /**
     * 备注
     */
    private String remark;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_FOODID = "foodId";
    public static final String FIELD_FOODPROPERTY = "foodProperty";
    public static final String FIELD_FOODSTATUS = "foodStatus";
    public static final String FIELD_REMARK = "remark";

}
