package com.jiankangyouyi.cloud.basedata.model.entity.mongo.food;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.api.enums.food.AuditStatusValidEnum;
import com.jiankangyouyi.cloud.basedata.api.model.entity.foodv4.FoodPackage;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import java.util.Date;
import java.util.List;

/**
 * 预包装食品表
 *
 * @author ：yangsongbo
 */
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "foodId_-1",
                        def = "{'foodId' : -1}",
                        unique = true
                ),
                @CompoundIndex(
                        name = "foodName_1",
                        def = "{'foodName' : 1}"
                ),
                @CompoundIndex(
                        name = "updateTime_-1__id_-1",
                        def = "{'updateTime' : -1,'_id' : -1}"
                )
        }
)
@Data
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "v4.food.package")
public class FoodPackageDO extends FoodPackage {

    private static final long serialVersionUID = 1L;


    /**
     * 主键
     */
    @Id
    private ObjectId _id;

    /**
     * 更新时间
     */
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    /**
     * 创建时间 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 审核状态
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.food.AuditStatusValidEnum}
     */
    @NotBlank(message = "请求参数auditStatus不能为空")
    @EnumHC(enumTypes = AuditStatusValidEnum.class, message = "请求参数auditStatus不合法")
    private String auditStatus;

    /**
     * 操作人账号
     */
    private String operateAccount;

    /**
     * 创建者账号
     */
    private String createAccount;

    /**
     * 驳回理由
     */
    private List<String> reasonsForRejection;

    /**
     * 采纳时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date adoptTime;
    /**
     * 采纳人账号
     */
    private String adoptAccount;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_ADOPTTIME = "adoptTime";
    public static final String FIELD_AUDITSTATUS = "auditStatus";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_OPERATEACCOUNT = "operateAccount";
    public static final String FIELD_CREATE_ACCOUNT = "createAccount";
    public static final String FIELD_ADOPT_ACCOUNT = "adoptAccount";
}
