package com.jiankangyouyi.cloud.data.center.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 身体指标类型以及参考范围
 *
 * @author jingpeng
 */
@AllArgsConstructor
@Getter
public enum BodyIndicatorRefEnum {

    /**
     * 心率参数
     */
    HEART_RATE("heartRate", "60~70", 59d, 70d, 100d, 0d),

    /**
     * 血氧 bloodOxygen
     */
    BLOOD_OXYGEN("bloodOxygen", "≥95", 95d, 0d, 0d, 0d),

    /**
     * 体温
     */
    BODY_TEMPERATURE("bodyTemperature", "36~37.2", 36d, 37.2d, 38d, 40d),

    /**
     * hrv
     */
    HRV("hrv", "31~60", 30d, 60d, 100d, 0d),

    /**
     * 压力
     */
    STRESS("stress", "26~50", 25d, 50d, 75d, 0d),

    /**
     * 血压
     */
    BLOOD_PRESSURE("bloodPressure", "<120/<80", 120d, 80d, 139d, 89d),

    /**
     * 血糖
     */
    BLOOD_GLUCOSE("bloodGlucose", "4.5~11.1 ", 4.4, 11.1d, 0d, 0d),

    /**
     * 体重
     */
    WEIGHT("weight", "", 0d, 0d, 0d, 0d),

    /**
     * 腰围
     */
    WAIST("waist", "", 0d, 0d, 0d, 0d),

    /**
     * 血尿酸
     */
    BLOODURICACID("bloodUricAcid", "", 0d, 0d, 0d, 0d),

    /**
     * 血脂
     */
    BLOODLIPIDS("bloodLipids", "", 0d, 0d, 0d, 0d),
    /**
     * 骨密度
     */
    BONE("bmdTscore", "", 0d, 0d, 0d, 0d),
    /**
     * 肝内脂肪
     */
    LIVERFATCONTENT("liverFatContent", "", 0d, 0d, 0d, 0d),
    /**
     * 糖化血红蛋白
     */
    GHB("ghb", "", 0d, 0d, 0d, 0d),
    ;

    /**
     * 指标类型名称
     */
    private String indicator;

    /**
     * 参考值
     */
    private String referValue;
    /**
     * 标准值1
     */
    private Double stander1;
    /**
     * 标准值2
     */
    private Double stander2;
    /**
     * 标准值3
     */
    private Double stander3;
    /**
     * 标准值4
     */
    private Double stander4;


    public static BodyIndicatorRefEnum getEnum(String indicator) {
        BodyIndicatorRefEnum[] values = values();
        if (indicator == null) {
            return null;
        }
        for (BodyIndicatorRefEnum value : values) {
            if (indicator.equals(value.indicator)) {
                return value;
            }
        }
        return null;
    }
}