package com.jiankangyouyi.cloud.data.center.enums;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @author jingpeng
 * @description 疾病枚举
 * @date 2020/11/5
 */
@Getter
@AllArgsConstructor
public enum DiseaseTypeEnum {

    /**
     * 健康人群
     */
    HEALTH_PEOPLE("HEALTH_PEOPLE", "健康人群", null),

    /**
     * 2型糖尿病
     */
    DIABETES_TYPE_2("TYPE_2_DIABETES", "2型糖尿病", "1"),
    /**
     * 高血压
     */
    HIGH_BLOOD_PRESSURE("HYPERTENSION", "高血压", "4"),
    /**
     * 高血脂
     */
    HIGH_BLOOD_FAT("DYSLIPIDEMIA", "高血脂", "0"),
    /**
     * 冠心病
     */
    CORONARY_DISEASE("CORONARY_DISEASE", "冠心病", "6"),
    /**
     * 骨质疏松
     */
    OSTEOPOROSIS("OSTEOPOROSIS", "骨质疏松", "7"),
    /**
     * 痛风
     */
    GOUT("GOUT", "痛风", "3"),
    /**
     * 脂肪肝
     */
    FATTY_LIVER("FATTY_LIVER", "脂肪肝", "10"),
    /**
     * 脑卒中
     */
    APOPLEXY("STROKE", "脑卒中", "8"),
    /**
     * 高尿酸血症
     */
    HYPERURICEMIA("HYPERURICEMIA", "高尿酸血症", "15"),
    /**
     * 肥胖
     */
    OBESITY("OBESITY", "肥胖", "2"),

    /**
     * 免疫力
     */
    IMMUNE("HYPOIMMUNITY", "免疫力", "16"),
    /**
     * 肠道
     */
    INTESTINE("INTESTINAL_FUNCTION_DISORDER", "肠道", "12"),

    /**
     * 胃功能
     */
    GASTRIC("GASTRIC_FUNCTION_DISORDER", "胃功能", "13"),

    /**
     * 产后
     */
    CHILDBIRTH("CHILDBIRTH", "产后", "11"),
    /**
     * 营养素缺乏
     */
    LACK_NUTRIENT("LACK_NUTRIENT", "营养素缺乏", "14"),
    /**
     * 贫血
     */
    ANEMIA("ANEMIA", "贫血", null),
    /**
     * 慢性肾脏病
     */
    CHRONIC_RENAL_FAILURE("CHRONIC_RENAL_FAILURE", "慢性肾脏病", null),
    /**
     * 慢性胃炎
     */
    CHRONIC_GASTRITIS("CHRONIC_GASTRITIS", "慢性胃炎", null),
    /**
     * 肠炎
     */
    UC("UC", "肠炎", null),
    /**
     * 慢性肝炎
     */
    CHRONIC_HEPATITIS("CHRONIC_HEPATITIS", "慢性肝炎", null),

    ;

    private String code;

    private String message;

    /**
     * 关联到饮食推荐服务的疾病名称代码
     */
    private String externalCode;

    public static DiseaseTypeEnum parseCode(String code) {
        for (DiseaseTypeEnum enumItem : DiseaseTypeEnum.values()) {
            if (enumItem.code.equals(code)) {
                return enumItem;
            }
        }
        return null;
    }

    public static DiseaseTypeEnum parseExternalCode(String externalCode) {
        for (DiseaseTypeEnum enumItem : DiseaseTypeEnum.values()) {
            if (enumItem.externalCode.equals(externalCode)) {
                return enumItem;
            }
        }
        return null;
    }

    public static DiseaseTypeEnum parseMessage(String message) {
        if (StringUtils.isEmpty(message)) {
            return null;
        }
        for (DiseaseTypeEnum enumItem : DiseaseTypeEnum.values()) {
            if (enumItem.message.equals(message)) {
                return enumItem;
            }
        }
        return null;
    }

    /**
     * 根据疾病集合获取高等级疾病 20210408改后： 2型糖尿病>骨质疏松>肥胖>产后>脑卒中>痛风>冠心病>高血压>高血脂>脂肪肝>胃功能>肠道功能>营养缺乏/免疫力低下>健康人群
     * 
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum getHighLevelDiseaseType(List<DiseaseTypeEnum> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }

        if (diseaseTypeEnums.contains(DIABETES_TYPE_2)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(OBESITY)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(CHILDBIRTH)) {
            return CHILDBIRTH;
        } else if (diseaseTypeEnums.contains(APOPLEXY)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(GOUT)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(FATTY_LIVER)) {
            return FATTY_LIVER;
        } else if (diseaseTypeEnums.contains(GASTRIC)) {
            return GASTRIC;
        } else if (diseaseTypeEnums.contains(INTESTINE)) {
            return INTESTINE;
        } else if (diseaseTypeEnums.contains(LACK_NUTRIENT)) {
            return LACK_NUTRIENT;
        } else if (diseaseTypeEnums.contains(IMMUNE)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }

    /**
     * 根据疾病集合获取高等级疾病 顺序：痛风>脑卒中>冠心病>骨质疏松>2型糖尿病>产后>高血压>高血脂>脂肪肝>肥胖>胃功能>肠道功能>营养缺乏/免疫力低下>健康人群
     * 
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum getConsumeHighLevelDiseaseType(List<DiseaseTypeEnum> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }

        if (diseaseTypeEnums.contains(GOUT)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(APOPLEXY)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(DIABETES_TYPE_2)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(CHILDBIRTH)) {
            return CHILDBIRTH;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(FATTY_LIVER)) {
            return FATTY_LIVER;
        } else if (diseaseTypeEnums.contains(OBESITY)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(GASTRIC)) {
            return GASTRIC;
        } else if (diseaseTypeEnums.contains(INTESTINE)) {
            return INTESTINE;
        } else if (diseaseTypeEnums.contains(LACK_NUTRIENT)) {
            return LACK_NUTRIENT;
        } else if (diseaseTypeEnums.contains(IMMUNE)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }

    /**
     * 根据疾病集合获取高等级疾病，膳食结构，确诊疾病使用 顺序：肥胖>骨质疏松>2型糖尿病>>痛风>脑卒中>冠心病>产后>高血压>高血脂>脂肪肝>胃功能>肠道功能>营养缺乏/免疫力低下>健康人群
     * 
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum getDietBalanceConfirmHighLevelDiseaseType(List<DiseaseTypeEnum> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return LACK_NUTRIENT;
        }

        if (diseaseTypeEnums.contains(OBESITY)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(DIABETES_TYPE_2)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(GOUT)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(APOPLEXY)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(CHILDBIRTH)) {
            return CHILDBIRTH;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(GASTRIC)) {
            return GASTRIC;
        } else if (diseaseTypeEnums.contains(INTESTINE)) {
            return INTESTINE;
        } else if (diseaseTypeEnums.contains(LACK_NUTRIENT)) {
            return LACK_NUTRIENT;
        } else if (diseaseTypeEnums.contains(IMMUNE)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }

    /**
     * 根据疾病集合获取高等级疾病 内蒙古云盾 慢性肾脏病＞产后哺乳＞肥胖＞骨质疏松＞糖尿病＞痛风＞慢性肝炎＞脑卒中＞冠心病＞产后非哺乳＞高血压>高血脂>脂肪肝>慢性胃炎＞肠炎＞胃功能>肠道功能>营养缺乏＞贫血＞免疫力低下>健康人群
     * 
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum getYDHighLevelDiseaseType(List<DiseaseTypeEnum> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }

        if (diseaseTypeEnums.contains(CHRONIC_RENAL_FAILURE)) {
            return CHRONIC_RENAL_FAILURE;
        } else if (diseaseTypeEnums.contains(OBESITY)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(DIABETES_TYPE_2)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(GOUT)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(CHRONIC_HEPATITIS)) {
            return CHRONIC_HEPATITIS;
        } else if (diseaseTypeEnums.contains(APOPLEXY)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(FATTY_LIVER)) {
            return FATTY_LIVER;
        } else if (diseaseTypeEnums.contains(CHRONIC_GASTRITIS)) {
            return CHRONIC_GASTRITIS;
        } else if (diseaseTypeEnums.contains(UC)) {
            return UC;
        } else if (diseaseTypeEnums.contains(GASTRIC)) {
            return GASTRIC;
        } else if (diseaseTypeEnums.contains(INTESTINE)) {
            return INTESTINE;
        } else if (diseaseTypeEnums.contains(LACK_NUTRIENT)) {
            return LACK_NUTRIENT;
        } else if (diseaseTypeEnums.contains(ANEMIA)) {
            return ANEMIA;
        } else if (diseaseTypeEnums.contains(IMMUNE)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }

    /**
     * 根据疾病集合获取高等级疾病 内蒙古云盾 慢性肾脏病＞产后哺乳＞肥胖＞骨质疏松＞糖尿病＞痛风＞慢性肝炎＞脑卒中＞冠心病＞产后非哺乳＞高血压>高血脂>脂肪肝>慢性胃炎＞肠炎＞胃功能>肠道功能>营养缺乏＞贫血＞免疫力低下>健康人群
     * 
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum getYDConsumeHighLevelDiseaseType(List<DiseaseTypeEnum> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }
        if (diseaseTypeEnums.contains(APOPLEXY)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(CHRONIC_RENAL_FAILURE)) {
            return CHRONIC_RENAL_FAILURE;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(CHRONIC_GASTRITIS)) {
            return CHRONIC_GASTRITIS;
        } else if (diseaseTypeEnums.contains(UC)) {
            return UC;
        } else if (diseaseTypeEnums.contains(DIABETES_TYPE_2)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(HYPERURICEMIA)) {
            return HYPERURICEMIA;
        } else if (diseaseTypeEnums.contains(GOUT)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(FATTY_LIVER)) {
            return FATTY_LIVER;
        } else if (diseaseTypeEnums.contains(CHRONIC_HEPATITIS)) {
            return CHRONIC_HEPATITIS;
        } else if (diseaseTypeEnums.contains(OBESITY)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(ANEMIA)) {
            return ANEMIA;
        } else if (diseaseTypeEnums.contains(IMMUNE)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }

    public static DiseaseTypeEnum get160103HighLevelDiseaseType(List<String> diseaseTypeEnums,
        List<String> pastHistoryEnums) {
        if (CollectionUtils.isEmpty(pastHistoryEnums) && CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }
        if (CollectionUtils.isNotEmpty(pastHistoryEnums)) {
            return get160103HighLevelDiseaseType(pastHistoryEnums);
        } else {
            return get160103HighLevelDiseaseType(diseaseTypeEnums);
        }
    }

    /**
     * 根据疾病集合获取高等级疾病 内蒙古云盾 慢性肾脏病＞产后哺乳＞肥胖＞骨质疏松＞糖尿病＞痛风＞慢性肝炎＞脑卒中＞冠心病＞产后非哺乳＞高血压>高血脂>脂肪肝>慢性胃炎＞肠炎＞胃功能>肠道功能>营养缺乏＞贫血＞免疫力低下>健康人群
     *
     * @param diseaseTypeEnums 疾病集合
     * @return DiseaseTypeEnum 高优先级的疾病
     */
    public static DiseaseTypeEnum get160103HighLevelDiseaseType(List<String> diseaseTypeEnums) {
        if (CollectionUtils.isEmpty(diseaseTypeEnums)) {
            return HEALTH_PEOPLE;
        }
        if (diseaseTypeEnums.contains(CHRONIC_RENAL_FAILURE.code)) {
            return CHRONIC_RENAL_FAILURE;
        } else if (diseaseTypeEnums.contains(CHILDBIRTH.code)) {
            return CHILDBIRTH;
        } else if (diseaseTypeEnums.contains(OBESITY.code)) {
            return OBESITY;
        } else if (diseaseTypeEnums.contains(OSTEOPOROSIS.code)) {
            return OSTEOPOROSIS;
        } else if (diseaseTypeEnums.contains(DIABETES_TYPE_2.code)) {
            return DIABETES_TYPE_2;
        } else if (diseaseTypeEnums.contains(GOUT.code)) {
            return GOUT;
        } else if (diseaseTypeEnums.contains(CHRONIC_HEPATITIS.code)) {
            return CHRONIC_HEPATITIS;
        } else if (diseaseTypeEnums.contains(APOPLEXY.code)) {
            return APOPLEXY;
        } else if (diseaseTypeEnums.contains(CORONARY_DISEASE.code)) {
            return CORONARY_DISEASE;
        } else if (diseaseTypeEnums.contains(CHILDBIRTH.code)) {
            return CHILDBIRTH;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_PRESSURE.code)) {
            return HIGH_BLOOD_PRESSURE;
        } else if (diseaseTypeEnums.contains(HIGH_BLOOD_FAT.code)) {
            return HIGH_BLOOD_FAT;
        } else if (diseaseTypeEnums.contains(FATTY_LIVER.code)) {
            return FATTY_LIVER;
        } else if (diseaseTypeEnums.contains(CHRONIC_GASTRITIS.code)) {
            return CHRONIC_GASTRITIS;
        } else if (diseaseTypeEnums.contains(UC.code)) {
            return UC;
        } else if (diseaseTypeEnums.contains(GASTRIC.code)) {
            return GASTRIC;
        } else if (diseaseTypeEnums.contains(INTESTINE.code)) {
            return INTESTINE;
        } else if (diseaseTypeEnums.contains(LACK_NUTRIENT.code)) {
            return LACK_NUTRIENT;
        } else if (diseaseTypeEnums.contains(ANEMIA.code)) {
            return ANEMIA;
        } else if (diseaseTypeEnums.contains(IMMUNE.code)) {
            return IMMUNE;
        } else {
            return HEALTH_PEOPLE;
        }
    }
}
