package com.jiankangyouyi.cloud.data.center.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.ArrayList;
import java.util.List;

/**
 * @author jingpeng
 * @description 能量单位枚举
 * @date 2020/11/11
 */

@Getter
@AllArgsConstructor
public enum EnergyUnitEnum implements BaseEnum {

    /**
     * 千卡，卡路里，大卡
     */
    KCAL("KCAL", "卡路里", 4.186),


    KJ("KJ", "千焦", 1.0),


    ;
    private String code;

    private String message;

    /**
     * 换算值，基于 千焦
     */
    private double value;

    @Override
    public String code() {
        return this.code;
    }

    @Override
    public String message() {
        return this.message;
    }

    public static EnergyUnitEnum getEnum(String code) {
        EnergyUnitEnum[] values = values();
        if (code == null) {
            return null;
        }
        for (EnergyUnitEnum value : values) {
            if (code.equals(value.code)) {
                return value;
            }
        }
        return null;
    }

    public static EnergyUnitEnum getEnumByMessage(String message) {
        EnergyUnitEnum[] values = values();
        if (message == null) {
            return null;
        }
        for (EnergyUnitEnum value : values) {
            if (message.equals(value.message)) {
                return value;
            }
        }
        return null;
    }

    public static List<String> getAllUnitCode() {
        List<String> unitCodes = new ArrayList<>();
        for (EnergyUnitEnum energyUnitEnum : values()) {
            unitCodes.add(energyUnitEnum.code);
        }
        return unitCodes;
    }

}
