package com.jiankangyouyi.cloud.data.center.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.apache.commons.collections.CollectionUtils;

import java.util.List;

/**
 * 健康分析类型
 * @author ：wangyalei
 * @date ：Created in 2021/8/2 10:27 上午
 */
@Getter
@AllArgsConstructor
public enum HealthAnalysisTypeEnum {
    /**
     * 步数（热量、里程）
     */
    STEP("STEP", "步数（热量、里程）"),

    /**
     * HRV
     */
    HRV("HRV", "HRV"),

    /**
     * 睡眠
     */
    SLEEP("SLEEP", "睡眠"),

    /**
     * 血氧
     */
    BLOOD_OXYGEN("BLOOD_OXYGEN", "血氧"),

    /**
     * 血压
     */
    BLOOD_PRESSURE("BLOOD_PRESSURE", "血压"),
    /**
     * 体温
     */
    BODY_TEMPERATURE("BODY_TEMPERATURE", "体温"),
    /**
     * 心率
     */
    HEART_RATE("HEART_RATE", "心率"),
    /**
     * 压力
     */
    STRESS("STRESS", "压力"),
    /**
     * 总胆固醇
     */
    TOTAL_CHOLESTEROL("TOTAL_CHOLESTEROL", "总胆固醇"),
    /**
     * 血尿酸
     */
    BLOOD_URIC_ACID("BLOOD_URIC_ACID", "血尿酸"),
    /**
     * 血糖
     */
    BLOOD_GLUCOSE("BLOOD_GLUCOSE", "血糖"),
    /**
     * 基础代谢
     */
    BMR("BMR", "基础代谢"),
    /**
     * 身体年龄
     */
    BODY_AGE("BODY_AGE", "身体年龄"),
    /**
     * 体重
     */
    WEIGHT("WEIGHT", "体重"),
    /**
     * 身体指数
     */
    BMI("BMI", "身体指数"),
    /**
     * 体脂率
     */
    BFP("BFP", "体脂率"),
    /**
     * 皮下脂肪率
     */
    SUBCUTANEOUS_FAT("SUBCUTANEOUS_FAT", "皮下脂肪率"),
    /**
     * 内脏脂肪指数
     */
    VISCERAL_FAT("VISCERAL_FAT", "内脏脂肪指数"),
    /**
     * 水分率
     */
    WATER("WATER", "水分率"),
    /**
     * 肌肉率
     */
    MUSCLE("MUSCLE", "肌肉率"),
    /**
     * 蛋白质率
     */
    PROTEIN("PROTEIN", "蛋白质率"),
    /**
     * 骨量
     */
    BONE("BONE", "骨量"),

    /**
     * 热量
     */
    HEAT("HEAT","热量"),

    /**
     * 卡路里平衡
     *
     */
    CALORIE_BALANCE("CALORIE_BALANCE","卡路里平衡"),


    /**
     * 运动时长
     *
     */
    SPORT_TIMES("SPORT_TIMES","运动时长"),

    /**
     * 运动强度
     *
     */
    EXERCISE_INTENSITY("EXERCISE_INTENSITY","运动强度"),

    /**
     * 运动类型
     *
     */
    EXERCISE_TYPE("EXERCISE_TYPE","运动类型"),


    /**
     * 三餐能量比例
     *
     */
    MEAL_ENERGY_RATIO("MEAL_ENERGY_RATIO","三餐能量"),

    /**
     * 膳食结构分析
     */
    DIETARY_STRUCTURE_ANALYSIS("DIETARY_STRUCTURE_ANALYSIS","膳食结构分析"),

    /**
     * 三大营养素功能
     */
    THREE_NUTRIENT_UNCTIONS("THREE_NUTRIENT_UNCTIONS","三大营养素功能"),

    /**
     * 关键营养素摄入
     */
    KEY_NUTRIENTS_INTAKE("KEY_NUTRIENTS_INTAKE","关键营养素摄入"),






    ;
    private final String type;

    private final String message;

    public String type() {
        return this.type;
    }

    public String message() {
        return this.message;
    }

    public static HealthAnalysisTypeEnum getEnum(String type) {
        HealthAnalysisTypeEnum[] values = values();
        if (type == null) {
            return null;
        }
        for (HealthAnalysisTypeEnum value : values) {
            if (type.equals(value.type)) {
                return value;
            }
        }
        return null;
    }

    //
    /**
     * 是否有 首页的全新
     * @param type 1 善食均衡 2 运动规律 3 养生好习惯 4 一夜好眠 5 指标分析 6 心里平衡
     * @return
     */
    public static Boolean getEnumPermission(List<String> types,String type) {
        HealthAnalysisTypeEnum[] values = values();
        if(CollectionUtils.isEmpty(types)){
            return false;
        }
        if (type == null) {
            return false;
        }
        //善食均衡
        if(type.equals("1")){
            if (types.contains(CALORIE_BALANCE.getType())
                    || types.contains(MEAL_ENERGY_RATIO.getType())
                    || types.contains(DIETARY_STRUCTURE_ANALYSIS.getType())
                    || types.contains(THREE_NUTRIENT_UNCTIONS.getType())
                    || types.contains(KEY_NUTRIENTS_INTAKE.getType())) {
              return true;
            }
        }
        //运动规律
        if(type.equals("2")){
            if (types.contains(CALORIE_BALANCE.getType())
                    || types.contains(SPORT_TIMES.getType())
                    || types.contains(EXERCISE_INTENSITY.getType())
                    || types.contains(EXERCISE_TYPE.getType())
                    || types.contains(STEP.getType())) {
                return true;
            }
        }
        //养生好习惯
        //4 一夜好眠
        if(type.equals("4")){
            if (types.contains(SLEEP.getType())) {
                return true;
            }
        }
        //5 指标分析检测指标-心率、检测指标-体温、检测指标-血氧、检测指标-HRV、检测指标-血压、
        // 检测指标-血糖、检测指标-血尿酸、检测指标-总胆固醇、检测指标-体重、检测指标-体脂率、检测指标-BMI、检测指标-身体年龄、
        // 检测指标-基础代谢、检测指标-骨量/骨骼率、检测指标-内脏脂肪指数、检测指标-皮下脂肪、检测指标-蛋白量/蛋白率、检测指标-脂肪量/脂肪率、检测指标-肌肉量/肌肉率、检测指标-水分率
        if(type.equals("5")){
            if (types.contains(HEART_RATE.getType())
                    || types.contains(BODY_TEMPERATURE.getType())
                    || types.contains(BLOOD_OXYGEN.getType())
                    || types.contains(HRV.getType())
                    || types.contains(BLOOD_PRESSURE.getType())
                    || types.contains(BLOOD_GLUCOSE.getType())
                    || types.contains(BLOOD_URIC_ACID.getType())
                    || types.contains(TOTAL_CHOLESTEROL.getType())
                    || types.contains(WEIGHT.getType())
                    || types.contains(BFP.getType())
                    || types.contains(BMI.getType())
                    || types.contains(BODY_AGE.getType())
                    || types.contains(BMR.getType())
                    || types.contains(BONE.getType())
                    || types.contains(VISCERAL_FAT.getType())
                    || types.contains(SUBCUTANEOUS_FAT.getType())
                    || types.contains(MUSCLE.getType())
                    || types.contains(PROTEIN.getType())
                    || types.contains(WATER.getType())) {
                return true;
            }
        }
        //6 心里平衡
        if(type.equals("6")){
            if (types.contains(STRESS.type)) {
                return true;
            }
        }
        return false;
    }

}
