package com.jiankangyouyi.cloud.data.center.enums;

import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;


/**
 * Redis Key Enum
 *
 * @author yangsongbo
 */
@AllArgsConstructor
public enum RedisKeyEnum {


    /**
     * 后台管理loginToken 后缀为UUID
     */
    STRING_MANAGER_LOGIN_TOKEN("string_data_center_manager_login_token", "后台管理loginToken 后缀为UUID"),


    /**
     * <p>公共参数缓存，后缀为paramGroup、paramKey</p>
     */
    STRING_PARAM_VALUE("string_param_value", "公共参数缓存，后缀为paramGroup、paramKey"),

    /**
     * <p>公共参数缓存，后缀为paramGroup</p>
     */
    LIST_PARAM_VALUE("list_param_value", "公共参数缓存，后缀为paramGroup"),


    /**
     * 导出后台管理数据导出间隔时间，后缀为account，exportType
     */
    STRING_MANAGER_EXPORT_DATA_INTERVAL(
            "string_data_center_manager_export_data_interval",
            "导出后台管理数据导出间隔时间，后缀为account，exportType"),


    /**
     * 接口调用数，后缀为appId + interfaceUrl + 时间（时间为空则默认年，否则有月yyyyMM 日yyyyMMdd）
     */
    STRING_INTERFACE_INVOKE_COUNT("string_interface_invoke_count", "接口调用数"),

    /**
     * <p>用户给缓存，后缀为appId、userId</p>
     */
    STRING_DATA_CENTER_APP_USER_CACHE("string_data_center_app_user_cache", "用户缓存，后缀为appId、userId"),

    /**
     * 字典缓存 后缀为dictType,dictSubType
     */
    LIST_BASE_DICT("list_base_dict", "字典数据缓存，后缀为dictType,dictSubType"),

    /**
     * 应用信息表developer.app.info2缓存Key
     */
    STRING_DEVELOPER_APP("string_developer_app_health_ai", "应用信息表developer.app.info2缓存Key,后缀为develpoerId"),
    ;

    /**
     * redis key
     */
    private String key;

    /**
     * 描述
     */
    private String describe;


    public String getDescribe() {
        return this.describe;
    }

    /**
     * 获取key
     *
     * @param keySuffixes key后缀
     * @return redis key
     */
    public String getKey(String... keySuffixes) {
        StringBuilder builder = new StringBuilder(this.key);

        if (ArrayUtils.isNotEmpty(keySuffixes)) {
            for (String keySuffix : keySuffixes) {
                if (StringUtils.isNotBlank(keySuffix)) {
                    builder.append("_").append(keySuffix);
                }
            }
        }
        return builder.toString();
    }


}



