package com.jiankangyouyi.cloud.data.center.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 处理码定义
 *
 * @author wangshuang
 */
@Getter
@AllArgsConstructor
public enum ResultCodeEnum implements BaseEnum {

    /**
     * 成功
     */
    SUCCESS("0", "成功"),

    /**
     * 登出
     */
    LOGOUT("LOGOUT", "登出"),

    /**
     * 解析HTTP BODY失败
     */
    DATA0001("DATA0001", "解析HTTP BODY失败"),

    /**
     * HTTP BODY参数错误
     */
    DATA0002("DATA0002", "HTTP BODY参数错误"),

    /**
     * 未知的HTTP请求来源
     */
    DATA0003("DATA0003", "未知的HTTP请求来源"),

    /**
     * HTTP请求来源非法
     */
    DATA0004("DATA0004", "HTTP请求来源非法"),

    /**
     * 解析心电数据失败
     */
    DATA0005("DATA0005", "解析心电数据失败"),

    /**
     * 操作过于频繁，请稍后再试
     */
    DATA0006("DATA0006", "操作过于频繁，请稍后再试"),

    /**
     * 数据为空，无法导出
     */
    DATA0007("DATA0007", "数据为空，无法导出"),

    /**
     * 导出数据失败,请稍后再试
     */
    DATA0008("DATA0008", "导出数据失败,请稍后再试"),

    /**
     * 用户信息为空
     */
    DATA0009("DATA0009", "用户信息为空，请先完善用户信息"),

    /**
     * 用户信息为空
     */
    DATA0010("DATA0010", "音频数据识别失败"),

    /**
     * 无效的授权码
     */
    DATA0011("DATA0011", "无效的授权码"),

    /**
     * 手机号已经绑定
     */
    DATA0012("DATA0012", "手机号已经绑定"),

    /**
     * 授权码已绑定
     */
    DATA0013("DATA0013", "授权码已绑定"),

    /**
     * 授权码失效
     */
    DATA0014("DATA0014", "授权码失效"),

    /**
     * 查询数据失败，请稍后再试
     */
    DATA0015("DATA0015", "查询数据失败，请稍后再试"),

    /**
     * 短信模板不存在
     */
    DATA0016("DATA0016", "短信模板不存在"),

    /**
     * 验证码发送失败
     */
    DATA0017("DATA0017", "验证码发送失败"),

    /**
     * 验证码不能为空
     */
    DATA0018("DATA0018", "验证码不能为空"),

    /**
     * 验证码校验异常，请稍后再试
     */
    DATA0019("DATA0019", "验证码校验异常，请稍后再试"),

    /**
     * 验证码不正确
     */
    DATA0020("DATA0020", "验证码不正确"),

    /**
     * 验证码已失效
     */
    DATA0021("DATA0021", "验证码已失效"),

    /**
     * 验证码不能为空
     */
    DATA0022("DATA0022", "手机号不能为空不能为空"),

    /**
     * 和缓医生系统故障，请联系工作人员，稍后再试
     */
    DATA0023("DATA0023", "和缓医生系统故障，请联系工作人员，稍后再试"),

    /**
     * 和缓医生系统故障，请联系工作人员，稍后再试
     */
    DATA0024("DATA0024", "数据入库异常"),

    /**
     * 用户--目标体重不存在
     */
    DATA0025("DATA0025", "用户--目标体重不存在"),
    /**
     * 权限不足
     */
    DATA0027("DATA0027", "权限不足"),

    /**
     * 测评报告不存在
     */
    DATA0026("DATA0026", "测评报告不存在"),

    /**
     * 保存益云数字健康管理平台配置失败
     */
    DATA0028("DATA0028", "保存管理平台配置失败"),
    /**
     * 益云数字健康管理平台配置信息不存在
     */
    DATA0029("DATA0029", "账号配置信息不存在"),

    /**
     * 益云数字健康管理平台配置信息不存在
     */
    DATA0030("DATA0030", "解绑设备失败，稍后再试"),

    /**
     * 权益不存在
     */
    EQUITY_404("EQUITY_404","权益不存在"),

    /**
     * 权益包不存在
     */
    EQUITY_PACKAGE_404("EQUITY_PACKAGE_404","权益包不存在"),

    /**
     * 权益包已被项目关联
     */
    EQUITY_PACKAGE_DONOT_EDIT("EQUITY_PACKAGE_DONOT_EDIT","权益包已被项目关联不可进行修改/删除"),

    /**
     * 激活码不存在
     */
    CDK_404("CDK_404","激活码不存在"),
    /**
     * 激活码未绑定
     */
    CDK_NOBIND("CDK_NOBIND","激活码未绑定"),
    /**
     * 激活码下无权益信息
     */
    CDK_NOHAS_EQUITY("CDK_NOHAS_EQUITY","激活码下无权益信息"),

    /**
     * 保存失败
     */
    DATA0031("DATA0031", "保存失败"),

    /**
     * 个人信息为空
     */
    DATA0032("DATA0032", "无效的用户信息"),

    /**
     * 个人信息为空
     */
    DATA0033("DATA0033", "请完善用户信息，身高，体重，性别为必填信息"),

    /**
     * 操作的数据不存在
     */
    DATA0034("DATA0034", "操作的数据不存在"),
    /**
     * 处理失败
     */
    DATA0035("DATA0035", "处理失败");


    private final String code;
    private final String message;

    @Override
    public String code() {
        return code;
    }

    @Override
    public String message() {
        return message;
    }

    public static ResultCodeEnum getEnum(String code) {
        ResultCodeEnum[] values = values();
        if (code == null) {
            return null;
        }
        for (ResultCodeEnum value : values) {
            if (code.equals(value.code)) {
                return value;
            }
        }
        return null;
    }
}
