package com.jiankangyouyi.cloud.data.center.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * Result Code枚举
 *
 * @author yangsongbo
 */
@Getter
@AllArgsConstructor
public enum ResultTokenEnum implements BaseEnum {

    /**
     * 处理成功
     */
    OK("0", "处理成功"),

    /**
     * 应用信息不存在
     */
    APP_NOT_FOUND("1104", "应用信息不存在"),

    /**
     * apiKey不正确
     */
    APIKEY_IS_WRONG("1105", "apiKey不正确"),

    /**
     * 应用信息中的apiKey不存在
     */
    APIKEY_FOR_APP_NOT_FOUND("1106", "应用信息中的apiKey不存在"),

    /**
     * 授权码已停用
     */
    LICENSE_HAS_BEEN_DISABLED("1108", "授权码已停用"),

    /**
     * 授权码已过期
     */
    LICENSE_IS_EXPIRED("1109", "授权码已过期"),

    /**
     * 授权码不存在
     */
    LICENSE_NOT_FOUND("1110", "授权码不存在"),

    /**
     * 授权码已被使用
     */
    LICENSE_HAS_BEEN_USED("1111", "授权码已被使用"),

    /**
     * 授权码绑定失败
     */
    LICENSE_BINDING_FAILED("1112", "授权码绑定失败"),

    /**
     * IP频繁变动预警
     */
    IP_FREQUENT_CHANGE_WARING("1113", "IP频繁变动预警"),

    /**
     * 生成HLS key失败
     */
    HLS_KEY_GENERATE_FAIL("1115", "生成HLS key失败"),

    /**
     * 微信授权渠道chanType未配置
     */
    WECHAT_CHAN_TYPE_NOT_FOUND("1116", "微信授权渠道chanType未配置"),

    /**
     * 重定向失败
     */
    RESPONSE_REDIRECT_ERROR("1117", "重定向失败"),

    /**
     * 获取网页授权access_token失败
     */
    GET_WECHAT_WEB_ACCESS_TOKEN_FAIL("1118", "获取网页授权access_token失败"),

    /**
     * 获取微信小程序session_key失败
     */
    GET_WECHAT_APP_SESSION_KEY_FAIL("1119", "获取微信小程序session_key失败"),

    ;

    /**
     * 处理码
     */
    private final String code;

    /**
     * 处理信息
     */
    private final String comment;


    @Override
    public String code() {
        return code;
    }

    @Override
    public String message() {
        return comment;
    }
}
