package com.jiankangyouyi.cloud.data.center.enums;

import com.jiankangyouyi.cloud.data.center.api.enums.MealTypeEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @author jingpeng
 * @description 三餐分析对应的能量占比与话术
 * @date 2020/11/9
 */
@Getter
@AllArgsConstructor
public enum ThreeMealEnergyRateRangeEnum {


    /**
     * 早餐偏低
     */
    BREAKFAST_LOW("早餐+早加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
        "吃的有点少，早餐作为一天营养的开始，健康饮食非常重要，绝对不能忽略，开始关注自己的早餐吧。"),
    /**
     * 早餐合适
     */
    BREAKFAST_SUITABLE("早餐+早加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
        "很不错，继续保持合理摄入。"),
    /**
     * 早餐偏高
     */
    BREAKFAST_HIGH("早餐+早加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
        "吃多了，早餐摄入过多可能会影响午餐的食用，科学分配早餐热量将更利于健康的维护哟。"),
    /**
     * 午餐偏低
     */
    LUNCH_LOW("午餐+午加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.34, 0.4,
        "吃的有点少，午餐是全天重要的营养来源，有助于恢复精力，保持新陈代谢活跃，要保证摄入量哟。"),
    /**
     * 午餐合适
     */
    LUNCH_SUITABLE("午餐+午加餐", AnalysisStatusEnum.SUITABLE.code(), 0.35, 0.45, 0.4, "很不错，继续保持合理摄入。"),
    /**
     * 午餐偏高
     */
    LUNCH_HIGH("午餐+午加餐", AnalysisStatusEnum.HIGHER.code(), 0.46, 1.0, 0.4,
        "吃多了，午餐摄入过多可能会影响晚餐的食用，科学分配午餐热量将更利于健康的维护哟。"),
    /**
     * 晚餐偏低
     */
    SUPPER_LOW("晚餐+晚加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
        "吃的有点少，晚餐过少或不吃，会影响睡眠，还会影响胃肠功能健康，规律饮食更有助于健康哟。"),
    /**
     * 晚餐合适
     */
    SUPPER_SUITABLE("晚餐+晚加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
        "很不错，继续保持合理摄入。"),
    /**
     * 晚餐偏高
     */
    SUPPER_HIGH("晚餐+晚加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
        "吃多了，晚餐摄入过多，能量消耗不掉，非常容易造成肥胖，会增加心脑血管疾病的患病风险，要适量降低晚餐的摄入哟。"),

    //慢性肾脏病
    /**
     * 早餐偏低
     */
    CHRONIC_RENAL_FAILURE_BREAKFAST_LOW("早餐+早加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
            "吃的有点少，早餐作为一天营养的开始，健康饮食非常重要，绝对不能忽略，开始关注自己的早餐吧。"),
    /**
     * 早餐合适
     */
    CHRONIC_RENAL_FAILURE_BREAKFAST_SUITABLE("早餐+早加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
            "很不错，继续保持合理摄入。"),
    /**
     * 早餐偏高
     */
    CHRONIC_RENAL_FAILURE_BREAKFAST_HIGH("早餐+早加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
            "吃多了，早餐摄入过多可能会影响午餐的食用，科学分配早餐热量将更利于健康的维护哟。"),
    /**
     * 午餐偏低
     */
    CHRONIC_RENAL_FAILURE_LUNCH_LOW("午餐+午加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.34, 0.4,
            "吃的有点少，午餐是全天重要的营养来源，有助于恢复精力，保持新陈代谢活跃，要保证摄入量哟。"),
    /**
     * 午餐合适
     */
    CHRONIC_RENAL_FAILURE_LUNCH_SUITABLE("午餐+午加餐", AnalysisStatusEnum.SUITABLE.code(), 0.35, 0.45, 0.4, "很不错，继续保持合理摄入。"),
    /**
     * 午餐偏高
     */
    CHRONIC_RENAL_FAILURE_LUNCH_HIGH("午餐+午加餐", AnalysisStatusEnum.HIGHER.code(), 0.46, 1.0, 0.4,
            "吃多了，午餐摄入过多可能会影响晚餐的食用，科学分配午餐热量将更利于健康的维护哟。"),
    /**
     * 晚餐偏低
     */
    CHRONIC_RENAL_FAILURE_SUPPER_LOW("晚餐+晚加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
            "吃的有点少，晚餐过少或不吃，会影响睡眠，还会影响胃肠功能健康，规律饮食更有助于健康哟。"),
    /**
     * 晚餐合适
     */
    CHRONIC_RENAL_FAILURE_SUPPER_SUITABLE("晚餐+晚加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
            "很不错，继续保持合理摄入。"),
    /**
     * 晚餐偏高
     */
    CHRONIC_RENAL_FAILURE_SUPPER_HIGH("晚餐+晚加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
            "吃多了，晚餐摄入过多，能量消耗不掉，非常容易造成肥胖，会增加心脑血管疾病的患病风险，要适量降低晚餐的摄入哟。"),


    //其他四中病 贫血  慢性胃炎 肠炎 慢性肝炎
    /**
     * 早餐偏低
     */
    OTHER_BREAKFAST_LOW("早餐+早加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
            "吃的有点少，早餐作为一天营养的开始，健康饮食非常重要，绝对不能忽略，开始关注自己的早餐吧。"),
    /**
     * 早餐合适
     */
    OTHER_BREAKFAST_SUITABLE("早餐+早加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
            "很不错，继续保持合理摄入。"),
    /**
     * 早餐偏高
     */
    OTHER_BREAKFAST_HIGH("早餐+早加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
            "吃多了，早餐摄入过多可能会影响午餐的食用，科学分配早餐热量将更利于健康的维护哟。"),
    /**
     * 午餐偏低
     */
    OTHER_LUNCH_LOW("午餐+午加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.34, 0.4,
            "吃的有点少，午餐是全天重要的营养来源，有助于恢复精力，保持新陈代谢活跃，要保证摄入量哟。"),
    /**
     * 午餐合适
     */
    OTHER_LUNCH_SUITABLE("午餐+午加餐", AnalysisStatusEnum.SUITABLE.code(), 0.35, 0.45, 0.4, "很不错，继续保持合理摄入。"),
    /**
     * 午餐偏高
     */
    OTHER_LUNCH_HIGH("午餐+午加餐", AnalysisStatusEnum.HIGHER.code(), 0.46, 1.0, 0.4,
            "吃多了，午餐摄入过多可能会影响晚餐的食用，科学分配午餐热量将更利于健康的维护哟。"),
    /**
     * 晚餐偏低
     */
    OTHER_SUPPER_LOW("晚餐+晚加餐", AnalysisStatusEnum.LOWER.code(), 0, 0.24, 0.3,
            "吃的有点少，晚餐过少或不吃，会影响睡眠，还会影响胃肠功能健康，规律饮食更有助于健康哟。"),
    /**
     * 晚餐合适
     */
    OTHER_SUPPER_SUITABLE("晚餐+晚加餐", AnalysisStatusEnum.SUITABLE.code(), 0.25, 0.35, 0.3,
            "很不错，继续保持合理摄入。"),
    /**
     * 晚餐偏高
     */
    OTHER_SUPPER_HIGH("晚餐+晚加餐", AnalysisStatusEnum.HIGHER.code(), 0.36, 1.0, 0.3,
            "吃多了，晚餐摄入过多，能量消耗不掉，非常容易造成肥胖，会增加心脑血管疾病的患病风险，要适量降低晚餐的摄入哟。"),


    ;
    /**
     * 餐别
     */
    private String mealType;

    /**
     * 描述
     */
    private String status;

    /**
     * 开始比例
     */
    private double startRate;

    /**
     * 结束比例
     */
    private double endRate;

    /**
     * 标准比例
     */
    private double standardRate;

    /**
     * 话术
     */
    private String describe;

    /**
     * 根据餐别获取餐别出合适的摄入范围
     *
     * @param mealTypeEnum 餐别
     * @return ThreeMealEnergyRateRangeEnum
     */
    public static ThreeMealEnergyRateRangeEnum getThreeMealSuitableRateEnum(
        MealTypeEnum mealTypeEnum) {
        switch (mealTypeEnum) {
            case BREAKFAST:
                return BREAKFAST_SUITABLE;
            case LUNCH:
                return LUNCH_SUITABLE;
            default:
                return SUPPER_SUITABLE;
        }
    }

    /**
     * 根据餐别与比例查询范围枚举
     *
     * @param mealType 餐别
     * @param rate     比例
     * @return ThreeMealEnergyRateRangeEnum
     */
    public static ThreeMealEnergyRateRangeEnum getEnumByMealAndRate(MealTypeEnum mealType, double rate) {
        rate = Math.min(rate, 1.0);
        ThreeMealEnergyRateRangeEnum[] rateRangeEnums = values();

        if (mealType == null) {
            return null;
        }
        for (ThreeMealEnergyRateRangeEnum rateRangeEnum : rateRangeEnums) {
            if (rateRangeEnum.name().startsWith(mealType.name()) && rate >= rateRangeEnum.startRate
                && rate <= rateRangeEnum.endRate) {
                return rateRangeEnum;
            }
        }
        return null;
    }

    /**
     * 根据餐别与比例查询范围枚举  慢性肾脏病
     *
     * @param name 肾脏病前缀   CHRONIC_RENAL_FAILURE
     * @param rate     比例
     * @return ThreeMealEnergyRateRangeEnum
     */
    public static ThreeMealEnergyRateRangeEnum getEnumByChronicKidneyDiseaseMealAndRate(String name, double rate) {
        rate = Math.min(rate, 1.0);
        ThreeMealEnergyRateRangeEnum[] rateRangeEnums = values();

        if (name == null) {
            return null;
        }
        for (ThreeMealEnergyRateRangeEnum rateRangeEnum : rateRangeEnums) {
            if (rateRangeEnum.name().startsWith(name) && rate >= rateRangeEnum.startRate
                    && rate <= rateRangeEnum.endRate) {
                return rateRangeEnum;
            }
        }
        return null;
    }
    /**
     * 根据餐别与比例查询范围枚举 其他四中病 贫血  慢性胃炎 肠炎 慢性肝炎
     *
     * @param name 其他四中病   OTHER
     * @param rate     比例
     * @return ThreeMealEnergyRateRangeEnum
     */
    public static ThreeMealEnergyRateRangeEnum getEnumByOtherMealAndRate(String name, double rate) {
        rate = Math.min(rate, 1.0);
        ThreeMealEnergyRateRangeEnum[] rateRangeEnums = values();

        if (name == null) {
            return null;
        }
        for (ThreeMealEnergyRateRangeEnum rateRangeEnum : rateRangeEnums) {
            if (rateRangeEnum.name().startsWith(name) && rate >= rateRangeEnum.startRate
                    && rate <= rateRangeEnum.endRate) {
                return rateRangeEnum;
            }
        }
        return null;
    }

}
