package com.jiankangyouyi.cloud.data.center.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @author jingpeng
 * @description 内蒙古云盾疾病对应的热量消耗上下限
 * @date 2020/11/5
 */

@Getter
@AllArgsConstructor
public enum YDDiseaseTypeEnergyConsumeEnum {

    /**
     * 健康人群
     */
    HEALTH_PEOPLE("0", "健康人群", 0.10, 0.3, "保持关节良好功能，预防损伤。改善体型，平衡肌肉，改善身体姿态"),
    /**
     * 高血压
     */
    HIGH_BLOOD_PRESSURE("2", "高血压", 0.10, 0.25, "维持正常的血压"),
    /**
     * 2型糖尿病
     */
    DIABETES_TYPE_2("1", "2型糖尿病", 0.10, 0.3, "控制及稳定血糖"),
    /**
     * 高血脂
     */
    HIGH_BLOOD_FAT("3", "高血脂", 0.10, 0.25, "改善脂质代谢，降低血清胆固醇水平"),
    /**
     * 冠心病
     */
    CORONARY_DISEASE("4", "冠心病", 0.05, 0.25, "预防冠状动脉硬化、提高心肺功能"),
    /**
     * 骨质疏松
     */
    OSTEOPOROSIS("5", "骨质疏松", 0.10, 0.25, "预防骨质疏松，减缓老化速度"),
    /**
     * 痛风
     */
    GOUT("6", "痛风", 0.1, 0.25, "调节代谢，促进尿酸的排出"),
    /**
     * 脂肪肝
     */
    FATTY_LIVER("7", "脂肪肝", 0.10, 0.25, "降低肝脏的脂肪含量"),
    /**
     * 脑卒中
     */
    APOPLEXY("8", "脑卒中", 0.05, 0.25, "恢复身体功能"),
    /**
     * 肥胖
     */
    OBESITY("10", "肥胖", 0.10, 0.3, "燃烧脂肪"),
    /**
     * 免疫力
     */
    IMMUNE("12", "免疫力", 0.10, 0.3, "有利于提高抵抗力"),
    /**
     * 肠道
     */
    INTESTINE("13", "肠道", 0.10, 0.3, "改善胃肠道的血液循环，加强胃肠道蠕动，加强胃肠的消化和吸收功能"),
    /**
     * 胃功能
     */
    GASTRIC("14", "胃功能", 0.10, 0.3, "改善胃肠道的血液循环，加强胃肠道蠕动，加强胃肠的消化和吸收功能"),
    /**
     * 营养素缺乏（缺≧1个）
     */
    NUTRIENT("14", "营养素缺乏", 0.10, 0.3, "促进体内的物质代谢，加强营养吸收"),
    /**
     * 产后
     */
    CHILDBIRTH("17", "产后", 0.1, 0.2, "改善体型，平衡肌肉，改善身体姿态，辅助产后恢复"),
    /**
     * 贫血
     */
    ANEMIA("17", "贫血", 0.1, 0.3, null),
    /**
     * 慢性肾脏病
     */
    CHRONIC_RENAL_FAILURE("17", "慢性肾脏病", 0.1, 0.25, null),
    /**
     * 慢性胃炎
     */
    CHRONIC_GASTRITIS("17", "慢性胃炎", 0.1, 0.3, null),
    /**
     * 肠炎
     */
    UC("17", "肠炎", 0.1, 0.3, null),
    /**
     * 慢性肝炎
     */
    CHRONIC_HEPATITIS("17", "肠炎", 0.1, 0.25, null),
    ;

    private String code;

    private String message;


    /**
     * 能量消耗下限
     */
    private double consumeLowerRate;

    /**
     * 能量消耗上限
     */
    private double consumeUpperRate;

    /**
     * 个性话术
     */
    private String describe;


    public static YDDiseaseTypeEnergyConsumeEnum parseCode(String code) {
        for (YDDiseaseTypeEnergyConsumeEnum enumItem : YDDiseaseTypeEnergyConsumeEnum.values()) {
            if (enumItem.code.equals(code)) {
                return enumItem;
            }
        }
        return null;
    }


    public static YDDiseaseTypeEnergyConsumeEnum getByDiseaseTypeEnum(DiseaseTypeEnum diseaseTypeEnum) {
        for (YDDiseaseTypeEnergyConsumeEnum enumItem : YDDiseaseTypeEnergyConsumeEnum.values()) {
            if (enumItem.name().equals(diseaseTypeEnum.name())) {
                return enumItem;
            }
        }
        //查不到给出健康人群
        return HEALTH_PEOPLE;
    }

}
