package com.jiankangyouyi.cloud.data.center.model.dto.api;

import com.jiankangyouyi.cloud.basedata.model.dto.api.AbstractHttpApiRequestDTO;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;

/**
 * 语音解析记录饮食
 *
 * @author jingpeng
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AllArgsConstructor
@NoArgsConstructor
public class SemanticSpeechAnalysisDTO extends AbstractHttpApiRequestDTO implements Serializable {
    private static final long serialVersionUID = 1L;


    /**
     * 用户ID
     */
    @NotBlank(message = "请求参数userId为空")
    @Size(max = 64, message = "请求参数userId长度不合法")
    private String userId;

    /**
     * 语音数据
     * </p>
     * 1、原始 PCM 的录音参数必须符合 8k/16k 采样率、16bit 位深、单声道， 支持的格式有：pcm（不压缩）、wav（不压缩，pcm编码）、amr（压缩格式）、map3
     * </p>
     * 2、目前系统支持的语音时长上限为60s，请不要超过这个长度，否则会返回错误。
     * </p>
     */
    @NotBlank(message = "请求参数speech为空")
    private String speech;

    /**
     * 音频格式
     */
    @NotBlank(message = "请求参数format为空")
    @Pattern(regexp = "pcm|wav|amr|mp3", message = "请求参数format不合法，参考值（pcm|wav|amr|mp3）")
    private String format;

    /**
     * 采样率 8000 或 16000
     */
    @NotNull(message = "请求参数rate为空")
    @Pattern(regexp = "8000|16000", message = "请求参数rate不合法，参考值（8000|16000）")
    private String rate;

}
