package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.model.entity.mongo.component.AppUserHealthProblem;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 用户健康状况-疾病表（包含测评结果之外的疾病）
 *
 * @author fengxuanjun
 */
@Data
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_validStatus_1_recordId_-1",
                        def = "{ 'appId' : -1, 'userId' : -1, 'validStatus': 1 ,'recordId': -1}",
                        unique = true
                ),
        }
)
@Document(collection = "v3.app.user.health.problem")
public class AppUserHealthProblemDO implements Serializable {

    private static final long serialVersionUID = 1L;


    @Id
    private ObjectId id;

    /**
     * NOT NULL 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;


    /**
     * NOT NULL 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NOT NULl 创建时间 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 记录ID
     */
    private String recordId;

    /**
     * NOT NULL 健康问题
     */
    private List<AppUserHealthProblem> healthProblems;

    /**
     * 状态
     * {@link com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum}
     */
    private String validStatus;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_HEALTHPROBLEMS = "healthProblems";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_RECOREID = "recordId";

}
