package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.api.model.entity.AppUser;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 用户历史表，每次更新用户信息时保存,字段与v3.app.user保持一致
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_createDate_-1",
                        def = "{ 'appId' : -1, 'userId' : -1, 'createDate':-1}"
                )
        }
)
@Document(collection = "v3.app.user.history")
public class AppUserHistoryDO extends AppUser implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * NOT NULL 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NOT NULl 创建时间 yyyy-MM-dd
     */
    private String createDate;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
}
