package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.model.entity.mongo.component.AppUserLifeState;
import lombok.Data;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 用户生活状况
 *
 * @author fengxuanjun
 */
@Data
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "recordId_-1",
                        def = "{ 'recordId' : -1}"
                ),
        }
)
@Document(collection = "v3.app.user.life.state")
public class AppUserLifeStateDO implements Serializable {

    private static final long serialVersionUID = 1L;


    @Id
    private ObjectId id;

    /**
     * NOT NULL 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;


    /**
     * NOT NULL 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NOT NULl 创建时间 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 记录ID
     */
    private String recordId;

    /**
     * NOT NULL 生活状况分类
     * {@link com.jiankangyouyi.cloud.data.center.api.enums.LifeStateCategoryEnum}
     */
    private String category;

    /**
     * NOT NULL 生活状况列表
     */
    private List<AppUserLifeState> lifeStateHistory;

    /**
     * 状态
     * {@link com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum}
     */
    private String validStatus;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CATEGORY = "category";
    public static final String FIELD_LIFESTATEHISTORY = "lifeStateHistory";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_RECOREID = "recordId";

}
