package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.api.model.dto.response.DietaryPattern;
import com.jiankangyouyi.cloud.data.center.api.model.dto.response.NutrientConstraint;
import com.jiankangyouyi.cloud.data.center.api.model.entity.EnergyRatio;
import com.jiankangyouyi.cloud.data.center.api.model.entity.MealRatio;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.RandomUtils;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.IndexDirection;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @description: 能量平衡计划do
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/6/7 3:48 下午
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(value = {@CompoundIndex(name = "appId_-1_userId_-1_date_-1",
        def = "{ 'appId' : -1, 'userId' : -1, 'date' : -1 }", unique = true)})
@Document(collection = "v3.energy.balance.plan")
public class EnergyBalancePlanDO implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @Builder.Default
    private Date updateTime = new Date();

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @Builder.Default
    private Date createTime = new Date();

    @Version
    private Long version;

    /**
     * 日期 yyyy-MM-dd
     */
    @Indexed(direction = IndexDirection.DESCENDING)
    private String date;


    /**
     * 是否已写入历史信息
     * true:代表已经填补了这一天的实际摄入和消耗,并且已经计算了需被调整的值
     * false:还未计算或者用户没有上传这一天的数据
     */
    private boolean history;

    /**
     * 是否突破最低阈值1200
     *
     * true:代表突破了
     * false:代表没突破
     */
    private boolean lower;
    /**
     * 建议能量摄入
     */
    @Builder.Default
    private BigDecimal energyIntakeAdvice = BigDecimal.ZERO;
    /**
     * 实际能量摄入
     */
    @Builder.Default
    private BigDecimal energyIntake = BigDecimal.ZERO;
    /**
     * 建议消耗热量
     */
    @Builder.Default
    private BigDecimal energyConsumeAdvice = BigDecimal.ZERO;
    /**
     * 建议消耗热量最大值
     */
    @Builder.Default
    private BigDecimal energyConsumeAdviceMax=BigDecimal.ZERO;
    /**
     * 建议消耗热量最小值
     */
    @Builder.Default
    private BigDecimal energyConsumeAdviceMin=BigDecimal.ZERO;

    /**
     * 运动消耗极限值
     */
    @Builder.Default
    private BigDecimal energyConsumeExtremityVal=BigDecimal.valueOf(700);
    /**
     * 实际消耗热量
     */
    @Builder.Default
    private BigDecimal energyConsume = BigDecimal.ZERO;

    /**
     * 待调整能量
     */
    @Builder.Default
    private BigDecimal awaitAdjusToEnergy = BigDecimal.ZERO;

    /**
     * 已经被调整的热量
     * {调整日期:调整值}示例{"2020-01-01":209.09}代表这一天需要调整的热量被2020-01-01调整了209.09
     */
    @Builder.Default
    private Map<String, AdjusToEnergyInfo> finishAdjusToEnergy = new HashMap<>();

    /**
     * 已经完成的热量调整
     * {去调整的日期:调整值}示例{"2021-01-01":200}代表这一天调整了2021-01-01的200热量
     */
    @Builder.Default
    private Map<String, AdjusToEnergyInfo> completeAdjusToEnergy = new HashMap<>();

    /**
     * 能量比例
     */
    private EnergyRatio energyRatio;
    /**
     * 餐次比例
     */
    private List<MealRatio> mealRatio;

    /**
     * 营养原则
     */
    private List<String> nutritionPrinciples;

    /**
     * 配餐目标信息
     */
    private List<String> foodMatchObjectiveMsgs;

    /**
     * 膳食结构
     */
    private DietaryPattern dietaryPattern;

    /**
     * 营养素约束
     */
    private NutrientConstraint nutrientConstraint;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_VERSION = "version";
    public static final String FIELD_DATE = "date";
    public static final String FIELD_HISTORY = "history";
    public static final String FIELD_LOWER = "lower";
    public static final String FIELD_ENERGYINTAKEADVICE = "energyIntakeAdvice";
    public static final String FIELD_ENERGYINTAKE = "energyIntake";
    public static final String FIELD_ENERGYCONSUMEADVICE = "energyConsumeAdvice";
    public static final String FIELD_ENERGYCONSUME = "energyConsume";
    public static final String FIELD_AWAITADJUSTOENERGY = "awaitAdjusToEnergy";
    public static final String FIELD_FINISHADJUSTOENERGY = "finishAdjusToEnergy";
    public static final String FIELD_COMPLETEADJUSTOENERGY = "completeAdjusToEnergy";

    /**
     * 调整能量信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class AdjusToEnergyInfo{
        private BigDecimal eat;
        private BigDecimal exercise;
    }

    /**
     * 推荐热量不能小于 1200 卡
     * @param energy
     */
    public void setAdjustEnergyIntakeAdvice(BigDecimal energy) {
        this.setEnergyIntakeAdvice(energy.compareTo(BigDecimal.valueOf(1200)) < 0 ? BigDecimal.valueOf(RandomUtils.nextInt(1200, 1300)) : energy);
    }

    /**
     * 计算并设置推荐运动量
     * @param exerciseEnergy   初始推荐运动量
     */
    public void mathSetEnergyConsumeAdvice(BigDecimal exerciseEnergy){
        this.setEnergyConsumeAdvice(exerciseEnergy.compareTo(this.getEnergyConsumeExtremityVal())<=0?exerciseEnergy:this.getEnergyConsumeExtremityVal());
    }
}
