package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 记录指标数据
 * @author ：wangyalei
 * @date ：Created in 2021/9/18 10:56 上午
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "indicatorType-1_indicatorDescLevel_-1",
                        def = "{ 'indicatorType' : -1, 'indicatorDescLevel' : -1}"
                )
        }
)
@Document(collection = "v3.record.indicator.data")
public class RecordIndicatorDataDO {

    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @Indexed
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NOT NULL 数据记录ID (由于将原始身体指标数据记录进行拆分存入到此表中，原始表的唯一 recordId 在此表中不是唯一，所以新增此字段作为唯一id。)
     */
    @Indexed(unique = true)
    private String dataRecordId;

    /**
     * NOT NULL 记录ID (原始身体指标数据记录id，保留此字段是为了可以追踪到此数据与原始表数据的关联关系，后续逐渐将原始数据表遗弃的时候，此字段可以忽略)
     * 一组数据 recordId相同
     */
    @Indexed
    private String recordId;

    /**
     * 应用id
     */
    private String appId;
    /**
     * 用户id
     */
    private String userId;
    /**
     * 性别 0、未知 1、男 2、女
     */
    private String gender;
    /**
     * 年龄
     */
    private Integer age;
    /**
     * 业务类型
     */
    private String bizType;
    /**
     * 记录时间 yyyy-MM-dd HH:mm:ss
     */
    private Date recordTime;
    /**
     * 记录日期 yyyy-MM-dd
     */
    @Indexed
    private String recordDate;
    /**
     * 指标名称
     */
    private String indicatorName;
    /**
     * 指标类型 {@link com.jiankangyouyi.cloud.data.center.api.enums.IndicatorEnum}
     */
    private String indicatorType;
    /**
     * 指标值类型 {@link com.jiankangyouyi.cloud.data.center.api.enums.IndicatorValueTypeEnum}
     */
    private String indicatorValueType;
    /**
     * 数值指标值类型 指标值
     */
    private BigDecimal numberValue;
    /**
     * 字符指标值类型 指标值
     */
    private String characterValue;
    /**
     * 指标范围 (正常值范围)
     */
    private String indicatorRange;
    /**
     * 指标单位
     */
    private String indicatorUnit;
    /**
     * 指标描述 (字典code)
     */
    private String indicatorDesc;
    /**
     * 指标描述等级 (字典code)
     */
    private Integer indicatorDescLevel;
    /**
     * 有效状态 {@link ValidStatusEnum}
     */
    @Builder.Default
    private String validStatus = ValidStatusEnum.VALID.code();

    /**
     * 标签 codes {@link com.jiankangyouyi.cloud.data.center.api.enums.IndicatorTagCodeEnum}
     */
    private List<String> tagCodes;

    /**
     * 异常等级 0 正常 -1异常
     */
    private String abnormalLevel;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_RECORDID = "recordId";
    public static final String FIELD_DATA_RECORD_ID = "dataRecordId";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_GENDER = "gender";
    public static final String FIELD_AGE = "age";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_RECORDDATE = "recordDate";
    public static final String FIELD_RECORDTIME = "recordTime";
    public static final String FIELD_INDICATORNAME = "indicatorName";
    public static final String FIELD_INDICATORTYPE = "indicatorType";
    public static final String FIELD_INDICATORRANGE = "indicatorRange";
    public static final String FIELD_INDICATORUNIT = "indicatorUnit";
    public static final String FIELD_INDICATORDESC = "indicatorDesc";
    public static final String FIELD_INDICATORDESCLEVEL = "indicatorDescLevel";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_ABNORMALLEVEL = "abnormalLevel";
    public static final String FIELD_NUMBERVALUE = "numberValue";
}
