package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.api.model.entity.RecordSleep;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 睡眠情况记录表
 *
 * @author yangsongbo
 */
@Data
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_bizType_-1_userId_-1_recordDate_-1_validStatus_1",
                        def = "{ 'appId' : -1,'bizType':-1,'userId' : -1, 'recordDate' : -1 , 'validStatus' : 1 }",
                        unique = true
                )
        }
)
@Document(collection = "v3.record.sleep")
public class RecordSleepDO extends RecordSleep implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * NOT NULL 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * NOT NULL 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 有效标识. 1 有效  UUID 无效
     */
    private String validStatus;

    /**
     * NOT NULL 记录ID
     */
    @Indexed(unique = true)
    private String recordId;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_RECORDID = "recordId";
    public static final String FIELD_RECORD_TIME = "recordTime";
}
