package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 步数记录明细表
 *
 * @author jingpeng
 * @date 2020/11/2
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "recordId_-1_recordHour_1",
                        def = "{ 'recordId' : -1, 'recordHour' : 1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.record.step.detail")
public class RecordStepDetailDO implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 更新时间 NOT NULL
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间 NOT NULL
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 记录id NOT NULL
     */
    private String recordId;

    /**
     * 记录日期 yyyy-MM-dd NOT NULL
     */
    private String recordDate;

    /**
     * 记录小时（24小时制）NOT NULL
     */
    private Integer recordHour;

    /**
     * 应用id NOT NULL
     */
    private String appId;

    /**
     * 能量 NOT NULL
     */
    private Integer energy;

    /**
     * 步数 NOT NULL
     */
    private Integer quantity;

    /**
     * 距离(米) NOT NULL
     */
    private Double distance;

    /**
     * 有效标识
     */
    private String validStatus;

    /**
     * 记录日期
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date recordTime;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_RECORDID = "recordId";
    public static final String FIELD_RECORDDATE = "recordDate";
    public static final String FIELD_RECORDHOUR = "recordHour";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_ENERGY = "energy";
    public static final String FIELD_QUANTITY = "quantity";
    public static final String FIELD_DISTANCE = "distance";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_RECORD_TIME = "recordTime";
}
