package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 步数目标设置表
 *
 * @author yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_recordDate_-1_bizType_1",
                        def = "{ 'appId' : -1, 'userId' : -1, 'recordDate' : -1 , 'bizType' : 1}"
                )
        }
)
@Document(collection = "v3.record.step.target")
public class RecordStepTargetDO implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * NOT NULL 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * NOT NULL 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * NOT NULL 记录日期 yyyy-MM-dd
     */
    private String recordDate;

    /**
     * NOT NULL 应用ID
     */
    private String appId;

    /**
     * NOT NULL 用户ID
     */
    private String userId;

    /**
     * NOT NULL 业务类型
     */
    private String bizType;

    /**
     * NOT NULL 目标值(步)
     */
    private Integer target;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_RECORDDATE = "recordDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_TARGET = "target";



}
