package com.jiankangyouyi.cloud.data.center.model.entity.mongo.healthanalysis;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.api.model.vo.analysis.health.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Date;

/**
 * 单日 日健康分析日志
 *
 * @author lvqidong
 * @date 2021/11/22 19:52
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_recordDate_-1",
                        def = "{ 'appId' : -1, 'userId' : -1,'recordDate':-1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.day.health.analysis")
@FieldNameConstants
public class HealthAnalysisDayDO implements Serializable {

    private static final long serialVersionUID = 1L;


    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 有效状态 1 有效  2/其他无效
     */
    private String validStatus;

    /**
     * 开发者名称
     */
    private String appName;
    /**
     * 开发者
     */
    private String appId;

    /**
     * 配置ID
     */
    private String configId;
    /**
     * 用户ID
     */
    private String userId;

    /**
     * bizType
     */
    private String bizType;

    /**
     * NOT NULL 记录日期 yyyy-MM-dd
     */
    @Size(max = 10, message = "请求参数recordDate长度不合法")
    private String recordDate;

    /**
     * 生产日期
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date recordTime;

    /**
     * 记录ID
     */
    private String recordId;


    /**
     * 版本 1 当前版本为1
     */
    private String dataVersion;

    /**
     * 单日综合分析
     */
    private SynthesisHealthAnalysisVO synthesisHealthAnalysis;

    /**
     *运动健康维度分析
     */
    private ExerciseHealthDimensionalityAnalysisVO exerciseHealthDimensionalityAnalysis;

    /**
     * 心理状态维度分析
     */
    private MentalityStatusDimensionalityAnalysisVO mentalityStatusDimensionalityAnalysis;

    /**
     *检测指标维度分析
     */
    private CheckIndicatorDimensionalityAnalysisVO checkIndicatorDimensionalityAnalysis;

    /**
     *睡眠维度分析
     */
    private SleepDimensionalityAnalysisVO sleepDimensionalityAnalysis;

    /**
     * 单日运动分析-规律运动
     */
    private UserCalorieBalanceVO userCalorieBalance;

    /**
     * 单日运动消耗
     */
    private ExerciseExpendVO exerciseExpend;

    /**
     * 均衡膳食
     */
    private BalancingGoodFoodVO balancingGoodFood;

    /**
     * 用户食物摄入
     */
    private UserIntakeFoodVO userIntakeFood;


    public static final String FIELD_SYNTHESIS_HEALTH_ANALYSIS = "synthesisHealthAnalysis";

    public static final String FIELD_EXERCISE_HEALTH_DIMENSIONALITY_ANALYSIS = "exerciseHealthDimensionalityAnalysis";

    public static final String FIELD_MENTALITYSTATUSDIMENSIONALITYANALYSIS = "mentalityStatusDimensionalityAnalysis";

    public static final String FIELD_CHECKINDICATORDIMENSIONALITYANALYSIS = "checkIndicatorDimensionalityAnalysis";

    public static final String FIELD_SLEEPDIMENSIONALITYANALYSIS = "sleepDimensionalityAnalysis";

    public static final String FIELD_USERCALORIEBALANCE  = "userCalorieBalance";

    public static final String FIELD_EXERCISEEXPEND  = "exerciseExpend";

    public static final String FIELD_BALANCINGGOODFOOD  = "balancingGoodFood";

    public static final String FIELD_USERINTAKEFOOD  = "userIntakeFood";

    public static final String FIELD_RECORDTIME  = "recordTime";



}
