package com.jiankangyouyi.cloud.data.center.model.entity.mongo.healthanalysis;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.data.center.api.model.vo.analysis.health.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Size;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 单日 日健康分析日志
 *
 * @author lvqidong
 * @date 2021/11/22 19:52
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-recordDateStart-1_recordDateEnd-1",
                        def = "{ 'appId' : -1, 'userId' : -1,'recordDateStart':-1,'recordDateEnd':-1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.month.health.analysis")
@FieldNameConstants
public class HealthAnalysisMonthDO implements Serializable {

    private static final long serialVersionUID = 1L;


    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime createTime;

    /**
     * 有效状态 1 有效  2/其他无效
     */
    private String validStatus;

    /**
     * 开发者名称
     */
    private String appName;
    /**
     * 开发者
     */
    private String appId;

    /**
     * 配置ID
     */
    private String configId;
    /**
     * 用户ID
     */
    private String userId;

    /**
     * bizType
     */
    private String bizType;

    /**
     * NOT NULL 记录日期 yyyy-MM-dd
     */
    @Size(max = 10, message = "请求参数recordDate长度不合法")
    private String recordDateStart;


    @Size(max = 10, message = "请求参数recordDate长度不合法")
    private String recordDateEnd;

    /**
     * 生产日期
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date recordTime;

    /**
     * 记录日期 yyyy-MM-dd
     */
    private String recordDate;

    /**
     * 记录ID
     */
    private String recordId;


    /**
     * 版本 1 当前版本为1
     */
    private String dataVersion;

    /**
     * 单日综合分析
     */
    private SynthesisHealthAnalysisVO synthesisHealthAnalysis;
    /**
     * 均衡善食 周报 月报
     */
    private BalancingGoodFoodMonthVO balancingGoodFoodMonth;

    /**
     * 规律运动 周报 月报
     */
    private SynthesisHealthSportVO synthesisHealthSport;

    /**
     * 步数量阶段分析
     */
    private StepStageAnalysisVO stepStageAnalysis;

    /**
     * 步数量阶段分析
     */
    private HeartRateStageAnalysisVO heartRateStageAnalysis;

    /**
     * 体温阶段分析
     */
    private BodyTemperatureStageAnalysisVO bodyTemperatureStageAnalysis;


    /**
     * 血氧阶段分析
     */
    private BloodOxygenStageAnalysisVO bloodOxygenStageAnalysis;

    /**
     * 血压阶段分析
     */
    private BloodPressureStageAnalysisVO bloodPressureStageAnalysis;

    /**
     * HRV阶段分析
     */
    private HrvStageAnalysisVO hrvStageAnalysis;


    /**
     * 压力阶段分析
     */
    private StressStageAnalysisVO stressStageAnalysis;

    /**
     * 睡眠阶段分析
     */
    private SleepStageAnalysisVO sleepStageAnalysis;

    /**
     * 总胆固醇阶段分析
     */
    private TotalCholesterolStageAnalysisVO totalCholesterolStageAnalysis;
    /**
     * 血尿酸阶段分析
     */
    private BloodUricAcidStageAnalysisVO bloodUricAcidStageAnalysis;

    /**
     * 血糖阶段分析
     */
    private BloodGlucoseStageAnalysisVO bloodGlucoseStageAnalysis;


    /**
     * 人体成分阶段分析
     */
    private BodyCompositionStageAnalysisVO bodyCompositionStageAnalysis;





}
