package com.jiankangyouyi.cloud.data.center.model.entity.mongo.rule;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;
import java.util.List;

/**
 * 周报月报 运动规则
 *
 * @author lvqidong
 * @date 2021/11/12 09:34
 **/
@Data
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "v3.rule.sport")
@Builder
@FieldNameConstants
public class YearMonthSportRuleDO implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 规则编号
     */
    private String codeNum;

    /**
     * 运动时间最小
     */
    private String sportTimeMin;

    /**
     *运动时间最大
     */
    private String sportTimeMax;

    /**
     * 运动频率最小
     */
    private Integer minExerciseFrequency;

    /**
     * 运动频率最大
     */
    private Integer maxExerciseFrequency;


    /**
     * 部分1 通用话术标准
     * eg [公式7,90]
     */
    private String generalBz;

    /**
     * 部分1 通用话术
     * eg 根据近期连续运动数据，平均每天完成$分钟，推荐每日平均运动$分钟以上。
     */
    private String generalMes;

    /**
     * 话术1判断逻辑
     */
    private List<BaseMes> wordsTechnique1;

   ////////////////////////////////////////////部分2

    /**
     * 运动频率
     */
    private List<FrequencyData> wordsTechnique2;

    /**
     * 运动强度
     *
     */
    private List<SportLevel> wordsTechnique3;
    /**
     * 运动强度 分数
     */
    private Integer sportLevelScore;

    /**
     *
     *热量消耗评估
     */
    private List<EnergyLevel> wordsTechnique4;

    /**
     * 热量消耗综合话术
     *
     */
    private String energyLevelContext;






    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class  BaseMes{
       //公式判断条件
        private  String conditions;
       //0 无记录 1欠佳 2良好 3优秀 4过量
        private String  code;
        //返回内容
        private String mess;
    }

    /**
     * 运动频率
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class  FrequencyData{
        //0 疲劳 1 适宜 2 间隔时长
        private String  code;
        //返回内容
        private String mess;
    }

    /**
     * 运动强度
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class  SportLevel{
        //1 有氧基础 2 有氧效率 3 无氧耐力
        private String  code;
        //返回内容
        private String mess;
    }

    /**
     * 热量消耗
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class  EnergyLevel{
        /**
         * [,170)
         */
        private  String conditions;
        //1 一般 2 适宜 3 过多
        private String  code;
        //返回内容
        private String mess;
    }


}
