package com.jiankangyouyi.cloud.food_match.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.math.BigDecimal;

/**
 * @description:
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2022/1/18 3:57 下午
 */
@Getter
@AllArgsConstructor
public enum EnergyRangeEnum {
    /**碳水**/
    ER_C_1("ER_C_1","40-55",BigDecimal.valueOf(0.4),BigDecimal.valueOf(0.55)),
    ER_C_2("ER_C_2","45-65",BigDecimal.valueOf(0.45),BigDecimal.valueOf(0.65)),
    ER_C_3("ER_C_3","50-55",BigDecimal.valueOf(0.5),BigDecimal.valueOf(0.55)),
    ER_C_4("ER_C_4","50-60",BigDecimal.valueOf(0.5),BigDecimal.valueOf(0.6)),
    ER_C_5("ER_C_5","50-65",BigDecimal.valueOf(0.5),BigDecimal.valueOf(0.65)),
    ER_C_6("ER_C_6","55-65",BigDecimal.valueOf(0.55),BigDecimal.valueOf(0.65)),
    ER_C_7("ER_C_7","60-65",BigDecimal.valueOf(0.6),BigDecimal.valueOf(0.65)),
    ER_C_8("ER_C_7","60-70",BigDecimal.valueOf(0.6),BigDecimal.valueOf(0.7)),
    /**蛋白质**/
    ER_P_1("ER_P_1","10-15",BigDecimal.valueOf(0.1),BigDecimal.valueOf(0.15)),
    ER_P_2("ER_P_2","10-13",BigDecimal.valueOf(0.1),BigDecimal.valueOf(0.13)),
    ER_P_3("ER_P_3","10-20",BigDecimal.valueOf(0.1),BigDecimal.valueOf(0.2)),
    ER_P_4("ER_P_4","13-15",BigDecimal.valueOf(0.13),BigDecimal.valueOf(0.15)),
    ER_P_5("ER_P_5","13-17",BigDecimal.valueOf(0.13),BigDecimal.valueOf(0.17)),
    ER_P_6("ER_P_6","15-20",BigDecimal.valueOf(0.15),BigDecimal.valueOf(0.2)),
    ER_P_7("ER_P_7","15-18",BigDecimal.valueOf(0.15),BigDecimal.valueOf(0.18)),

    /**脂肪**/
    ER_F_1("ER_F_1","15-25",BigDecimal.valueOf(0.15),BigDecimal.valueOf(0.25)),
    ER_F_2("ER_F_2","20-25",BigDecimal.valueOf(0.2),BigDecimal.valueOf(0.25)),
    ER_F_3("ER_F_3","20-30",BigDecimal.valueOf(0.2),BigDecimal.valueOf(0.3)),
    ER_F_4("ER_F_4","20-35",BigDecimal.valueOf(0.2),BigDecimal.valueOf(0.35)),
    ;


    private String code;
    private String name;
    private BigDecimal min;
    private BigDecimal max;

    public static EnergyRangeEnum getEnumByCodeOrName(String condition) {
        EnergyRangeEnum[] values = values();
        if (condition == null) {
            return null;
        } else {
            EnergyRangeEnum result = null;
            for(EnergyRangeEnum temp : values){
                if(temp.code.equals(condition) || temp.name.equals(condition)){
                    result = temp;
                    break;
                }
            }
            return  result;
        }
    }

    public static EnergyRangeEnum getEnumByEnergy(BigDecimal min,BigDecimal max) {
        EnergyRangeEnum[] values = values();
        if (min == null || max == null) {
            return null;
        } else {
            EnergyRangeEnum result = null;
            for(EnergyRangeEnum temp : values){
                if(temp.getMin().compareTo(min)==0 && temp.getMax().compareTo(max)==0){
                    result = temp;
                    break;
                }
            }
            return  result;
        }
    }

}
