package com.jiankangyouyi.cloud.food_match.enums.test;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;


/**
 * 配餐统计纬度
 *
 * @author june
 * @date 2022/11/03
 */
@Getter
@AllArgsConstructor
@NoArgsConstructor
public enum FoodMatchResultCollectTypeEnum {
    /**
     * 能量
     */
    ENERGY,
    /**
     * 碳水化合物
     */
    CARBOHYDRATE,
    /**
     * 蛋白质
     */
    PROTEIN,
    /**
     * 脂肪
     */
    FAT,
    /**
     * 碳水化合物-比例
     */
    CARBOHYDRATE_RATIO("碳水化合物", null),
    /**
     * 蛋白质-比例
     */
    PROTEIN_RATIO("蛋白质", null),
    /**
     * 脂肪-比例
     */
    FAT_RATIO("脂肪", null),
    /**
     * 早餐
     */
    BREAKFAST,
    /**
     * 早加餐
     */
    BREAKFAST_EXTRA,
    /**
     * 午餐
     */
    LUNCH,
    /**
     * 午加餐
     */
    LUNCH_EXTRA,
    /**
     * 晚餐
     */
    SUPPER,
    /**
     * 晚加餐
     */
    SUPPER_EXTRA,
    /**
     * 早餐-比例
     */
    BREAKFAST_RATIO("早餐", null),
    /**
     * 早加餐-比例
     */
    BREAKFAST_EXTRA_RATIO("早加餐", null),
    /**
     * 午餐-比例
     */
    LUNCH_RATIO("午餐", null),
    /**
     * 午加餐-比例
     */
    LUNCH_EXTRA_RATIO("午加餐", null),
    /**
     * 晚餐-比例
     */
    SUPPER_RATIO("晚餐", null),
    /**
     * 晚加餐-比例
     */
    SUPPER_EXTRA_RATIO("晚加餐", null),

    /**
     * 谷物
     */
    CEREAL("膳食结构", "谷物", "g"),
    /**
     * 全谷物
     */
    ALL_CEREAL("膳食结构", "全谷物", "g"),
    /**
     * 薯类
     */
    POTATO("膳食结构", "薯类", "g"),
    /**
     * 蔬菜
     */
    VEGETABLE("膳食结构", "蔬菜", "g"),

    /**
     * 水果
     */
    FRUITS("膳食结构", "水果", "g"),

    /**
     * 禽畜肉蛋
     */
    MEAT("膳食结构", "禽畜肉蛋", "g"),
    /**
     * 蛋及其制品
     */
    EGGS("膳食结构", "蛋及其制品", "g"),
    /**
     * 鱼虾类
     */
    SEAFOOD("膳食结构", "鱼虾类", "g"),
    /**
     * 奶
     */
    MILK("膳食结构", "奶", "g"),
    /**
     * 大豆
     */
    SOYA("膳食结构", "大豆", "g"),

    /**
     * 坚果
     */
    NUT("膳食结构", "坚果", "g"),

    /**
     * 烹饪油
     */
    OIL("膳食结构", "烹饪油", "g"),
    /**
     * 膳食纤维或可溶性膳食纤维
     */
    DF,

    /**
     * 总胆固醇
     */
    TOTAL_CHOLESTEROL,

    /**
     * 维生素a
     */
    VA,

    /**
     * 维生素c
     */
    VC,
    /**
     * 维生素d
     */
    VD,

    /**
     * 维生素e
     */
    VE,
    /**
     * 维生素b1
     */
    VB1,
    /**
     * 维生素b2
     */
    VB2,

    /**
     * 维生素b5
     */
    VB5,
    /**
     * 维生素b6
     */
    VB6,

    /**
     * 维生素b12
     */
    VB12,

    /**
     * 叶酸
     */
    FOLIC_ACID,
    /**
     * 烟酸
     */
    NIACIN,
    /**
     * 生物素
     */
    BIOTIN,
    /**
     * 维生素k
     */
    VK,
    /**
     * 胆碱
     */
    CHOLINE,

    /**
     * 钙
     */
    CALCIUM,
    /**
     * 钾
     */
    POTASSIUM,
    /**
     * 镁
     */
    MAGNESIUM,
    /**
     * 铁
     */
    IRON,
    /**
     * 锌
     */
    ZINC,
    /**
     * 硒
     */
    SELENIUM,
    /**
     * 铬
     */
    CHROMIUM,
    /**
     * 锰
     */
    MANGANESE,
    /**
     * 碘
     */
    IODINE,
    /**
     * 钠
     */
    SODIUM,
    /**
     * 磷
     */
    PHOSPHORUS,
    /**
     * 铜
     */
    COPPER,
    /**
     * 氟
     */
    FLUORINE,
    /**
     * 钼
     */
    MOLYBDENUM,
    ;
    /**
     * 父类名称
     */
    private String parentName;
    /**
     * 当前类名称
     */
    private String name;
    /**
     * 单位 默认百分比
     */
    private String unit;


    FoodMatchResultCollectTypeEnum(String name, String unit) {
        this.name = name;
        this.unit = unit;
    }

    /**
     * 获取不匹配提示信息
     *
     * @param min 最小值
     * @param max 最大值
     * @return
     */
    public String getNotMatchMessage(BigDecimal min, BigDecimal max) {
        String messageName = StringUtils.isBlank(this.parentName) ? this.name : String.format("%s（%s）", this.parentName, this.name);
        // 是否百分比
        boolean isRatio = StringUtils.isBlank(this.unit);
        String type = isRatio ? "占比" : "含量";
        String range = isRatio ? String.format("%s%%~%s%%", getRatioString(min), getRatioString(max)) : String.format("%s%s~%s%s", min.toPlainString(), this.unit, max.toPlainString(), this.unit);
        return String.format("%s%s不合理，合理范围为%s", messageName, type, range);
    }

    private static String getRatioString(BigDecimal ratio) {
        return ratio.multiply(new BigDecimal(100)).setScale(2, RoundingMode.HALF_UP).toPlainString();
    }
}
