package com.jiankangyouyi.cloud.food_match.model.dto.request.match;


import com.jiankangyouyi.cloud.data.center.api.model.entity.component.HealthProblemInfo;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.Data;
import org.apache.commons.collections4.CollectionUtils;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @description: 换一换请求DTO
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/8/20 4:23 下午
 */
@Data
public class ChangeFoodApiRequestDTO extends AbstractHttpApiRequestDTO {


    /**
     * 用户id
     */
    private String userId;
    /**
     * 体重 kg
     */
    private BigDecimal weight;
    /**
     * 身高 cm
     */
    private int height;
    /**
     * 出生年月日 yyyy-MM-dd
     */
    private String birthday;
    /**
     * 性别 1:男2:女
     */
    private String gender;
    /**
     * 体力活动等级
     */
    private String activityLevel;
    /**
     * 运动等级
     */
    private Integer exerciseRiskLevel;
    /**
     * 疾病情况
     */
    private List<HealthProblemInfo> healthProblemInfos;
    /**
     * 时令
     */
    private String userSeason;

    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;
    /**
     * 需要换的餐次
     */
    private String suitMeal;

    /**
     * NULL 民族 （膳食使用时数据来源——字典——字典大类：食物库，字典子类：禁忌民族）
     */
    private String nation;
    /**
     * 所在的地域
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：国家及地区）
     */
    private String area;

    /**
     * 喜好口味
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：口味）
     */
    private List<String> taste;
    /**
     * 配餐日期
     */
    private String planningDate;
    /**
     * 早餐食物
     */
    private List<MatchResFoodInfo> breakfastRes;


    /**
     * 早+餐食物
     */
    private List<MatchResFoodInfo> breakfastExtraRes;


    /**
     * 午餐食物
     */
    private List<MatchResFoodInfo> lunchRes;

    /**
     * 午+餐食物
     */
    private List<MatchResFoodInfo> lunchExtraRes;

    /**
     * 晚餐食物
     */
    private List<MatchResFoodInfo> supperRes;

    /**
     * 晚+餐食物
     */
    private List<MatchResFoodInfo> supperExtraRes;

    /**
     * 换一换食物所处餐次
     * 1早餐 2早+ 3午餐 4午+ 5晚餐 6晚+
     */
    private int changeMealCode;

    /**
     * 换一换食物所处位置，从0开始
     */
    private int changeFoodIndex;

    /**
     * 食物候选列表数量
     */
    private int foodNum;

    /**
     * 是否忽略餐次比例，不对外暴露，别写进文档
     */
    private boolean ignoreMealRatio;

    /**
     * 是否放弃约束
     */
    private Boolean isAbandonConstraint;

    public Set<String> hasFoodIds() {
        Set<String> res = new LinkedHashSet<>();
        if (CollectionUtils.isNotEmpty(this.getBreakfastRes()))
            res.addAll(this.getBreakfastRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        if (CollectionUtils.isNotEmpty(this.getBreakfastExtraRes()))
            res.addAll(this.getBreakfastExtraRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        if (CollectionUtils.isNotEmpty(this.getLunchRes()))
            res.addAll(this.getLunchRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        if (CollectionUtils.isNotEmpty(this.getLunchExtraRes()))
            res.addAll(this.getLunchExtraRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        if (CollectionUtils.isNotEmpty(this.getSupperRes()))
            res.addAll(this.getSupperRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        if (CollectionUtils.isNotEmpty(this.getSupperExtraRes()))
            res.addAll(this.getSupperExtraRes().stream().collect(Collectors.groupingBy(MatchResFoodInfo::getFoodId)).keySet());
        return res;
    }

    /**
     * 配餐成功的食物精简结果
     */
    @Data
    public static class MatchResFoodInfo implements Serializable {
        private String foodId;
        private int gram;
    }

}
