package com.jiankangyouyi.cloud.food_match.model.dto.request.match;

import com.jiankangyouyi.cloud.core.validator.annotation.*;
import com.jiankangyouyi.cloud.food_match.api.enums.FoodMealTypeEnum;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Objects;
import java.util.Set;

/**
 * @description: 整餐换一换请求dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2022/1/18 5:03 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class ChangeMealRequestApiDTO extends AbstractHttpApiRequestDTO {

    /**
     * 日期 格式yyyy-MM-dd
     */
    @NotEmptyHC
    @DateValHC(pattern = "yyyy-MM-dd")
    private String recipesDate;


    /**
     * 用户id
     */
    @NotEmptyHC
    @SizeHC(64)
    private String userId;

    /**
     * 餐次类型 1早餐2早+3午餐4午+5晚餐6晚+
     */
    @NotEmptyHC
    @IntValHC
    @EnumHC(enumTypes = FoodMealTypeEnum.class)
    @SizeHC(1)
    private String mealType;


    /**
     * 不可变食物ids
     */
    private Set<String> immutableFoodIds;

    /**
     * 是否放弃约束条件
     */
    private Boolean discard = false;

    /**
     * 是否限制热量 - 默认true
     */
    private Boolean isLimitEnergy;

    /**
     * 是否放弃约束
     */
    private Boolean isAbandonConstraint;

    public Boolean getLimitEnergy() {
        if (Objects.isNull(isLimitEnergy)) {
            return true;
        }
        return isLimitEnergy;
    }

 
}
