package com.jiankangyouyi.cloud.food_match.model.dto.request.match;

import com.jiankangyouyi.cloud.core.validator.annotation.SizeHC;
import com.jiankangyouyi.cloud.data.center.api.model.entity.component.HealthProblemInfo;
import com.jiankangyouyi.cloud.data.center.api.model.entity.component.NutrientStateInfo;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.*;

import java.math.BigDecimal;
import java.util.List;

/**
 * @description: 配餐请求dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/26 3:32 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class MatchFoodV2RequestDTO extends AbstractHttpApiRequestDTO {

    private static final long serialVersionUID = 1L;
    /**
     * 用户id
     */
    private String userId;
    /**
     * 体重 kg
     */
    private BigDecimal weight;
    /**
     * 身高 cm
     */
    private int height;
    /**
     * 出生年月日 yyyy-MM-dd
     */
    private String birthday;
    /**
     * 性别 1:男2:女
     */
    private String gender;
    /**
     * 体力活动等级
     */
    private String activityLevel;
    /**
     * 运动等级
     */
    private Integer exerciseRiskLevel;
    /**
     * 疾病情况
     */
    private List<HealthProblemInfo> healthProblemInfos;

    /**
     * NULL 营养素状态信息 当健康问题包含 NUTRIENT_DEFICIENCY 时此处不可为空
     */
    private List<NutrientStateInfo> nutrientStateInfos;

    /**
     * NUll 分娩日期,性别为女性时才能赋值 yyyy-MM-dd
     */
    private String deliveryDate;

    /**
     * NULL 哺乳状态，性别为女性时才能赋值
     * <p>
     * {@link com.jiankangyouyi.cloud.data.center.api.enums.LactationStatusEnum}
     */
    private String lactationStatus;

    /**
     * NULL 民族 （膳食使用时数据来源——字典——字典大类：食物库，字典子类：禁忌民族）
     */
    private String nation;
    /**
     * 所在的地域
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：国家及地区）
     */
    private String area;

    /**
     * 喜好口味
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：口味）
     */
    private List<String> taste;
    /**
     * 配餐日期
     */
    private String planningDate;
    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;
    /**
     * 是否强行重新配餐
     */
    private boolean reMatch;


    /**
     * 糖尿病用药情况,不传默认4
     * {@link com.jiankangyouyi.cloud.data.center.api.enums.Type2DiabetesPharmacyEnum}
     */
    @SizeHC(1)
    private String type2DiabetesPharmacyCode;


    // /**
    //  * 调试时使用
    //  */
    // private Integer type;

    private Integer recommendedIntakeEnergy;

    /**
     * 区分产品 华为 ，标品
     */
    private String standard;


}
