package com.jiankangyouyi.cloud.food_match.model.dto.request.match;

import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.NotEmptyHC;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

/**
 * @description: 重新保存配餐结果
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/8/24 2:54 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class ReSaveFoodMatchResRequestDTOV2 extends AbstractHttpApiRequestDTO {

    /**
     * 配餐用户id
     * @length 64
     */
    private String userId;

    /**
     * 配餐日期
     */
    @NotEmptyHC
    @DateValHC(pattern = "yyyy-MM-dd")
    private String recipesDate;


    /**
     * 餐次类型 <br/>1:早餐<br/>2早+餐<br/>3午餐<br/>4午+餐<br/>5晚餐<br/>6晚+餐
     * @length 1
     */
    @Min(value = 1,message = "mealType 范围为1~6")
    @Max(value = 6,message = "mealType 范围为1~6")
    private int mealType;

    /**
     * 替换食物id
     * @length 32
     */
    @NotEmptyHC
    private String replaceFoodId;

    /**
     * 被替换食物id
     * @length 32
     */
    @NotEmptyHC
    private String byReplaceFoodId;

    /**
     * 更换后的食物克数
     * @length 4
     */
    @NotEmptyHC
    private int gram;
}
