package com.jiankangyouyi.cloud.food_match.model.dto.request.match;

import com.jiankangyouyi.cloud.core.validator.annotation.DateValHC;
import com.jiankangyouyi.cloud.core.validator.annotation.NotEmptyHC;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.*;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

/**
 * @description: 第三方换一换请求dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/10/9 2:05 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class V3ChangeFoodRequestDTO extends AbstractHttpApiRequestDTO {

    /**
     * 日期 格式yyyy-MM-dd
     */
    @NotEmptyHC
    @DateValHC(pattern = "yyyy-MM-dd")
    private String recipesDate;

    /**
     * 用户id
     * @length 64
     */
    @NotEmptyHC
    private String userId;
    /**
     * 替换食物id
     * @length 32
     */
    @NotEmptyHC
    private String replaceFoodId;

    /**
     * 餐次类型 <br/>1:早餐<br/>2早+餐<br/>3午餐<br/>4午+餐<br/>5晚餐<br/>6晚+餐
     */
    @Min(value = 1, message = "mealType 范围为1~6")
    @Max(value = 6, message = "mealType 范围为1~6")
    private int mealType;

    /**
     * 是否放弃约束-默认放弃
     */
    private Boolean isAbandonConstraint;


}
