package com.jiankangyouyi.cloud.food_match.model.dto.request.match.food;

import com.jiankangyouyi.cloud.core.validator.annotation.IntValHC;
import com.jiankangyouyi.cloud.food_match.model.dto.request.AbstractHttpApiRequestDTO;
import lombok.*;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Objects;

/**
 * @description: 配餐请求dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/26 3:32 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class GetFoodNutrientInfoV2RequestDTO extends AbstractHttpApiRequestDTO {

    private static final long serialVersionUID = 1L;
    /**
     * 食物id
     */
    @NotBlank(message = "食物ID不能为空")
    @Length(max = 64, message = "食物ID长度不能超过64")
    private String foodId;

    /**
     * 克数
     */
    @NotNull(message = "克数不能为空")
    @IntValHC(message = "克数必须为整数")
    @Min(value = 1, message = "克数不能小于1")
    @Max(value = 9999, message = "克数长度不能超过4")
    private String gram;


    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;

    public String getFoodId() {
        return foodId;
    }

    public void setFoodId(String foodId) {
        this.foodId = foodId;
    }

    public Integer getGram() {
        if (Objects.isNull(gram)) {
            return null;
        }
        return Integer.valueOf(gram);
    }

    public void setGram(String gram) {
        this.gram = gram;
    }

    public void setGram(Integer gram) {
        if (Objects.isNull(gram)) {
            this.gram = null;
            return;
        }
        this.gram = String.valueOf(getGram());
    }
}
