package com.jiankangyouyi.cloud.food_match.model.dto.request.match.test;

import com.jiankangyouyi.cloud.data.center.api.model.dto.response.EnergyBalancePlanInfoResponseDTO;
import com.jiankangyouyi.cloud.data.center.api.model.entity.EnergyRatio;
import com.jiankangyouyi.cloud.data.center.api.model.entity.MealRatio;
import com.jiankangyouyi.cloud.food_match.api.model.vo.FoodMatchVO;
import com.jiankangyouyi.cloud.food_match.model.dto.request.match.APIMatchFoodV2RequestDTO;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import java.math.BigDecimal;
import java.util.List;
import java.util.Objects;

/**
 * 测试参数
 *
 * @author june
 * @date 2022/11/02
 */
@Data
@Slf4j
public class MatchTestParam {

    public static final ThreadLocal<MatchTestParam> PARAM = new ThreadLocal<>();

    /**
     * 能量比例
     */
    private EnergyRatio energyRatio;

    /**
     * 餐次比例
     */
    private List<MealRatio> mealRatio;

    /**
     * 批次ID
     */
    private String batchId;
    /**
     * 备注
     */
    private String remark;

    /**
     * 三餐能量最小值缩减
     */
    private BigDecimal mealsEnergyMinCut = BigDecimal.valueOf(0.005);
    /**
     * 三餐能量最大值缩减
     */
    private BigDecimal mealsEnergyMaxCut = BigDecimal.valueOf(0.01);
    /**
     * 膳食结构带公式的下限缩减
     */
    private BigDecimal dietaryMinCut = BigDecimal.valueOf(0.05);
    /**
     * 膳食结构带公式的上缩减
     */
    private BigDecimal dietaryMaxCut = BigDecimal.valueOf(0.03);
    /**
     * 禽肉蛋-膳食结构 - g
     */
    private BigDecimal dietaryEegCut = BigDecimal.valueOf(1);

    // 以下参数不支持传参
    /**
     * 能量平衡计划
     */
    private EnergyBalancePlanInfoResponseDTO energyBalancePlan;
    /**
     * 配餐结果
     */
    private FoodMatchVO matchResult;
    /**
     * 配餐请求
     */
    private APIMatchFoodV2RequestDTO matchRequest;

    /**
     * 是否插入日志
     */
    private Boolean isInsertLog = Boolean.FALSE;

    /**
     * 设置测试参数
     *
     * @param testParam 测试参数
     */
    public static void setTestParam(MatchTestParam testParam) {
        if (Objects.isNull(testParam)) {
            testParam = new MatchTestParam();
        }
        PARAM.set(testParam);
    }

    /**
     * 获取测试参数
     *
     * @return {@link MatchTestParam}
     */
    public static MatchTestParam getTestParam() {
        MatchTestParam testParam = PARAM.get();
        if (Objects.isNull(testParam)) {
            testParam = new MatchTestParam();
            setTestParam(testParam);
        }
        return testParam;
    }

    /**
     * 清空测试参数
     */
    public static void clearTestParam() {
        PARAM.remove();
    }

}
