package com.jiankangyouyi.cloud.food_match.model.dto.response.match;

import com.jiankangyouyi.cloud.core.validator.annotation.SizeHC;
import com.jiankangyouyi.cloud.data.center.api.model.entity.component.HealthProblemInfo;
import com.jiankangyouyi.cloud.data.center.api.model.entity.component.NutrientStateInfo;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @description: 用户最后一次配餐请求的请求信息
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/30 5:43 下午
 */
@Data
public class UserLastFoodMatchReqInfoResponseDTO implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * 用户id
     */
    @SizeHC(value = 32)
    private String userId;
    /**
     * 体重 kg
     * @length 5,2
     */
    private BigDecimal weight;
    /**
     * 身高 cm
     * @length 3
     */
    private int height;
    /**
     * 出生年月日 yyyy-MM-dd
     * @length 10
     */
    private String birthday;
    /**
     * 性别 1:男2:女
     * @length 1
     */
    private String gender;
    /**
     * 体力活动等级
     * @length 1
     */
    private String activityLevel;
    /**
     * 运动等级
     * @length 1
     */
    private Integer exerciseRiskLevel;
    /**
     * 疾病情况
     */
    private List<HealthProblemInfo> healthProblemInfos;

    /**
     * NULL 营养素状态信息 当健康问题包含 NUTRIENT_DEFICIENCY 时此处不可为空
     */
    private List<NutrientStateInfo> nutrientStateInfos;

    /**
     * NUll 分娩日期,性别为女性时才能赋值 yyyy-MM-dd
     * @length 10
     */
    private String deliveryDate;

    /**
     * NULL 哺乳状态，性别为女性时才能赋值
     * <p>
     * {@link com.jiankangyouyi.cloud.data.center.api.enums.LactationStatusEnum}
     * @length 1
     */
    private String lactationStatus;
    /**
     * 配餐日期 yyyy-MM-dd
     * @length 10
     */
    private String planningDate;

    /**
     * NULL 民族 （膳食使用时数据来源——字典——字典大类：食物库，字典子类：禁忌民族）
     * @length 16
     */
    private String nation;
    /**
     * 所在的地域
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：国家及地区）
     * @length 16
     */
    private String area;

    /**
     * 喜好口味
     * （膳食使用时数据来源——字典——字典大类：食物库，字典子类：口味）
     */
    private List<String> taste;
    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;


    /**
     * 糖尿病用药情况
     * {@link com.jiankangyouyi.cloud.data.center.api.enums.Type2DiabetesPharmacyEnum}
     */
    @SizeHC(1)
    private String type2DiabetesPharmacyCode;
}
