package com.jiankangyouyi.cloud.food_match.model.entity.mongodb;

import com.jiankangyouyi.cloud.food_match.enums.FoodQuantityLevelEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;
import java.util.List;

/**
 * 动态配餐规 则
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@FieldNameConstants
@Document(collection = "v3.7.food_match.rule")
public class FoodMatchRuleDOV3_7 implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    private ObjectId id;

    /**
     * 餐次类型  {@link com.jiankangyouyi.cloud.data.center.api.enums.MealType}
     */
    private Integer mealTimesType;

    /**
     * 餐类 key  唯一标示
     */
    private  String mealKey;

    /**
     * 是否支持加餐
     * v3.7
     */
    private boolean extra;

    /**
     * 热量等级 {@link FoodQuantityLevelEnum}
     * v3.7
     */
    private List<String> quantityLevels;

    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;

    /**
     * 推荐食物坑位
     */
    private List<List<FoodMatchRuleFoodDOV3_7>> foodMatchRuleFoodList;


}
