package com.jiankangyouyi.cloud.food_match.model.vo;

import cn.hutool.core.util.NumberUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.QiniuKeyToUrlJsonSerialize;
import com.jiankangyouyi.cloud.food_match.api.model.entity.food.FoodMatchDietaryPattern;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.data.annotation.Transient;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @description: 食物营养素汇总信息响应dto, 信息都是*过可食部系数的
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/27 10:19 上午
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class FoodNutrientInfoCountVO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 食物id 唯一
     */
    private String foodId;
    /**
     * 食物名称
     */
    private String foodName;

    /**
     * 食物图片
     */
    @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
    private String foodImg;

    /**
     * 提供的总能量 kcal
     */
    private BigDecimal totalEnergy;


    /**
     * 食物总含量 碳水化合物含量 大卡
     */
    private BigDecimal carbohydrate;
    /**
     * 食物总含量 蛋白质含量 大卡
     */
    private BigDecimal protein;
    /**
     * 食物总含量 脂肪含量 大卡
     */
    private BigDecimal fat;

    /**
     * 食物总含量 碳水化合物含量 g
     */
    private BigDecimal carbohydrateGram;
    /**
     * 食物总含量 蛋白质含量 g
     */
    private BigDecimal proteinGram;
    /**
     * 食物总含量 脂肪含量 g
     */
    private BigDecimal fatGram;

    /**
     * 主要组成食材
     */
    private List<FoodConstituteInfo> majorMaterials;

    /**
     * 次要组成材料
     */
    private List<FoodConstituteInfo> minorMaterials;

    /**
     * 烹饪步骤
     */
    private List<CookingStep> cookingSteps;


    /**
     * 维生素信息
     */
    private Vitamin vitaminInfo;
    /***
     * 矿物质信息
     */
    private Mineral mineralInfo;
    /**
     * 氨基酸信息
     */
    private AminoAcid aminoAcidInfo;
    /**
     * 脂肪酸信息
     */
    private FattyAcid fattyAcidInfo;
    /**
     * 植物化学物信息
     */
    private Phytochemical phytochemicalInfo;

    /**
     * 食物基本组成信息
     */
    private FoodBasicCompositionInfo foodBasicCompositionInfo;

    /**
     * 膳食结构信息
     */
    private FoodMatchDietaryPattern dietaryPattern;

    /**
     * 根据可食部系数处理数据
     *
     * @param edibleRatio 可食部系数
     * @param gram        克数
     */
    public void execDataByEdibleRatio(BigDecimal edibleRatio, BigDecimal gram) {
        //region 三大产能从g转化为大卡算上重量以及可食部并填补
        BigDecimal carbohydrateGram = this.getCarbohydrateGram();
        BigDecimal proteinGram = this.getProteinGram();
        BigDecimal fatGram = this.getFatGram();
        BigDecimal carbohydrate = carbohydrateGram.multiply(BigDecimal.valueOf(4)).multiply(edibleRatio).multiply(gram);
        BigDecimal protein = proteinGram.multiply(BigDecimal.valueOf(4)).multiply(edibleRatio).multiply(gram);
        BigDecimal fat = fatGram.multiply(BigDecimal.valueOf(9)).multiply(edibleRatio).multiply(gram);
        this.setCarbohydrate(carbohydrate);
        this.setProtein(protein);
        this.setFat(fat);
        //endregion
        //region 认为三大产能相加就是总能量
        this.setTotalEnergy(NumberUtil.add(this.getCarbohydrate(), this.getProtein(), this.getFat()));
        //endregion
        //region 处理维生素信息 算上重量和可食部
        Vitamin vitaminInfo = this.getVitaminInfo();
        if (vitaminInfo != null) {
            vitaminInfo.setVitaminA(NumberUtil.mul(vitaminInfo.getVitaminA(), edibleRatio, gram));
            vitaminInfo.setVitaminB1(NumberUtil.mul(vitaminInfo.getVitaminB1(), edibleRatio, gram));
            vitaminInfo.setVitaminB2(NumberUtil.mul(vitaminInfo.getVitaminB2(), edibleRatio, gram));
            vitaminInfo.setVitaminB3(NumberUtil.mul(vitaminInfo.getVitaminB3(), edibleRatio, gram));
            vitaminInfo.setVitaminB5(NumberUtil.mul(vitaminInfo.getVitaminB5(), edibleRatio, gram));
            vitaminInfo.setVitaminB6(NumberUtil.mul(vitaminInfo.getVitaminB6(), edibleRatio, gram));
            vitaminInfo.setVitaminB9(NumberUtil.mul(vitaminInfo.getVitaminB9(), edibleRatio, gram));
            vitaminInfo.setVitaminB12(NumberUtil.mul(vitaminInfo.getVitaminB12(), edibleRatio, gram));
            vitaminInfo.setVitaminC(NumberUtil.mul(vitaminInfo.getVitaminC(), edibleRatio, gram));
            vitaminInfo.setVitaminD(NumberUtil.mul(vitaminInfo.getVitaminD(), edibleRatio, gram));
            vitaminInfo.setVitaminE(NumberUtil.mul(vitaminInfo.getVitaminE(), edibleRatio, gram));
            vitaminInfo.setVitaminH(NumberUtil.mul(vitaminInfo.getVitaminH(), edibleRatio, gram));
            vitaminInfo.setVitaminK(NumberUtil.mul(vitaminInfo.getVitaminK(), edibleRatio, gram));
            vitaminInfo.setCholine(NumberUtil.mul(vitaminInfo.getCholine(), edibleRatio, gram));
        }
        //endregion
        //region 处理矿物质信息 算上重量和可食部
        Mineral mineralInfo = this.getMineralInfo();
        if (mineralInfo != null) {
            mineralInfo.setCalcium(NumberUtil.mul(mineralInfo.getCalcium(), edibleRatio, gram));
            mineralInfo.setPhosphorus(NumberUtil.mul(mineralInfo.getPhosphorus(), edibleRatio, gram));
            mineralInfo.setPotassium(NumberUtil.mul(mineralInfo.getPotassium(), edibleRatio, gram));
            mineralInfo.setSodium(NumberUtil.mul(mineralInfo.getSodium(), edibleRatio, gram));
            mineralInfo.setMagnesium(NumberUtil.mul(mineralInfo.getMagnesium(), edibleRatio, gram));
            mineralInfo.setCopper(NumberUtil.mul(mineralInfo.getCopper(), edibleRatio, gram));
            mineralInfo.setIron(NumberUtil.mul(mineralInfo.getIron(), edibleRatio, gram));
            mineralInfo.setZinc(NumberUtil.mul(mineralInfo.getZinc(), edibleRatio, gram));
            mineralInfo.setManganese(NumberUtil.mul(mineralInfo.getManganese(), edibleRatio, gram));
            mineralInfo.setIodine(NumberUtil.mul(mineralInfo.getIodine(), edibleRatio, gram));
            mineralInfo.setChromium(NumberUtil.mul(mineralInfo.getChromium(), edibleRatio, gram));
            mineralInfo.setFluorine(NumberUtil.mul(mineralInfo.getFluorine(), edibleRatio, gram));
            mineralInfo.setSelenium(NumberUtil.mul(mineralInfo.getSelenium(), edibleRatio, gram));
        }
        //endregion
        //region 氨基酸信息 算上重量和可食部
        AminoAcid aminoAcidInfo = this.getAminoAcidInfo();
        if (aminoAcidInfo != null) {
            aminoAcidInfo.setIsoleucine(NumberUtil.mul(aminoAcidInfo.getIsoleucine(), edibleRatio, gram));
            aminoAcidInfo.setLeucine(NumberUtil.mul(aminoAcidInfo.getLeucine(), edibleRatio, gram));
            aminoAcidInfo.setLysine(NumberUtil.mul(aminoAcidInfo.getLysine(), edibleRatio, gram));
            aminoAcidInfo.setMethionine(NumberUtil.mul(aminoAcidInfo.getMethionine(), edibleRatio, gram));
            aminoAcidInfo.setCysteine(NumberUtil.mul(aminoAcidInfo.getCysteine(), edibleRatio, gram));
            aminoAcidInfo.setPhenylalanine(NumberUtil.mul(aminoAcidInfo.getPhenylalanine(), edibleRatio, gram));
            aminoAcidInfo.setTyrosine(NumberUtil.mul(aminoAcidInfo.getTyrosine(), edibleRatio, gram));
            aminoAcidInfo.setThreonine(NumberUtil.mul(aminoAcidInfo.getThreonine(), edibleRatio, gram));
            aminoAcidInfo.setTryptophan(NumberUtil.mul(aminoAcidInfo.getTryptophan(), edibleRatio, gram));
            aminoAcidInfo.setValine(NumberUtil.mul(aminoAcidInfo.getValine(), edibleRatio, gram));
            aminoAcidInfo.setArginine(NumberUtil.mul(aminoAcidInfo.getArginine(), edibleRatio, gram));
            aminoAcidInfo.setHistidine(NumberUtil.mul(aminoAcidInfo.getHistidine(), edibleRatio, gram));
            aminoAcidInfo.setAlanine(NumberUtil.mul(aminoAcidInfo.getAlanine(), edibleRatio, gram));
            aminoAcidInfo.setAsparticAcid(NumberUtil.mul(aminoAcidInfo.getAsparticAcid(), edibleRatio, gram));
            aminoAcidInfo.setGlutamicAcid(NumberUtil.mul(aminoAcidInfo.getGlutamicAcid(), edibleRatio, gram));
            aminoAcidInfo.setGlycine(NumberUtil.mul(aminoAcidInfo.getGlycine(), edibleRatio, gram));
            aminoAcidInfo.setProline(NumberUtil.mul(aminoAcidInfo.getProline(), edibleRatio, gram));
            aminoAcidInfo.setSerine(NumberUtil.mul(aminoAcidInfo.getSerine(), edibleRatio, gram));
        }
        //endregion
        //region 脂肪酸信息 算上重量和可食部
        FattyAcid fattyAcidInfo = this.getFattyAcidInfo();
        if (fattyAcidInfo != null) {
            fattyAcidInfo.setTotalFattyAcid(NumberUtil.mul(fattyAcidInfo.getTotalFattyAcid(), edibleRatio, gram));
            fattyAcidInfo.setSaturatedFattyAcid(NumberUtil.mul(fattyAcidInfo.getSaturatedFattyAcid(), edibleRatio, gram));
            fattyAcidInfo.setMonounsaturatedFattyAcid(NumberUtil.mul(fattyAcidInfo.getMonounsaturatedFattyAcid(), edibleRatio, gram));
            fattyAcidInfo.setPolyunsaturatedFattyAcid(NumberUtil.mul(fattyAcidInfo.getPolyunsaturatedFattyAcid(), edibleRatio, gram));
            fattyAcidInfo.setSfaPercent(NumberUtil.mul(fattyAcidInfo.getSfaPercent(), edibleRatio, gram));
            fattyAcidInfo.setMfaPercent(NumberUtil.mul(fattyAcidInfo.getMfaPercent(), edibleRatio, gram));
            fattyAcidInfo.setPfaPercent(NumberUtil.mul(fattyAcidInfo.getPfaPercent(), edibleRatio, gram));
        }
        //endregion
        //region 植物化学物信息 算上重量和可食部
        Phytochemical phytochemicalInfo = this.getPhytochemicalInfo();
        if (phytochemicalInfo != null) {
            phytochemicalInfo.setPhytosterol(NumberUtil.mul(phytochemicalInfo.getPhytosterol(), edibleRatio, gram));
            phytochemicalInfo.setCarotene(NumberUtil.mul(phytochemicalInfo.getCarotene(), edibleRatio, gram));
            phytochemicalInfo.setLuteinZeaxanthin(NumberUtil.mul(phytochemicalInfo.getLuteinZeaxanthin(), edibleRatio, gram));
            Flavonoid flavonoid = phytochemicalInfo.getFlavonoid();
            if (flavonoid != null) {
                flavonoid.setQuercetin(NumberUtil.mul(flavonoid.getQuercetin(), edibleRatio, gram));
                flavonoid.setMyricetin(NumberUtil.mul(flavonoid.getMyricetin(), edibleRatio, gram));
                flavonoid.setLuteolin(NumberUtil.mul(flavonoid.getLuteolin(), edibleRatio, gram));
                flavonoid.setKaemPferol(NumberUtil.mul(flavonoid.getKaemPferol(), edibleRatio, gram));
                flavonoid.setApigenin(NumberUtil.mul(flavonoid.getApigenin(), edibleRatio, gram));
            }
            Isoflavone isoflavone = phytochemicalInfo.getIsoflavone();
            if (isoflavone != null) {
                isoflavone.setDaidzein(NumberUtil.mul(isoflavone.getDaidzein(), edibleRatio, gram));
                isoflavone.setGlycitein(NumberUtil.mul(isoflavone.getGlycitein(), edibleRatio, gram));
                isoflavone.setGenistein(NumberUtil.mul(isoflavone.getGenistein(), edibleRatio, gram));
            }
            Anthocyanidin anthocyanidin = phytochemicalInfo.getAnthocyanidin();
            if (anthocyanidin != null) {
                anthocyanidin.setDelphinidin(NumberUtil.mul(anthocyanidin.getDelphinidin(), edibleRatio, gram));
                anthocyanidin.setCyamidin(NumberUtil.mul(anthocyanidin.getCyamidin(), edibleRatio, gram));
                anthocyanidin.setPeonidin(NumberUtil.mul(anthocyanidin.getPeonidin(), edibleRatio, gram));
            }
            Resveratrol resveratrol = phytochemicalInfo.getResveratrol();
            if (resveratrol != null) {
                resveratrol.setResveratrol(NumberUtil.mul(resveratrol.getResveratrol(), edibleRatio, gram));
                resveratrol.setPolydatin(NumberUtil.mul(resveratrol.getPolydatin(), edibleRatio, gram));
            }
        }

        //endregion
        //region 处理食物基本信息 算上重量和可食部
        FoodBasicCompositionInfo foodBasicCompositionInfo = this.getFoodBasicCompositionInfo();
        if (foodBasicCompositionInfo != null) {
            foodBasicCompositionInfo.setEnergy(this.getTotalEnergy().intValue());
            foodBasicCompositionInfo.setProtein(this.getProteinGram());
            foodBasicCompositionInfo.setFat(this.getFatGram());
            foodBasicCompositionInfo.setCarbohydrate(this.getCarbohydrateGram());
            foodBasicCompositionInfo.setWater(NumberUtil.mul(foodBasicCompositionInfo.getWater(), edibleRatio, gram));
            foodBasicCompositionInfo.setInsolubleFiber(NumberUtil.mul(foodBasicCompositionInfo.getInsolubleFiber(), edibleRatio, gram));
            foodBasicCompositionInfo.setSolubilityFiber(NumberUtil.mul(foodBasicCompositionInfo.getSolubilityFiber(), edibleRatio, gram));
            foodBasicCompositionInfo.setDietaryFiber(NumberUtil.mul(foodBasicCompositionInfo.getDietaryFiber(), edibleRatio, gram));
            foodBasicCompositionInfo.setCholesterol(NumberUtil.mul(foodBasicCompositionInfo.getCholesterol(), edibleRatio, gram));
            foodBasicCompositionInfo.setPurine(NumberUtil.mul(foodBasicCompositionInfo.getPurine(), edibleRatio, gram));
            foodBasicCompositionInfo.setAsh(NumberUtil.mul(foodBasicCompositionInfo.getAsh(), edibleRatio, gram));
        }
        //endregion

        //region 膳食结构
        FoodMatchDietaryPattern dietaryPattern = this.getDietaryPattern();
        if (dietaryPattern != null) {
            dietaryPattern.setCereal(NumberUtil.mul(dietaryPattern.getCereal(), edibleRatio, gram));
            dietaryPattern.setAllCereal(NumberUtil.mul(dietaryPattern.getAllCereal(), edibleRatio, gram));
            dietaryPattern.setPotato(NumberUtil.mul(dietaryPattern.getPotato(), edibleRatio, gram));
            dietaryPattern.setVegetable(NumberUtil.mul(dietaryPattern.getVegetable(), edibleRatio, gram));
            dietaryPattern.setFruits(NumberUtil.mul(dietaryPattern.getFruits(), edibleRatio, gram));
            dietaryPattern.setMeat(NumberUtil.mul(dietaryPattern.getMeat(), edibleRatio, gram));
            dietaryPattern.setEgg(NumberUtil.mul(dietaryPattern.getEgg(), edibleRatio, gram));
            dietaryPattern.setSeafood(NumberUtil.mul(dietaryPattern.getSeafood(), edibleRatio, gram));
            dietaryPattern.setMilk(NumberUtil.mul(dietaryPattern.getMilk(), edibleRatio, gram));
            dietaryPattern.setSoya(NumberUtil.mul(dietaryPattern.getSoya(), edibleRatio, gram));
            dietaryPattern.setNut(NumberUtil.mul(dietaryPattern.getNut(), edibleRatio, gram));
            dietaryPattern.setOil(NumberUtil.mul(dietaryPattern.getOil(), edibleRatio, gram));
        }
        //endregion
    }

    /**
     * 食物基本组成信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class FoodBasicCompositionInfo implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 热量
         */
        private Integer energy;
        /**
         * 蛋白质
         */
        private BigDecimal protein;
        /**
         * 脂肪
         */
        private BigDecimal fat;
        /**
         * 碳水化合物
         */
        private BigDecimal carbohydrate;
        /**
         * 水分
         */
        private BigDecimal water;
        /**
         * 不溶性纤维
         */
        private BigDecimal insolubleFiber;
        /**
         * 可溶性纤维
         */
        private BigDecimal solubilityFiber;
        /**
         * 膳食纤维
         */
        private BigDecimal dietaryFiber;
        /**
         * 胆固醇
         */
        private BigDecimal cholesterol;
        /**
         * 嘌呤
         */
        private BigDecimal purine;
        /**
         * GI 值 不计算可食部
         */
        private BigDecimal gi;
        /**
         * 灰分
         */
        private BigDecimal ash;

        /**
         * 可食部
         */
        private Integer edible;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            BigDecimal energy = BigDecimal.valueOf(this.getEnergy());
            this.setEnergy(NumberUtil.mul(energy, BigDecimal.valueOf(0.01), gram, edibleRatio).setScale(0, BigDecimal.ROUND_UP).intValue());
            this.setProtein(NumberUtil.mul(this.getProtein(), BigDecimal.valueOf(0.01), gram, edibleRatio));
            this.setFat(NumberUtil.mul(this.getFat(), BigDecimal.valueOf(0.01), gram, edibleRatio));
            this.setCarbohydrate(NumberUtil.mul(this.getCarbohydrate(), BigDecimal.valueOf(0.01), gram, edibleRatio));

            this.setWater(NumberUtil.mul(this.getWater(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            this.setInsolubleFiber(NumberUtil.mul(this.getInsolubleFiber(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            this.setSolubilityFiber(NumberUtil.mul(this.getSolubilityFiber(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            this.setDietaryFiber(NumberUtil.mul(this.getDietaryFiber(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            this.setCholesterol(NumberUtil.mul(this.getCholesterol(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            this.setPurine(NumberUtil.mul(this.getPurine(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
            //modify by yangsongbo GI值不需要按照质量进行换算
//            this.setGi(NumberUtil.mul(this.getGi(), gram, BigDecimal.valueOf(0.01)));
            this.setAsh(NumberUtil.mul(this.getAsh(), gram, edibleRatio, BigDecimal.valueOf(0.01)));
        }
    }


    /**
     * 食物组成信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class FoodConstituteInfo implements Serializable {

        private static final long serialVersionUID = 1L;
        /**
         * 食材id
         */
        private String foodId;

        /**
         * 食材名称
         */
        private String foodName;

        /**
         * 食物图片地址
         */
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private String foodImg;

        /**
         * 质量
         */
        private BigDecimal gram;

        /**
         * 单位：g/ml
         */
        private String unit;
    }

    /**
     * 维生素信息
     */
    @Data
    public static class Vitamin implements Serializable {
        /**
         * 维生素A
         */
        private BigDecimal vitaminA;
        /**
         * 维生素B1
         */
        private BigDecimal vitaminB1;
        /**
         * 维生素B2
         */
        private BigDecimal vitaminB2;
        /**
         * 维生素B3
         */
        private BigDecimal vitaminB3;
        /**
         * 维生素B5
         */
        private BigDecimal vitaminB5;
        /**
         * 维生素B6
         */
        private BigDecimal vitaminB6;
        /**
         * 维生素B9
         */
        private BigDecimal vitaminB9;
        /**
         * 维生素B12
         */
        private BigDecimal vitaminB12;
        /**
         * 维生素C
         */
        private BigDecimal vitaminC;
        /**
         * 维生素D
         */
        private BigDecimal vitaminD;
        /**
         * 维生素E
         */
        private BigDecimal vitaminE;
        /**
         * 维生素H
         */
        private BigDecimal vitaminH;
        /**
         * 维生素K
         */
        private BigDecimal vitaminK;
        /**
         * 胆碱
         */
        private BigDecimal choline;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            this.setVitaminA(this.getVitaminA().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB1(this.getVitaminB1().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB2(this.getVitaminB2().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB3(this.getVitaminB3().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB5(this.getVitaminB5().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB6(this.getVitaminB6().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB9(this.getVitaminB9().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminB12(this.getVitaminB12().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminC(this.getVitaminC().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminD(this.getVitaminD().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminE(this.getVitaminE().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminH(this.getVitaminH().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setVitaminK(this.getVitaminK().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
            this.setCholine(this.getCholine().multiply(BigDecimal.valueOf(0.01)).multiply(gram).multiply(edibleRatio));
        }
    }

    /**
     * 烹饪步骤
     */
    @Data
    public static class CookingStep implements Serializable {
        /**
         * 标题
         */
        private String title;
        /**
         * 内容
         */
        private String content;
        /**
         * 图片key
         */
        private String imageKey;

        @Transient
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private String imageKeyUrl;

        public String getImageKeyUrl() {
            return this.imageKey;
        }
    }


    /**
     * 矿物质信息
     */
    @Data
    public static class Mineral implements Serializable {
        /**
         * 钙
         */
        private BigDecimal calcium;
        /**
         * 磷
         */
        private BigDecimal phosphorus;
        /**
         * 钾
         */
        private BigDecimal potassium;
        /**
         * 钠
         */
        private BigDecimal sodium;
        /**
         * 镁
         */
        private BigDecimal magnesium;
        /**
         * 铜
         */
        private BigDecimal copper;
        /**
         * 铁
         */
        private BigDecimal iron;
        /**
         * 锌
         */
        private BigDecimal zinc;
        /**
         * 锰
         */
        private BigDecimal manganese;
        /**
         * 碘
         */
        private BigDecimal iodine;
        /**
         * 铬
         */
        private BigDecimal chromium;
        /**
         * 氟（生物素、维生素B7)
         */
        private BigDecimal fluorine;
        /**
         * 硒
         */
        private BigDecimal selenium;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            this.setCalcium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getCalcium(), gram, edibleRatio));
            this.setPhosphorus(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getPhosphorus(), gram, edibleRatio));
            this.setPotassium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getPotassium(), gram, edibleRatio));
            this.setSodium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getSodium(), gram, edibleRatio));
            this.setMagnesium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getMagnesium(), gram, edibleRatio));
            this.setCopper(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getCopper(), gram, edibleRatio));
            this.setIron(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getIron(), gram, edibleRatio));
            this.setZinc(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getZinc(), gram, edibleRatio));
            this.setManganese(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getManganese(), gram, edibleRatio));
            this.setIodine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getIodine(), gram, edibleRatio));
            this.setChromium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getChromium(), gram, edibleRatio));
            this.setFluorine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getFluorine(), gram, edibleRatio));
            this.setSelenium(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getSelenium(), gram, edibleRatio));
        }

    }

    /**
     * 氨基酸信息
     */
    @Data
    public static class AminoAcid implements Serializable {
        /**
         * 异亮氨酸
         */
        private BigDecimal isoleucine;
        /**
         * 亮氨酸
         */
        private BigDecimal leucine;
        /**
         * 赖氨酸
         */
        private BigDecimal lysine;
        /**
         * 蛋氨酸
         */
        private BigDecimal methionine;
        /**
         * 胱氨酸
         */
        private BigDecimal cysteine;
        /**
         * 苯丙氨酸
         */
        private BigDecimal phenylalanine;
        /**
         * 酪氨酸
         */
        private BigDecimal tyrosine;
        /**
         * 苏氨酸
         */
        private BigDecimal threonine;
        /**
         * 色氨酸
         */
        private BigDecimal tryptophan;
        /**
         * 缬氨酸
         */
        private BigDecimal valine;
        /**
         * 精氨酸
         */
        private BigDecimal arginine;
        /**
         * 组氨酸
         */
        private BigDecimal histidine;
        /**
         * 丙氨酸
         */
        private BigDecimal alanine;
        /**
         * 天冬氨酸
         */
        private BigDecimal asparticAcid;
        /**
         * 谷氨酸
         */
        private BigDecimal glutamicAcid;
        /**
         * 甘氨酸
         */
        private BigDecimal glycine;
        /**
         * 脯氨酸
         */
        private BigDecimal proline;
        /**
         * 丝氨酸
         */
        private BigDecimal serine;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            this.setIsoleucine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getIsoleucine(), gram, edibleRatio));
            this.setLeucine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getLeucine(), gram, edibleRatio));
            this.setLysine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getLysine(), gram, edibleRatio));
            this.setMethionine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getMethionine(), gram, edibleRatio));
            this.setCysteine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getCysteine(), gram, edibleRatio));
            this.setPhenylalanine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getPhenylalanine(), gram, edibleRatio));
            this.setTyrosine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getTyrosine(), gram, edibleRatio));
            this.setThreonine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getThreonine(), gram, edibleRatio));
            this.setTryptophan(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getTryptophan(), gram, edibleRatio));
            this.setValine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getValine(), gram, edibleRatio));
            this.setArginine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getArginine(), gram, edibleRatio));
            this.setHistidine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getHistidine(), gram, edibleRatio));
            this.setAlanine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getAlanine(), gram, edibleRatio));
            this.setAsparticAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getAsparticAcid(), gram, edibleRatio));
            this.setGlutamicAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getGlutamicAcid(), gram, edibleRatio));
            this.setGlycine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getGlycine(), gram, edibleRatio));
            this.setProline(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getProline(), gram, edibleRatio));
            this.setSerine(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getSerine(), gram, edibleRatio));
        }
    }


    /**
     * 脂肪酸信息
     */
    @Data
    public static class FattyAcid implements Serializable {
        /**
         * 总脂肪酸
         */
        private BigDecimal totalFattyAcid;
        /**
         * 饱和脂肪酸
         */
        private BigDecimal saturatedFattyAcid;
        /**
         * 单不饱和脂肪酸
         */
        private BigDecimal monounsaturatedFattyAcid;
        /**
         * 多不饱和脂肪酸
         */
        private BigDecimal polyunsaturatedFattyAcid;
        /**
         * 饱和脂肪酸/总脂肪酸
         */
        private BigDecimal sfaPercent;
        /**
         * 单不饱和脂肪酸/总脂肪酸
         */
        private BigDecimal mfaPercent;
        /**
         * 多不饱和脂肪酸/总脂肪酸
         */
        private BigDecimal pfaPercent;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            this.setTotalFattyAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getTotalFattyAcid(), gram, edibleRatio));
            this.setSaturatedFattyAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getSaturatedFattyAcid(), gram, edibleRatio));
            this.setMonounsaturatedFattyAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getMonounsaturatedFattyAcid(), gram, edibleRatio));
            this.setPolyunsaturatedFattyAcid(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getPolyunsaturatedFattyAcid(), gram, edibleRatio));
            //modify by yangsongbo 百分比不需要按照质量进行换算
//            this.setSfaPercent(NumberUtil.mul(BigDecimal.valueOf(0.01),this.getSfaPercent(),gram,edibleRatio));
//            this.setMfaPercent(NumberUtil.mul(BigDecimal.valueOf(0.01),this.getMfaPercent(),gram,edibleRatio));
//            this.setPfaPercent(NumberUtil.mul(BigDecimal.valueOf(0.01),this.getPfaPercent(),gram,edibleRatio));
        }
    }


    /**
     * 植物化学信息
     */
    @Data
    public static class Phytochemical implements Serializable {
        /**
         * 植物淄醇
         */
        private BigDecimal phytosterol;
        /**
         * 胡萝卜素
         */
        private BigDecimal carotene;
        /**
         * 叶黄素和玉米黄素
         */
        private BigDecimal luteinZeaxanthin;
        /**
         * 类黄酮
         */
        private Flavonoid flavonoid;
        /**
         * 大豆异黄酮
         */
        private Isoflavone isoflavone;
        /**
         * 花青素
         */
        private Anthocyanidin anthocyanidin;
        /**
         * 白藜芦醇
         */
        private Resveratrol resveratrol;

        /**
         * 处理数据 加上克数换算和可食部系数
         *
         * @param gram        克数
         * @param edibleRatio 可食部系数
         */
        public void execData(BigDecimal gram, BigDecimal edibleRatio) {
            this.setPhytosterol(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getPhytosterol(), gram, edibleRatio));
            this.setCarotene(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getCarotene(), gram, edibleRatio));
            this.setLuteinZeaxanthin(NumberUtil.mul(BigDecimal.valueOf(0.01), this.getLuteinZeaxanthin(), gram, edibleRatio));
            Flavonoid flavonoid = this.getFlavonoid();
            flavonoid.setQuercetin(NumberUtil.mul(BigDecimal.valueOf(0.01), flavonoid.getQuercetin(), gram, edibleRatio));
            flavonoid.setMyricetin(NumberUtil.mul(BigDecimal.valueOf(0.01), flavonoid.getMyricetin(), gram, edibleRatio));
            flavonoid.setLuteolin(NumberUtil.mul(BigDecimal.valueOf(0.01), flavonoid.getLuteolin(), gram, edibleRatio));
            flavonoid.setKaemPferol(NumberUtil.mul(BigDecimal.valueOf(0.01), flavonoid.getKaemPferol(), gram, edibleRatio));
            flavonoid.setApigenin(NumberUtil.mul(BigDecimal.valueOf(0.01), flavonoid.getApigenin(), gram, edibleRatio));
            Isoflavone isoflavone = this.getIsoflavone();
            isoflavone.setDaidzein(NumberUtil.mul(BigDecimal.valueOf(0.01), isoflavone.getDaidzein(), gram, edibleRatio));
            isoflavone.setGlycitein(NumberUtil.mul(BigDecimal.valueOf(0.01), isoflavone.getGlycitein(), gram, edibleRatio));
            isoflavone.setGenistein(NumberUtil.mul(BigDecimal.valueOf(0.01), isoflavone.getGenistein(), gram, edibleRatio));
            Anthocyanidin anthocyanidin = this.getAnthocyanidin();
            anthocyanidin.setDelphinidin(NumberUtil.mul(BigDecimal.valueOf(0.01), anthocyanidin.getDelphinidin(), gram, edibleRatio));
            anthocyanidin.setCyamidin(NumberUtil.mul(BigDecimal.valueOf(0.01), anthocyanidin.getCyamidin(), gram, edibleRatio));
            anthocyanidin.setPeonidin(NumberUtil.mul(BigDecimal.valueOf(0.01), anthocyanidin.getPeonidin(), gram, edibleRatio));
            Resveratrol resveratrol = this.getResveratrol();
            resveratrol.setResveratrol(NumberUtil.mul(BigDecimal.valueOf(0.01), resveratrol.getResveratrol(), gram, edibleRatio));
            resveratrol.setPolydatin(NumberUtil.mul(BigDecimal.valueOf(0.01), resveratrol.getPolydatin(), gram, edibleRatio));
        }

        public Flavonoid getFlavonoid() {
            if (this.flavonoid == null) {
                return new Flavonoid();
            }
            return this.flavonoid;
        }

        public Isoflavone getIsoflavone() {
            if (this.isoflavone == null) {
                return new Isoflavone();
            }
            return this.isoflavone;
        }

        public Anthocyanidin getAnthocyanidin() {
            if (this.anthocyanidin == null) {
                return new Anthocyanidin();
            }
            return this.anthocyanidin;
        }

        public Resveratrol getResveratrol() {
            if (this.resveratrol == null) {
                return new Resveratrol();
            }
            return this.resveratrol;
        }
    }

    /**
     * 类黄酮信息
     */
    @Data
    public static class Flavonoid implements Serializable {
        /**
         * 槲皮素
         */
        private BigDecimal quercetin;
        /**
         * 杨梅黄酮
         */
        private BigDecimal myricetin;
        /**
         * 玉米黄酮
         */
        private BigDecimal luteolin;
        /**
         * 坎二菲醇
         */
        private BigDecimal kaemPferol;
        /**
         * 芹菜配基
         */
        private BigDecimal apigenin;
    }

    /**
     * 大豆异黄酮信息
     */
    @Data
    public static class Isoflavone implements Serializable {
        /**
         * 黄豆苷元
         */
        private BigDecimal daidzein;
        /**
         * 黄豆黄素
         */
        private BigDecimal glycitein;
        /**
         * 染料木黄酮
         */
        private BigDecimal genistein;
    }

    /**
     * 花青素信息
     */
    @Data
    public static class Anthocyanidin implements Serializable {
        /**
         * 飞燕草素
         */
        private BigDecimal delphinidin;
        /**
         * 矢车菊素
         */
        private BigDecimal cyamidin;
        /**
         * 芍药素
         */
        private BigDecimal peonidin;
    }

    /**
     * 白藜芦醇
     */
    @Data
    public static class Resveratrol implements Serializable {
        /**
         * 白藜芦醇
         */
        private BigDecimal resveratrol;
        /**
         * 白藜芦醇苷
         */
        private BigDecimal polydatin;
    }


}
