package com.june.entitytodbdoc.dto;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

/**
 * 字段信息DTO
 * @author june
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
public class DocumentInfoDTO {
    /**
     * 文档名称
     */
    private String documentName;

    /**
     * 文档备注
     */
    private String documentDescribe;


    public String getDocumentName() {
        return Optional.ofNullable(documentName).orElse("");
    }

    /**
     * 字段信息列表
     */
    private List<FieldInfoDTO> fieldList;


    public DocumentInfoDTO(List<FieldInfoDTO> fieldList) {
        this.fieldList = fieldList;
    }

    public DocumentInfoDTO(String documentName, String documentDescribe) {
        this.documentName = documentName;
        this.documentDescribe = documentDescribe;
    }

    /**
     * 字段信息
     * @author june
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class FieldInfoDTO {

        /**
         * 字段ID
         */
        private  final String filedId = UUID.randomUUID().toString();

        /**
         * 属性名称
         */
        private String fieldName;

        /**
         * 属性类型
         */
        private String fieldType;

        /**
         * 属性注释
         */
        private String describe;

        /**
         * 子字段列表
         */
        private List<FieldInfoDTO> childrenFieldList;

        public String getFieldName() {
            return Optional.ofNullable(fieldName).orElse("");
        }

        public FieldInfoDTO(String fieldName, String fieldType, String describe) {
            this.fieldName = fieldName;
            this.fieldType = fieldType;
            this.describe = describe;
        }
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        DocumentInfoDTO that = (DocumentInfoDTO) o;

        return documentName.equals(that.documentName);
    }

    @Override
    public int hashCode() {
        return documentName.hashCode();
    }
}

