package com.june.entitytodbdoc.utils;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.ArrayUtils;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * 文件工具类
 *
 * @author june
 */
public class FileUtils {
    public static List<String> findJavaFilePaths(String directory) {
        List<String> javaFilePaths = new ArrayList<>();

        File folder = new File(directory);

        File[] files = folder.listFiles();
        if (ArrayUtils.isEmpty(files)) {
            return javaFilePaths;
        }
        for (File file : files) {
            String absolutePath = file.getAbsolutePath();
            if (file.isFile() && absolutePath.toLowerCase().endsWith("do.java") && absolutePath.contains("jiankangyouyi")) {
                javaFilePaths.add(absolutePath);
            } else if (file.isDirectory()) {
                javaFilePaths.addAll(findJavaFilePaths(absolutePath));
            }
        }

        return javaFilePaths;
    }


    public static void writeMarkdown(List<String> contentList, String fileFullPath) {
        if (CollectionUtils.isEmpty(contentList)) {
            return;
        }
        if (!exists(fileFullPath)) {
            createFile(fileFullPath);
        }
        // 创建文件对象并设置文件路径
        File file = new File(fileFullPath);
        FileWriter writer = null;
        try {
            writer = new FileWriter(file);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 循环拼接数据
        for (String content : contentList) {
            // 写入数据
            BufferedWriter writer2 = new BufferedWriter(writer);
            try {
                writer2.write(content);
                writer2.newLine();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
            try {
                writer2.flush();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        try {
            writer.flush();
            writer.close();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }

    }


    /**
     * 判断文件是否存在
     *
     * @param fileFullPath 文件全路径
     * @return 是否存在
     */
    public static boolean exists(String fileFullPath) {
        File file = new File(fileFullPath);
        return file.exists();
    }

    /**
     * 创建文件
     *
     * @param fileFullPath 文件路径
     */
    public static void createFile(String fileFullPath) {
        File file = new File(fileFullPath);
        if (!file.exists()) {
            try {
                file.createNewFile();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
    }
}
